/* Automatically @generated by tree-sitter v0.25.8 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 850
#define LARGE_STATE_COUNT 16
#define SYMBOL_COUNT 244
#define ALIAS_COUNT 1
#define TOKEN_COUNT 130
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 20
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 42
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  anon_sym_PERCENT_LBRACE = 1,
  aux_sym__c_code_token1 = 2,
  anon_sym_RBRACE = 3,
  anon_sym_PERCENT = 4,
  anon_sym_RBRACE_PERCENT = 5,
  anon_sym_PERCENT_PERCENT = 6,
  aux_sym__c_code_token2 = 7,
  anon_sym_LF = 8,
  anon_sym_POUND = 9,
  sym_line_number = 10,
  anon_sym_program = 11,
  anon_sym_LPAREN = 12,
  anon_sym_RPAREN = 13,
  anon_sym_entry = 14,
  anon_sym_exit = 15,
  anon_sym_struct = 16,
  anon_sym_SEMI = 17,
  anon_sym_LBRACE = 18,
  anon_sym_COMMA = 19,
  anon_sym_EQ = 20,
  anon_sym_STAR = 21,
  anon_sym_foreign = 22,
  anon_sym_evflag = 23,
  anon_sym_enum = 24,
  anon_sym_union = 25,
  anon_sym_typename = 26,
  anon_sym_void = 27,
  anon_sym_char = 28,
  anon_sym_short = 29,
  anon_sym_int = 30,
  anon_sym_long = 31,
  anon_sym_unsigned = 32,
  anon_sym_int8_t = 33,
  anon_sym_uint8_t = 34,
  anon_sym_int16_t = 35,
  anon_sym_uint16_t = 36,
  anon_sym_int32_t = 37,
  anon_sym_uint32_t = 38,
  anon_sym_float = 39,
  anon_sym_double = 40,
  anon_sym_string = 41,
  anon_sym_const = 42,
  anon_sym_assign = 43,
  anon_sym_to = 44,
  anon_sym_DQUOTE = 45,
  aux_sym__expanded_string_literal_token1 = 46,
  anon_sym_LBRACE2 = 47,
  anon_sym_LBRACK = 48,
  anon_sym_RBRACK = 49,
  anon_sym_monitor = 50,
  anon_sym_sync = 51,
  anon_sym_syncq = 52,
  anon_sym_option = 53,
  anon_sym_PLUS = 54,
  anon_sym_DASH = 55,
  anon_sym_ss = 56,
  anon_sym_state = 57,
  anon_sym_when = 58,
  anon_sym_break = 59,
  anon_sym_continue = 60,
  anon_sym_if = 61,
  anon_sym_else = 62,
  anon_sym_while = 63,
  anon_sym_for = 64,
  anon_sym_DOT = 65,
  anon_sym_DASH_GT = 66,
  anon_sym_DASH_DASH = 67,
  anon_sym_PLUS_PLUS = 68,
  anon_sym_BANG = 69,
  anon_sym_TILDE = 70,
  anon_sym_SLASH = 71,
  anon_sym_PIPE_PIPE = 72,
  anon_sym_AMP_AMP = 73,
  anon_sym_PIPE = 74,
  anon_sym_CARET = 75,
  anon_sym_AMP = 76,
  anon_sym_EQ_EQ = 77,
  anon_sym_BANG_EQ = 78,
  anon_sym_GT = 79,
  anon_sym_GT_EQ = 80,
  anon_sym_LT_EQ = 81,
  anon_sym_LT = 82,
  anon_sym_LT_LT = 83,
  anon_sym_GT_GT = 84,
  anon_sym_QMARK = 85,
  anon_sym_COLON = 86,
  anon_sym_STAR_EQ = 87,
  anon_sym_SLASH_EQ = 88,
  anon_sym_PERCENT_EQ = 89,
  anon_sym_PLUS_EQ = 90,
  anon_sym_DASH_EQ = 91,
  anon_sym_LT_LT_EQ = 92,
  anon_sym_GT_GT_EQ = 93,
  anon_sym_AMP_EQ = 94,
  anon_sym_CARET_EQ = 95,
  anon_sym_PIPE_EQ = 96,
  anon_sym_sizeof = 97,
  sym_true = 98,
  sym_false = 99,
  sym_null = 100,
  anon_sym_L_DQUOTE = 101,
  anon_sym_u_DQUOTE = 102,
  anon_sym_U_DQUOTE = 103,
  anon_sym_u8_DQUOTE = 104,
  aux_sym_string_literal_token1 = 105,
  sym_number_literal = 106,
  anon_sym_L_SQUOTE = 107,
  anon_sym_u_SQUOTE = 108,
  anon_sym_U_SQUOTE = 109,
  anon_sym_u8_SQUOTE = 110,
  anon_sym_SQUOTE = 111,
  aux_sym_char_literal_token1 = 112,
  sym_system_lib_string = 113,
  sym_identifier = 114,
  sym_escape_sequence = 115,
  aux_sym_preproc_include_token1 = 116,
  aux_sym_preproc_def_token1 = 117,
  anon_sym_LPAREN2 = 118,
  anon_sym_DOT_DOT_DOT = 119,
  aux_sym_preproc_if_token1 = 120,
  aux_sym_preproc_if_token2 = 121,
  aux_sym_preproc_ifdef_token1 = 122,
  aux_sym_preproc_ifdef_token2 = 123,
  aux_sym_preproc_else_token1 = 124,
  aux_sym_preproc_elif_token1 = 125,
  sym_preproc_directive = 126,
  sym_preproc_arg = 127,
  anon_sym_defined = 128,
  sym_comment = 129,
  sym_source_file = 130,
  sym__top_level_item = 131,
  sym__c_code = 132,
  sym_line_marker = 133,
  sym_program = 134,
  sym_program_param = 135,
  sym_initial_defn = 136,
  sym_final_defn = 137,
  sym_entry = 138,
  sym_exit = 139,
  sym_funcdef = 140,
  sym_structdef = 141,
  sym_field_declaration_list = 142,
  sym_member_decl = 143,
  sym_declaration = 144,
  sym_init_declarator = 145,
  sym_declarator = 146,
  sym__declarator = 147,
  sym_pointer_declarator = 148,
  sym_function_declarator = 149,
  sym_array_declarator = 150,
  sym_init_expr = 151,
  sym_foreign_declaration = 152,
  sym_basetype = 153,
  sym_prim_type = 154,
  sym_type_expr = 155,
  sym_abs_decl = 156,
  sym__abs_decl = 157,
  sym_abstract_pointer_declarator = 158,
  sym_abstract_function_declarator = 159,
  sym_type_qualifier = 160,
  sym_param_decl = 161,
  sym_assign = 162,
  sym__expanded_string_literal = 163,
  sym_parameter_expansion = 164,
  sym_subscript = 165,
  sym_monitor = 166,
  sym_sync = 167,
  sym_event_flag = 168,
  sym_syncq = 169,
  sym_syncq_size = 170,
  sym_option = 171,
  sym_option_value = 172,
  sym_state_set = 173,
  sym_ss_defn = 174,
  sym_state = 175,
  sym_state_block = 176,
  sym_state_defn = 177,
  sym_transition = 178,
  sym_block = 179,
  sym_block_defn = 180,
  sym_statement = 181,
  sym_break_statement = 182,
  sym_continue_statement = 183,
  sym_if_statement = 184,
  sym_else_statement = 185,
  sym_while_statement = 186,
  sym_for_statement = 187,
  sym__expr = 188,
  sym_parenthesized_expression = 189,
  sym_call_expression = 190,
  sym_exit_expression = 191,
  sym_subscript_expression = 192,
  sym_field_expression = 193,
  sym_update_expression = 194,
  sym_unary_expression = 195,
  sym_binary_expression = 196,
  sym_conditional_expression = 197,
  sym_assignment_expression = 198,
  sym_cast_expression = 199,
  sym_sizeof_expression = 200,
  sym__comma_expr = 201,
  sym_comma_expr = 202,
  sym_args = 203,
  sym_string_literal = 204,
  sym_char_literal = 205,
  sym_preproc_include = 206,
  sym_preproc_def = 207,
  sym_preproc_function_def = 208,
  sym_preproc_params = 209,
  sym_preproc_call = 210,
  sym_preproc_if = 211,
  sym_preproc_ifdef = 212,
  sym_preproc_else = 213,
  sym_preproc_elif = 214,
  sym__preproc_expression = 215,
  sym_preproc_parenthesized_expression = 216,
  sym_preproc_defined = 217,
  sym_preproc_unary_expression = 218,
  sym_preproc_call_expression = 219,
  sym_preproc_argument_list = 220,
  sym_preproc_binary_expression = 221,
  aux_sym_source_file_repeat1 = 222,
  aux_sym__c_code_repeat1 = 223,
  aux_sym_program_repeat1 = 224,
  aux_sym_program_repeat2 = 225,
  aux_sym_program_repeat3 = 226,
  aux_sym_field_declaration_list_repeat1 = 227,
  aux_sym_declaration_repeat1 = 228,
  aux_sym_function_declarator_repeat1 = 229,
  aux_sym_init_expr_repeat1 = 230,
  aux_sym_foreign_declaration_repeat1 = 231,
  aux_sym_assign_repeat1 = 232,
  aux_sym__expanded_string_literal_repeat1 = 233,
  aux_sym_state_set_repeat1 = 234,
  aux_sym_state_set_repeat2 = 235,
  aux_sym_state_block_repeat1 = 236,
  aux_sym_state_block_repeat2 = 237,
  aux_sym_block_repeat1 = 238,
  aux_sym_block_repeat2 = 239,
  aux_sym_comma_expr_repeat1 = 240,
  aux_sym_string_literal_repeat1 = 241,
  aux_sym_preproc_params_repeat1 = 242,
  aux_sym_preproc_argument_list_repeat1 = 243,
  alias_sym_file_name = 244,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_PERCENT_LBRACE] = "%{",
  [aux_sym__c_code_token1] = "_c_code_token1",
  [anon_sym_RBRACE] = "}",
  [anon_sym_PERCENT] = "%",
  [anon_sym_RBRACE_PERCENT] = "}%",
  [anon_sym_PERCENT_PERCENT] = "%%",
  [aux_sym__c_code_token2] = "c_code",
  [anon_sym_LF] = "\n",
  [anon_sym_POUND] = "#",
  [sym_line_number] = "line_number",
  [anon_sym_program] = "program",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_entry] = "entry",
  [anon_sym_exit] = "exit",
  [anon_sym_struct] = "struct",
  [anon_sym_SEMI] = ";",
  [anon_sym_LBRACE] = "{",
  [anon_sym_COMMA] = ",",
  [anon_sym_EQ] = "=",
  [anon_sym_STAR] = "*",
  [anon_sym_foreign] = "foreign",
  [anon_sym_evflag] = "evflag",
  [anon_sym_enum] = "enum",
  [anon_sym_union] = "union",
  [anon_sym_typename] = "typename",
  [anon_sym_void] = "void",
  [anon_sym_char] = "char",
  [anon_sym_short] = "short",
  [anon_sym_int] = "int",
  [anon_sym_long] = "long",
  [anon_sym_unsigned] = "unsigned",
  [anon_sym_int8_t] = "int8_t",
  [anon_sym_uint8_t] = "uint8_t",
  [anon_sym_int16_t] = "int16_t",
  [anon_sym_uint16_t] = "uint16_t",
  [anon_sym_int32_t] = "int32_t",
  [anon_sym_uint32_t] = "uint32_t",
  [anon_sym_float] = "float",
  [anon_sym_double] = "double",
  [anon_sym_string] = "string",
  [anon_sym_const] = "const",
  [anon_sym_assign] = "assign",
  [anon_sym_to] = "to",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym__expanded_string_literal_token1] = "_expanded_string_literal_token1",
  [anon_sym_LBRACE2] = "{",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_monitor] = "monitor",
  [anon_sym_sync] = "sync",
  [anon_sym_syncq] = "syncq",
  [anon_sym_option] = "option",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_ss] = "ss",
  [anon_sym_state] = "state",
  [anon_sym_when] = "when",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [anon_sym_if] = "if",
  [anon_sym_else] = "else",
  [anon_sym_while] = "while",
  [anon_sym_for] = "for",
  [anon_sym_DOT] = ".",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_BANG] = "!",
  [anon_sym_TILDE] = "~",
  [anon_sym_SLASH] = "/",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE] = "|",
  [anon_sym_CARET] = "^",
  [anon_sym_AMP] = "&",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_GT] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_LT] = "<",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_QMARK] = "\?",
  [anon_sym_COLON] = ":",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_sizeof] = "sizeof",
  [sym_true] = "true",
  [sym_false] = "false",
  [sym_null] = "null",
  [anon_sym_L_DQUOTE] = "L\"",
  [anon_sym_u_DQUOTE] = "u\"",
  [anon_sym_U_DQUOTE] = "U\"",
  [anon_sym_u8_DQUOTE] = "u8\"",
  [aux_sym_string_literal_token1] = "string_literal_token1",
  [sym_number_literal] = "number_literal",
  [anon_sym_L_SQUOTE] = "L'",
  [anon_sym_u_SQUOTE] = "u'",
  [anon_sym_U_SQUOTE] = "U'",
  [anon_sym_u8_SQUOTE] = "u8'",
  [anon_sym_SQUOTE] = "'",
  [aux_sym_char_literal_token1] = "char_literal_token1",
  [sym_system_lib_string] = "system_lib_string",
  [sym_identifier] = "identifier",
  [sym_escape_sequence] = "escape_sequence",
  [aux_sym_preproc_include_token1] = "#include",
  [aux_sym_preproc_def_token1] = "#define",
  [anon_sym_LPAREN2] = "(",
  [anon_sym_DOT_DOT_DOT] = "...",
  [aux_sym_preproc_if_token1] = "#if",
  [aux_sym_preproc_if_token2] = "#endif",
  [aux_sym_preproc_ifdef_token1] = "#ifdef",
  [aux_sym_preproc_ifdef_token2] = "#ifndef",
  [aux_sym_preproc_else_token1] = "#else",
  [aux_sym_preproc_elif_token1] = "#elif",
  [sym_preproc_directive] = "preproc_directive",
  [sym_preproc_arg] = "preproc_arg",
  [anon_sym_defined] = "defined",
  [sym_comment] = "comment",
  [sym_source_file] = "source_file",
  [sym__top_level_item] = "_top_level_item",
  [sym__c_code] = "_c_code",
  [sym_line_marker] = "line_marker",
  [sym_program] = "program",
  [sym_program_param] = "program_param",
  [sym_initial_defn] = "initial_defn",
  [sym_final_defn] = "final_defn",
  [sym_entry] = "entry",
  [sym_exit] = "exit",
  [sym_funcdef] = "funcdef",
  [sym_structdef] = "structdef",
  [sym_field_declaration_list] = "field_declaration_list",
  [sym_member_decl] = "member_decl",
  [sym_declaration] = "declaration",
  [sym_init_declarator] = "init_declarator",
  [sym_declarator] = "declarator",
  [sym__declarator] = "_declarator",
  [sym_pointer_declarator] = "pointer_declarator",
  [sym_function_declarator] = "function_declarator",
  [sym_array_declarator] = "array_declarator",
  [sym_init_expr] = "init_expr",
  [sym_foreign_declaration] = "foreign_declaration",
  [sym_basetype] = "basetype",
  [sym_prim_type] = "prim_type",
  [sym_type_expr] = "type_expr",
  [sym_abs_decl] = "abs_decl",
  [sym__abs_decl] = "_abs_decl",
  [sym_abstract_pointer_declarator] = "abstract_pointer_declarator",
  [sym_abstract_function_declarator] = "abstract_function_declarator",
  [sym_type_qualifier] = "type_qualifier",
  [sym_param_decl] = "param_decl",
  [sym_assign] = "assign",
  [sym__expanded_string_literal] = "string_literal",
  [sym_parameter_expansion] = "parameter_expansion",
  [sym_subscript] = "subscript",
  [sym_monitor] = "monitor",
  [sym_sync] = "sync",
  [sym_event_flag] = "event_flag",
  [sym_syncq] = "syncq",
  [sym_syncq_size] = "syncq_size",
  [sym_option] = "option",
  [sym_option_value] = "option_value",
  [sym_state_set] = "state_set",
  [sym_ss_defn] = "ss_defn",
  [sym_state] = "state",
  [sym_state_block] = "state_block",
  [sym_state_defn] = "state_defn",
  [sym_transition] = "transition",
  [sym_block] = "block",
  [sym_block_defn] = "block_defn",
  [sym_statement] = "statement",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_if_statement] = "if_statement",
  [sym_else_statement] = "else_statement",
  [sym_while_statement] = "while_statement",
  [sym_for_statement] = "for_statement",
  [sym__expr] = "_expr",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_call_expression] = "call_expression",
  [sym_exit_expression] = "exit_expression",
  [sym_subscript_expression] = "subscript_expression",
  [sym_field_expression] = "field_expression",
  [sym_update_expression] = "update_expression",
  [sym_unary_expression] = "unary_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_conditional_expression] = "conditional_expression",
  [sym_assignment_expression] = "assignment_expression",
  [sym_cast_expression] = "cast_expression",
  [sym_sizeof_expression] = "sizeof_expression",
  [sym__comma_expr] = "_comma_expr",
  [sym_comma_expr] = "comma_expr",
  [sym_args] = "args",
  [sym_string_literal] = "string_literal",
  [sym_char_literal] = "char_literal",
  [sym_preproc_include] = "preproc_include",
  [sym_preproc_def] = "preproc_def",
  [sym_preproc_function_def] = "preproc_function_def",
  [sym_preproc_params] = "preproc_params",
  [sym_preproc_call] = "preproc_call",
  [sym_preproc_if] = "preproc_if",
  [sym_preproc_ifdef] = "preproc_ifdef",
  [sym_preproc_else] = "preproc_else",
  [sym_preproc_elif] = "preproc_elif",
  [sym__preproc_expression] = "_preproc_expression",
  [sym_preproc_parenthesized_expression] = "parenthesized_expression",
  [sym_preproc_defined] = "preproc_defined",
  [sym_preproc_unary_expression] = "unary_expression",
  [sym_preproc_call_expression] = "call_expression",
  [sym_preproc_argument_list] = "argument_list",
  [sym_preproc_binary_expression] = "binary_expression",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym__c_code_repeat1] = "_c_code_repeat1",
  [aux_sym_program_repeat1] = "program_repeat1",
  [aux_sym_program_repeat2] = "program_repeat2",
  [aux_sym_program_repeat3] = "program_repeat3",
  [aux_sym_field_declaration_list_repeat1] = "field_declaration_list_repeat1",
  [aux_sym_declaration_repeat1] = "declaration_repeat1",
  [aux_sym_function_declarator_repeat1] = "function_declarator_repeat1",
  [aux_sym_init_expr_repeat1] = "init_expr_repeat1",
  [aux_sym_foreign_declaration_repeat1] = "foreign_declaration_repeat1",
  [aux_sym_assign_repeat1] = "assign_repeat1",
  [aux_sym__expanded_string_literal_repeat1] = "_expanded_string_literal_repeat1",
  [aux_sym_state_set_repeat1] = "state_set_repeat1",
  [aux_sym_state_set_repeat2] = "state_set_repeat2",
  [aux_sym_state_block_repeat1] = "state_block_repeat1",
  [aux_sym_state_block_repeat2] = "state_block_repeat2",
  [aux_sym_block_repeat1] = "block_repeat1",
  [aux_sym_block_repeat2] = "block_repeat2",
  [aux_sym_comma_expr_repeat1] = "comma_expr_repeat1",
  [aux_sym_string_literal_repeat1] = "string_literal_repeat1",
  [aux_sym_preproc_params_repeat1] = "preproc_params_repeat1",
  [aux_sym_preproc_argument_list_repeat1] = "preproc_argument_list_repeat1",
  [alias_sym_file_name] = "file_name",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_PERCENT_LBRACE] = anon_sym_PERCENT_LBRACE,
  [aux_sym__c_code_token1] = aux_sym__c_code_token1,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_RBRACE_PERCENT] = anon_sym_RBRACE_PERCENT,
  [anon_sym_PERCENT_PERCENT] = anon_sym_PERCENT_PERCENT,
  [aux_sym__c_code_token2] = aux_sym__c_code_token2,
  [anon_sym_LF] = anon_sym_LF,
  [anon_sym_POUND] = anon_sym_POUND,
  [sym_line_number] = sym_line_number,
  [anon_sym_program] = anon_sym_program,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_entry] = anon_sym_entry,
  [anon_sym_exit] = anon_sym_exit,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_foreign] = anon_sym_foreign,
  [anon_sym_evflag] = anon_sym_evflag,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_union] = anon_sym_union,
  [anon_sym_typename] = anon_sym_typename,
  [anon_sym_void] = anon_sym_void,
  [anon_sym_char] = anon_sym_char,
  [anon_sym_short] = anon_sym_short,
  [anon_sym_int] = anon_sym_int,
  [anon_sym_long] = anon_sym_long,
  [anon_sym_unsigned] = anon_sym_unsigned,
  [anon_sym_int8_t] = anon_sym_int8_t,
  [anon_sym_uint8_t] = anon_sym_uint8_t,
  [anon_sym_int16_t] = anon_sym_int16_t,
  [anon_sym_uint16_t] = anon_sym_uint16_t,
  [anon_sym_int32_t] = anon_sym_int32_t,
  [anon_sym_uint32_t] = anon_sym_uint32_t,
  [anon_sym_float] = anon_sym_float,
  [anon_sym_double] = anon_sym_double,
  [anon_sym_string] = anon_sym_string,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_assign] = anon_sym_assign,
  [anon_sym_to] = anon_sym_to,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym__expanded_string_literal_token1] = aux_sym__expanded_string_literal_token1,
  [anon_sym_LBRACE2] = anon_sym_LBRACE,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_monitor] = anon_sym_monitor,
  [anon_sym_sync] = anon_sym_sync,
  [anon_sym_syncq] = anon_sym_syncq,
  [anon_sym_option] = anon_sym_option,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_ss] = anon_sym_ss,
  [anon_sym_state] = anon_sym_state,
  [anon_sym_when] = anon_sym_when,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_sizeof] = anon_sym_sizeof,
  [sym_true] = sym_true,
  [sym_false] = sym_false,
  [sym_null] = sym_null,
  [anon_sym_L_DQUOTE] = anon_sym_L_DQUOTE,
  [anon_sym_u_DQUOTE] = anon_sym_u_DQUOTE,
  [anon_sym_U_DQUOTE] = anon_sym_U_DQUOTE,
  [anon_sym_u8_DQUOTE] = anon_sym_u8_DQUOTE,
  [aux_sym_string_literal_token1] = aux_sym_string_literal_token1,
  [sym_number_literal] = sym_number_literal,
  [anon_sym_L_SQUOTE] = anon_sym_L_SQUOTE,
  [anon_sym_u_SQUOTE] = anon_sym_u_SQUOTE,
  [anon_sym_U_SQUOTE] = anon_sym_U_SQUOTE,
  [anon_sym_u8_SQUOTE] = anon_sym_u8_SQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym_char_literal_token1] = aux_sym_char_literal_token1,
  [sym_system_lib_string] = sym_system_lib_string,
  [sym_identifier] = sym_identifier,
  [sym_escape_sequence] = sym_escape_sequence,
  [aux_sym_preproc_include_token1] = aux_sym_preproc_include_token1,
  [aux_sym_preproc_def_token1] = aux_sym_preproc_def_token1,
  [anon_sym_LPAREN2] = anon_sym_LPAREN,
  [anon_sym_DOT_DOT_DOT] = anon_sym_DOT_DOT_DOT,
  [aux_sym_preproc_if_token1] = aux_sym_preproc_if_token1,
  [aux_sym_preproc_if_token2] = aux_sym_preproc_if_token2,
  [aux_sym_preproc_ifdef_token1] = aux_sym_preproc_ifdef_token1,
  [aux_sym_preproc_ifdef_token2] = aux_sym_preproc_ifdef_token2,
  [aux_sym_preproc_else_token1] = aux_sym_preproc_else_token1,
  [aux_sym_preproc_elif_token1] = aux_sym_preproc_elif_token1,
  [sym_preproc_directive] = sym_preproc_directive,
  [sym_preproc_arg] = sym_preproc_arg,
  [anon_sym_defined] = anon_sym_defined,
  [sym_comment] = sym_comment,
  [sym_source_file] = sym_source_file,
  [sym__top_level_item] = sym__top_level_item,
  [sym__c_code] = sym__c_code,
  [sym_line_marker] = sym_line_marker,
  [sym_program] = sym_program,
  [sym_program_param] = sym_program_param,
  [sym_initial_defn] = sym_initial_defn,
  [sym_final_defn] = sym_final_defn,
  [sym_entry] = sym_entry,
  [sym_exit] = sym_exit,
  [sym_funcdef] = sym_funcdef,
  [sym_structdef] = sym_structdef,
  [sym_field_declaration_list] = sym_field_declaration_list,
  [sym_member_decl] = sym_member_decl,
  [sym_declaration] = sym_declaration,
  [sym_init_declarator] = sym_init_declarator,
  [sym_declarator] = sym_declarator,
  [sym__declarator] = sym__declarator,
  [sym_pointer_declarator] = sym_pointer_declarator,
  [sym_function_declarator] = sym_function_declarator,
  [sym_array_declarator] = sym_array_declarator,
  [sym_init_expr] = sym_init_expr,
  [sym_foreign_declaration] = sym_foreign_declaration,
  [sym_basetype] = sym_basetype,
  [sym_prim_type] = sym_prim_type,
  [sym_type_expr] = sym_type_expr,
  [sym_abs_decl] = sym_abs_decl,
  [sym__abs_decl] = sym__abs_decl,
  [sym_abstract_pointer_declarator] = sym_abstract_pointer_declarator,
  [sym_abstract_function_declarator] = sym_abstract_function_declarator,
  [sym_type_qualifier] = sym_type_qualifier,
  [sym_param_decl] = sym_param_decl,
  [sym_assign] = sym_assign,
  [sym__expanded_string_literal] = sym_string_literal,
  [sym_parameter_expansion] = sym_parameter_expansion,
  [sym_subscript] = sym_subscript,
  [sym_monitor] = sym_monitor,
  [sym_sync] = sym_sync,
  [sym_event_flag] = sym_event_flag,
  [sym_syncq] = sym_syncq,
  [sym_syncq_size] = sym_syncq_size,
  [sym_option] = sym_option,
  [sym_option_value] = sym_option_value,
  [sym_state_set] = sym_state_set,
  [sym_ss_defn] = sym_ss_defn,
  [sym_state] = sym_state,
  [sym_state_block] = sym_state_block,
  [sym_state_defn] = sym_state_defn,
  [sym_transition] = sym_transition,
  [sym_block] = sym_block,
  [sym_block_defn] = sym_block_defn,
  [sym_statement] = sym_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_else_statement] = sym_else_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_for_statement] = sym_for_statement,
  [sym__expr] = sym__expr,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_call_expression] = sym_call_expression,
  [sym_exit_expression] = sym_exit_expression,
  [sym_subscript_expression] = sym_subscript_expression,
  [sym_field_expression] = sym_field_expression,
  [sym_update_expression] = sym_update_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_conditional_expression] = sym_conditional_expression,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_cast_expression] = sym_cast_expression,
  [sym_sizeof_expression] = sym_sizeof_expression,
  [sym__comma_expr] = sym__comma_expr,
  [sym_comma_expr] = sym_comma_expr,
  [sym_args] = sym_args,
  [sym_string_literal] = sym_string_literal,
  [sym_char_literal] = sym_char_literal,
  [sym_preproc_include] = sym_preproc_include,
  [sym_preproc_def] = sym_preproc_def,
  [sym_preproc_function_def] = sym_preproc_function_def,
  [sym_preproc_params] = sym_preproc_params,
  [sym_preproc_call] = sym_preproc_call,
  [sym_preproc_if] = sym_preproc_if,
  [sym_preproc_ifdef] = sym_preproc_ifdef,
  [sym_preproc_else] = sym_preproc_else,
  [sym_preproc_elif] = sym_preproc_elif,
  [sym__preproc_expression] = sym__preproc_expression,
  [sym_preproc_parenthesized_expression] = sym_parenthesized_expression,
  [sym_preproc_defined] = sym_preproc_defined,
  [sym_preproc_unary_expression] = sym_unary_expression,
  [sym_preproc_call_expression] = sym_call_expression,
  [sym_preproc_argument_list] = sym_preproc_argument_list,
  [sym_preproc_binary_expression] = sym_binary_expression,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym__c_code_repeat1] = aux_sym__c_code_repeat1,
  [aux_sym_program_repeat1] = aux_sym_program_repeat1,
  [aux_sym_program_repeat2] = aux_sym_program_repeat2,
  [aux_sym_program_repeat3] = aux_sym_program_repeat3,
  [aux_sym_field_declaration_list_repeat1] = aux_sym_field_declaration_list_repeat1,
  [aux_sym_declaration_repeat1] = aux_sym_declaration_repeat1,
  [aux_sym_function_declarator_repeat1] = aux_sym_function_declarator_repeat1,
  [aux_sym_init_expr_repeat1] = aux_sym_init_expr_repeat1,
  [aux_sym_foreign_declaration_repeat1] = aux_sym_foreign_declaration_repeat1,
  [aux_sym_assign_repeat1] = aux_sym_assign_repeat1,
  [aux_sym__expanded_string_literal_repeat1] = aux_sym__expanded_string_literal_repeat1,
  [aux_sym_state_set_repeat1] = aux_sym_state_set_repeat1,
  [aux_sym_state_set_repeat2] = aux_sym_state_set_repeat2,
  [aux_sym_state_block_repeat1] = aux_sym_state_block_repeat1,
  [aux_sym_state_block_repeat2] = aux_sym_state_block_repeat2,
  [aux_sym_block_repeat1] = aux_sym_block_repeat1,
  [aux_sym_block_repeat2] = aux_sym_block_repeat2,
  [aux_sym_comma_expr_repeat1] = aux_sym_comma_expr_repeat1,
  [aux_sym_string_literal_repeat1] = aux_sym_string_literal_repeat1,
  [aux_sym_preproc_params_repeat1] = aux_sym_preproc_params_repeat1,
  [aux_sym_preproc_argument_list_repeat1] = aux_sym_preproc_argument_list_repeat1,
  [alias_sym_file_name] = alias_sym_file_name,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_PERCENT_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__c_code_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__c_code_token2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [sym_line_number] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_program] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_entry] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_exit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_foreign] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_evflag] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_union] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_typename] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_void] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_char] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_short] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_long] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unsigned] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int8_t] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint8_t] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int16_t] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint16_t] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int32_t] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint32_t] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_float] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_double] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_string] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assign] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_to] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__expanded_string_literal_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LBRACE2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_monitor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sync] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_syncq] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_option] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ss] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_state] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_when] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sizeof] = {
    .visible = true,
    .named = false,
  },
  [sym_true] = {
    .visible = true,
    .named = true,
  },
  [sym_false] = {
    .visible = true,
    .named = true,
  },
  [sym_null] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_L_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_U_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_literal_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_number_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_L_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_U_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_char_literal_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_system_lib_string] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preproc_include_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_def_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_if_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_if_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_ifdef_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_ifdef_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_else_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_elif_token1] = {
    .visible = true,
    .named = false,
  },
  [sym_preproc_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_arg] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_defined] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym__top_level_item] = {
    .visible = false,
    .named = true,
  },
  [sym__c_code] = {
    .visible = false,
    .named = true,
  },
  [sym_line_marker] = {
    .visible = true,
    .named = true,
  },
  [sym_program] = {
    .visible = true,
    .named = true,
  },
  [sym_program_param] = {
    .visible = true,
    .named = true,
  },
  [sym_initial_defn] = {
    .visible = true,
    .named = true,
  },
  [sym_final_defn] = {
    .visible = true,
    .named = true,
  },
  [sym_entry] = {
    .visible = true,
    .named = true,
  },
  [sym_exit] = {
    .visible = true,
    .named = true,
  },
  [sym_funcdef] = {
    .visible = true,
    .named = true,
  },
  [sym_structdef] = {
    .visible = true,
    .named = true,
  },
  [sym_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_member_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_init_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym__declarator] = {
    .visible = false,
    .named = true,
  },
  [sym_pointer_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_function_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_array_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_init_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_foreign_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_basetype] = {
    .visible = true,
    .named = true,
  },
  [sym_prim_type] = {
    .visible = true,
    .named = true,
  },
  [sym_type_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_abs_decl] = {
    .visible = true,
    .named = true,
  },
  [sym__abs_decl] = {
    .visible = false,
    .named = true,
  },
  [sym_abstract_pointer_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_abstract_function_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_type_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym_param_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_assign] = {
    .visible = true,
    .named = true,
  },
  [sym__expanded_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript] = {
    .visible = true,
    .named = true,
  },
  [sym_monitor] = {
    .visible = true,
    .named = true,
  },
  [sym_sync] = {
    .visible = true,
    .named = true,
  },
  [sym_event_flag] = {
    .visible = true,
    .named = true,
  },
  [sym_syncq] = {
    .visible = true,
    .named = true,
  },
  [sym_syncq_size] = {
    .visible = true,
    .named = true,
  },
  [sym_option] = {
    .visible = true,
    .named = true,
  },
  [sym_option_value] = {
    .visible = true,
    .named = true,
  },
  [sym_state_set] = {
    .visible = true,
    .named = true,
  },
  [sym_ss_defn] = {
    .visible = true,
    .named = true,
  },
  [sym_state] = {
    .visible = true,
    .named = true,
  },
  [sym_state_block] = {
    .visible = true,
    .named = true,
  },
  [sym_state_defn] = {
    .visible = true,
    .named = true,
  },
  [sym_transition] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_block_defn] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_else_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__expr] = {
    .visible = false,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_exit_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_update_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_cast_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_sizeof_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__comma_expr] = {
    .visible = false,
    .named = true,
  },
  [sym_comma_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_args] = {
    .visible = true,
    .named = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_char_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_include] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_def] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_function_def] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_params] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_call] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_ifdef] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif] = {
    .visible = true,
    .named = true,
  },
  [sym__preproc_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_defined] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__c_code_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_program_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_program_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_program_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_declaration_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_declarator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_init_expr_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_foreign_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_assign_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__expanded_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_state_set_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_state_set_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_state_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_state_block_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_comma_expr_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_params_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_file_name] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_alternative = 1,
  field_argument = 2,
  field_arguments = 3,
  field_body = 4,
  field_condition = 5,
  field_consequence = 6,
  field_declarator = 7,
  field_directive = 8,
  field_field = 9,
  field_function = 10,
  field_initializer = 11,
  field_left = 12,
  field_name = 13,
  field_operator = 14,
  field_parameters = 15,
  field_path = 16,
  field_right = 17,
  field_type = 18,
  field_update = 19,
  field_value = 20,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_body] = "body",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_declarator] = "declarator",
  [field_directive] = "directive",
  [field_field] = "field",
  [field_function] = "function",
  [field_initializer] = "initializer",
  [field_left] = "left",
  [field_name] = "name",
  [field_operator] = "operator",
  [field_parameters] = "parameters",
  [field_path] = "path",
  [field_right] = "right",
  [field_type] = "type",
  [field_update] = "update",
  [field_value] = "value",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 2},
  [5] = {.index = 5, .length = 2},
  [6] = {.index = 7, .length = 2},
  [8] = {.index = 9, .length = 2},
  [9] = {.index = 11, .length = 2},
  [10] = {.index = 13, .length = 3},
  [11] = {.index = 16, .length = 1},
  [12] = {.index = 17, .length = 2},
  [14] = {.index = 19, .length = 3},
  [15] = {.index = 22, .length = 2},
  [16] = {.index = 24, .length = 2},
  [17] = {.index = 26, .length = 1},
  [18] = {.index = 27, .length = 2},
  [19] = {.index = 29, .length = 2},
  [20] = {.index = 31, .length = 1},
  [21] = {.index = 32, .length = 1},
  [22] = {.index = 33, .length = 2},
  [23] = {.index = 35, .length = 1},
  [24] = {.index = 36, .length = 1},
  [25] = {.index = 37, .length = 2},
  [26] = {.index = 39, .length = 1},
  [27] = {.index = 40, .length = 2},
  [28] = {.index = 42, .length = 2},
  [29] = {.index = 44, .length = 3},
  [30] = {.index = 47, .length = 1},
  [31] = {.index = 48, .length = 1},
  [32] = {.index = 49, .length = 2},
  [33] = {.index = 51, .length = 2},
  [34] = {.index = 53, .length = 2},
  [35] = {.index = 55, .length = 3},
  [36] = {.index = 58, .length = 3},
  [37] = {.index = 61, .length = 3},
  [38] = {.index = 64, .length = 4},
  [39] = {.index = 68, .length = 1},
  [40] = {.index = 69, .length = 1},
  [41] = {.index = 70, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_directive, 0},
  [1] =
    {field_name, 1},
  [2] =
    {field_path, 1},
  [3] =
    {field_arguments, 1},
    {field_function, 0},
  [5] =
    {field_argument, 1},
    {field_operator, 0},
  [7] =
    {field_argument, 1},
    {field_directive, 0},
  [9] =
    {field_name, 1},
    {field_value, 2},
  [11] =
    {field_name, 1},
    {field_parameters, 2},
  [13] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [16] =
    {field_condition, 1},
  [17] =
    {field_alternative, 2},
    {field_name, 1},
  [19] =
    {field_name, 1},
    {field_parameters, 2},
    {field_value, 3},
  [22] =
    {field_alternative, 3},
    {field_condition, 1},
  [24] =
    {field_alternative, 3},
    {field_name, 1},
  [26] =
    {field_value, 1},
  [27] =
    {field_argument, 0},
    {field_operator, 1},
  [29] =
    {field_body, 2},
    {field_name, 1},
  [31] =
    {field_name, 2},
  [32] =
    {field_declarator, 0},
  [33] =
    {field_alternative, 4},
    {field_condition, 1},
  [35] =
    {field_function, 0},
  [36] =
    {field_field, 2},
  [37] =
    {field_type, 1},
    {field_value, 3},
  [39] =
    {field_type, 2},
  [40] =
    {field_condition, 2},
    {field_consequence, 4},
  [42] =
    {field_body, 4},
    {field_condition, 2},
  [44] =
    {field_alternative, 4},
    {field_condition, 0},
    {field_consequence, 2},
  [47] =
    {field_body, 5},
  [48] =
    {field_consequence, 1},
  [49] =
    {field_body, 6},
    {field_update, 4},
  [51] =
    {field_body, 6},
    {field_condition, 3},
  [53] =
    {field_body, 6},
    {field_initializer, 2},
  [55] =
    {field_body, 7},
    {field_condition, 3},
    {field_update, 5},
  [58] =
    {field_body, 7},
    {field_initializer, 2},
    {field_update, 5},
  [61] =
    {field_body, 7},
    {field_condition, 4},
    {field_initializer, 2},
  [64] =
    {field_body, 8},
    {field_condition, 4},
    {field_initializer, 2},
    {field_update, 6},
  [68] =
    {field_name, 5},
  [69] =
    {field_condition, 2},
  [70] =
    {field_condition, 2},
    {field_name, 6},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [7] = {
    [2] = alias_sym_file_name,
  },
  [13] = {
    [1] = aux_sym__c_code_token2,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_string_literal, 2,
    sym_string_literal,
    alias_sym_file_name,
  aux_sym__c_code_repeat1, 2,
    aux_sym__c_code_repeat1,
    aux_sym__c_code_token2,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 3,
  [5] = 2,
  [6] = 3,
  [7] = 2,
  [8] = 3,
  [9] = 2,
  [10] = 2,
  [11] = 3,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 16,
  [19] = 16,
  [20] = 20,
  [21] = 17,
  [22] = 16,
  [23] = 23,
  [24] = 17,
  [25] = 16,
  [26] = 17,
  [27] = 17,
  [28] = 28,
  [29] = 28,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 35,
  [39] = 36,
  [40] = 37,
  [41] = 41,
  [42] = 31,
  [43] = 41,
  [44] = 32,
  [45] = 33,
  [46] = 46,
  [47] = 34,
  [48] = 46,
  [49] = 30,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 58,
  [60] = 58,
  [61] = 61,
  [62] = 62,
  [63] = 62,
  [64] = 64,
  [65] = 64,
  [66] = 61,
  [67] = 62,
  [68] = 61,
  [69] = 64,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 72,
  [78] = 78,
  [79] = 79,
  [80] = 72,
  [81] = 71,
  [82] = 71,
  [83] = 70,
  [84] = 73,
  [85] = 73,
  [86] = 86,
  [87] = 70,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 89,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 114,
  [127] = 118,
  [128] = 119,
  [129] = 122,
  [130] = 98,
  [131] = 91,
  [132] = 132,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 134,
  [138] = 138,
  [139] = 135,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 50,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 56,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 181,
  [182] = 141,
  [183] = 145,
  [184] = 151,
  [185] = 140,
  [186] = 141,
  [187] = 142,
  [188] = 143,
  [189] = 144,
  [190] = 145,
  [191] = 151,
  [192] = 146,
  [193] = 147,
  [194] = 148,
  [195] = 140,
  [196] = 147,
  [197] = 143,
  [198] = 148,
  [199] = 142,
  [200] = 144,
  [201] = 146,
  [202] = 202,
  [203] = 203,
  [204] = 204,
  [205] = 205,
  [206] = 206,
  [207] = 205,
  [208] = 206,
  [209] = 205,
  [210] = 206,
  [211] = 211,
  [212] = 212,
  [213] = 203,
  [214] = 203,
  [215] = 215,
  [216] = 211,
  [217] = 217,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 54,
  [224] = 224,
  [225] = 225,
  [226] = 226,
  [227] = 227,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 233,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 238,
  [239] = 239,
  [240] = 79,
  [241] = 241,
  [242] = 76,
  [243] = 243,
  [244] = 244,
  [245] = 86,
  [246] = 246,
  [247] = 50,
  [248] = 56,
  [249] = 249,
  [250] = 250,
  [251] = 251,
  [252] = 57,
  [253] = 253,
  [254] = 254,
  [255] = 255,
  [256] = 51,
  [257] = 257,
  [258] = 232,
  [259] = 215,
  [260] = 260,
  [261] = 229,
  [262] = 212,
  [263] = 230,
  [264] = 76,
  [265] = 220,
  [266] = 79,
  [267] = 76,
  [268] = 86,
  [269] = 50,
  [270] = 56,
  [271] = 255,
  [272] = 231,
  [273] = 257,
  [274] = 219,
  [275] = 234,
  [276] = 235,
  [277] = 236,
  [278] = 56,
  [279] = 279,
  [280] = 168,
  [281] = 212,
  [282] = 86,
  [283] = 217,
  [284] = 228,
  [285] = 215,
  [286] = 79,
  [287] = 226,
  [288] = 50,
  [289] = 289,
  [290] = 179,
  [291] = 233,
  [292] = 260,
  [293] = 56,
  [294] = 50,
  [295] = 279,
  [296] = 279,
  [297] = 179,
  [298] = 260,
  [299] = 168,
  [300] = 79,
  [301] = 76,
  [302] = 86,
  [303] = 303,
  [304] = 304,
  [305] = 305,
  [306] = 306,
  [307] = 307,
  [308] = 308,
  [309] = 309,
  [310] = 310,
  [311] = 311,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 318,
  [319] = 319,
  [320] = 320,
  [321] = 320,
  [322] = 317,
  [323] = 319,
  [324] = 316,
  [325] = 320,
  [326] = 319,
  [327] = 317,
  [328] = 316,
  [329] = 329,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 331,
  [334] = 332,
  [335] = 335,
  [336] = 330,
  [337] = 337,
  [338] = 338,
  [339] = 339,
  [340] = 340,
  [341] = 341,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 347,
  [348] = 348,
  [349] = 349,
  [350] = 350,
  [351] = 351,
  [352] = 352,
  [353] = 345,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 357,
  [358] = 348,
  [359] = 359,
  [360] = 360,
  [361] = 361,
  [362] = 362,
  [363] = 363,
  [364] = 363,
  [365] = 346,
  [366] = 366,
  [367] = 343,
  [368] = 368,
  [369] = 369,
  [370] = 356,
  [371] = 349,
  [372] = 372,
  [373] = 352,
  [374] = 374,
  [375] = 375,
  [376] = 376,
  [377] = 344,
  [378] = 354,
  [379] = 368,
  [380] = 355,
  [381] = 381,
  [382] = 125,
  [383] = 368,
  [384] = 384,
  [385] = 385,
  [386] = 381,
  [387] = 375,
  [388] = 388,
  [389] = 359,
  [390] = 360,
  [391] = 391,
  [392] = 361,
  [393] = 393,
  [394] = 374,
  [395] = 341,
  [396] = 391,
  [397] = 369,
  [398] = 372,
  [399] = 125,
  [400] = 384,
  [401] = 385,
  [402] = 362,
  [403] = 339,
  [404] = 340,
  [405] = 338,
  [406] = 342,
  [407] = 347,
  [408] = 350,
  [409] = 351,
  [410] = 335,
  [411] = 411,
  [412] = 412,
  [413] = 335,
  [414] = 414,
  [415] = 388,
  [416] = 388,
  [417] = 417,
  [418] = 418,
  [419] = 419,
  [420] = 420,
  [421] = 421,
  [422] = 420,
  [423] = 423,
  [424] = 424,
  [425] = 425,
  [426] = 426,
  [427] = 427,
  [428] = 428,
  [429] = 429,
  [430] = 430,
  [431] = 431,
  [432] = 432,
  [433] = 433,
  [434] = 434,
  [435] = 435,
  [436] = 436,
  [437] = 437,
  [438] = 438,
  [439] = 439,
  [440] = 440,
  [441] = 441,
  [442] = 442,
  [443] = 443,
  [444] = 444,
  [445] = 442,
  [446] = 442,
  [447] = 447,
  [448] = 426,
  [449] = 440,
  [450] = 432,
  [451] = 424,
  [452] = 425,
  [453] = 453,
  [454] = 437,
  [455] = 439,
  [456] = 436,
  [457] = 434,
  [458] = 431,
  [459] = 432,
  [460] = 435,
  [461] = 441,
  [462] = 435,
  [463] = 436,
  [464] = 431,
  [465] = 465,
  [466] = 429,
  [467] = 441,
  [468] = 434,
  [469] = 430,
  [470] = 427,
  [471] = 426,
  [472] = 433,
  [473] = 440,
  [474] = 424,
  [475] = 425,
  [476] = 465,
  [477] = 477,
  [478] = 478,
  [479] = 433,
  [480] = 427,
  [481] = 437,
  [482] = 439,
  [483] = 428,
  [484] = 465,
  [485] = 428,
  [486] = 430,
  [487] = 487,
  [488] = 429,
  [489] = 489,
  [490] = 490,
  [491] = 491,
  [492] = 492,
  [493] = 493,
  [494] = 494,
  [495] = 495,
  [496] = 496,
  [497] = 497,
  [498] = 498,
  [499] = 499,
  [500] = 500,
  [501] = 501,
  [502] = 502,
  [503] = 503,
  [504] = 504,
  [505] = 505,
  [506] = 505,
  [507] = 505,
  [508] = 498,
  [509] = 509,
  [510] = 510,
  [511] = 511,
  [512] = 512,
  [513] = 513,
  [514] = 514,
  [515] = 515,
  [516] = 498,
  [517] = 517,
  [518] = 518,
  [519] = 519,
  [520] = 520,
  [521] = 501,
  [522] = 522,
  [523] = 520,
  [524] = 524,
  [525] = 496,
  [526] = 520,
  [527] = 527,
  [528] = 528,
  [529] = 520,
  [530] = 527,
  [531] = 520,
  [532] = 527,
  [533] = 527,
  [534] = 520,
  [535] = 535,
  [536] = 527,
  [537] = 537,
  [538] = 538,
  [539] = 493,
  [540] = 492,
  [541] = 527,
  [542] = 542,
  [543] = 490,
  [544] = 544,
  [545] = 545,
  [546] = 544,
  [547] = 547,
  [548] = 548,
  [549] = 549,
  [550] = 550,
  [551] = 551,
  [552] = 552,
  [553] = 553,
  [554] = 554,
  [555] = 555,
  [556] = 556,
  [557] = 557,
  [558] = 558,
  [559] = 545,
  [560] = 554,
  [561] = 561,
  [562] = 562,
  [563] = 563,
  [564] = 564,
  [565] = 547,
  [566] = 544,
  [567] = 557,
  [568] = 568,
  [569] = 564,
  [570] = 547,
  [571] = 564,
  [572] = 487,
  [573] = 573,
  [574] = 574,
  [575] = 575,
  [576] = 576,
  [577] = 577,
  [578] = 578,
  [579] = 579,
  [580] = 580,
  [581] = 581,
  [582] = 582,
  [583] = 583,
  [584] = 584,
  [585] = 585,
  [586] = 586,
  [587] = 587,
  [588] = 588,
  [589] = 589,
  [590] = 590,
  [591] = 591,
  [592] = 592,
  [593] = 593,
  [594] = 594,
  [595] = 577,
  [596] = 596,
  [597] = 597,
  [598] = 598,
  [599] = 599,
  [600] = 600,
  [601] = 601,
  [602] = 602,
  [603] = 603,
  [604] = 604,
  [605] = 605,
  [606] = 606,
  [607] = 607,
  [608] = 578,
  [609] = 609,
  [610] = 610,
  [611] = 611,
  [612] = 612,
  [613] = 613,
  [614] = 614,
  [615] = 593,
  [616] = 616,
  [617] = 617,
  [618] = 618,
  [619] = 619,
  [620] = 598,
  [621] = 600,
  [622] = 622,
  [623] = 623,
  [624] = 624,
  [625] = 578,
  [626] = 626,
  [627] = 575,
  [628] = 628,
  [629] = 629,
  [630] = 598,
  [631] = 593,
  [632] = 584,
  [633] = 633,
  [634] = 634,
  [635] = 635,
  [636] = 636,
  [637] = 637,
  [638] = 638,
  [639] = 639,
  [640] = 640,
  [641] = 641,
  [642] = 584,
  [643] = 643,
  [644] = 644,
  [645] = 645,
  [646] = 646,
  [647] = 647,
  [648] = 648,
  [649] = 649,
  [650] = 650,
  [651] = 651,
  [652] = 652,
  [653] = 649,
  [654] = 650,
  [655] = 655,
  [656] = 643,
  [657] = 657,
  [658] = 658,
  [659] = 659,
  [660] = 660,
  [661] = 661,
  [662] = 648,
  [663] = 663,
  [664] = 664,
  [665] = 665,
  [666] = 666,
  [667] = 667,
  [668] = 668,
  [669] = 643,
  [670] = 670,
  [671] = 671,
  [672] = 648,
  [673] = 673,
  [674] = 674,
  [675] = 675,
  [676] = 664,
  [677] = 677,
  [678] = 678,
  [679] = 679,
  [680] = 680,
  [681] = 681,
  [682] = 682,
  [683] = 647,
  [684] = 684,
  [685] = 685,
  [686] = 686,
  [687] = 687,
  [688] = 664,
  [689] = 647,
  [690] = 690,
  [691] = 691,
  [692] = 692,
  [693] = 649,
  [694] = 694,
  [695] = 695,
  [696] = 696,
  [697] = 697,
  [698] = 698,
  [699] = 699,
  [700] = 700,
  [701] = 701,
  [702] = 702,
  [703] = 703,
  [704] = 704,
  [705] = 705,
  [706] = 706,
  [707] = 707,
  [708] = 708,
  [709] = 709,
  [710] = 710,
  [711] = 711,
  [712] = 712,
  [713] = 713,
  [714] = 714,
  [715] = 715,
  [716] = 716,
  [717] = 696,
  [718] = 718,
  [719] = 719,
  [720] = 720,
  [721] = 721,
  [722] = 722,
  [723] = 723,
  [724] = 724,
  [725] = 725,
  [726] = 703,
  [727] = 727,
  [728] = 728,
  [729] = 729,
  [730] = 730,
  [731] = 731,
  [732] = 732,
  [733] = 733,
  [734] = 709,
  [735] = 735,
  [736] = 736,
  [737] = 737,
  [738] = 738,
  [739] = 739,
  [740] = 740,
  [741] = 731,
  [742] = 742,
  [743] = 743,
  [744] = 704,
  [745] = 745,
  [746] = 746,
  [747] = 701,
  [748] = 124,
  [749] = 725,
  [750] = 750,
  [751] = 751,
  [752] = 752,
  [753] = 737,
  [754] = 696,
  [755] = 755,
  [756] = 737,
  [757] = 757,
  [758] = 758,
  [759] = 703,
  [760] = 705,
  [761] = 761,
  [762] = 707,
  [763] = 763,
  [764] = 718,
  [765] = 713,
  [766] = 766,
  [767] = 767,
  [768] = 718,
  [769] = 705,
  [770] = 88,
  [771] = 771,
  [772] = 710,
  [773] = 731,
  [774] = 696,
  [775] = 742,
  [776] = 776,
  [777] = 777,
  [778] = 778,
  [779] = 742,
  [780] = 780,
  [781] = 696,
  [782] = 782,
  [783] = 720,
  [784] = 784,
  [785] = 785,
  [786] = 786,
  [787] = 787,
  [788] = 696,
  [789] = 706,
  [790] = 757,
  [791] = 694,
  [792] = 746,
  [793] = 766,
  [794] = 794,
  [795] = 795,
  [796] = 796,
  [797] = 797,
  [798] = 728,
  [799] = 799,
  [800] = 800,
  [801] = 698,
  [802] = 802,
  [803] = 803,
  [804] = 695,
  [805] = 701,
  [806] = 806,
  [807] = 724,
  [808] = 713,
  [809] = 809,
  [810] = 782,
  [811] = 784,
  [812] = 812,
  [813] = 813,
  [814] = 706,
  [815] = 757,
  [816] = 785,
  [817] = 746,
  [818] = 766,
  [819] = 819,
  [820] = 820,
  [821] = 797,
  [822] = 725,
  [823] = 823,
  [824] = 824,
  [825] = 751,
  [826] = 797,
  [827] = 797,
  [828] = 797,
  [829] = 829,
  [830] = 708,
  [831] = 702,
  [832] = 707,
  [833] = 819,
  [834] = 813,
  [835] = 722,
  [836] = 751,
  [837] = 727,
  [838] = 838,
  [839] = 694,
  [840] = 702,
  [841] = 729,
  [842] = 796,
  [843] = 843,
  [844] = 844,
  [845] = 738,
  [846] = 729,
  [847] = 761,
  [848] = 843,
  [849] = 797,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(238);
      ADVANCE_MAP(
        '!', 367,
        '"', 322,
        '#', 259,
        '%', 246,
        '&', 378,
        '\'', 439,
        '(', 602,
        ')', 265,
        '*', 277,
        '+', 338,
        ',', 273,
        '-', 343,
        '.', 361,
        '/', 370,
        ':', 392,
        ';', 271,
        '<', 385,
        '=', 275,
        '>', 381,
        '?', 391,
        'F', 50,
        'L', 19,
        'N', 60,
        'T', 56,
        'U', 21,
        '[', 329,
        '\\', 58,
        ']', 330,
        '^', 376,
        'a', 192,
        'b', 182,
        'c', 116,
        'd', 85,
        'e', 137,
        'f', 67,
        'i', 103,
        'l', 170,
        'm', 174,
        'o', 180,
        'p', 188,
        's', 119,
        't', 168,
        'u', 22,
        'v', 171,
        'w', 118,
        '{', 328,
        '|', 373,
        '}', 244,
        '~', 368,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(236);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(262);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '\n', 257,
        '!', 46,
        '"', 322,
        '%', 245,
        '&', 377,
        '(', 264,
        '*', 276,
        '+', 335,
        '-', 340,
        '/', 369,
        '<', 386,
        '=', 47,
        '>', 382,
        'L', 18,
        'U', 20,
        '^', 375,
        'u', 23,
        '|', 374,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1);
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(17);
      if (lookahead == '"') ADVANCE(322);
      if (lookahead == '/') ADVANCE(323);
      if (lookahead == '\\') ADVANCE(58);
      if (lookahead == '{') ADVANCE(328);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(326);
      if (lookahead != 0) ADVANCE(327);
      END_STATE();
    case 3:
      if (lookahead == '\n') SKIP(17);
      if (lookahead == '"') ADVANCE(322);
      if (lookahead == '/') ADVANCE(415);
      if (lookahead == '\\') ADVANCE(58);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(418);
      if (lookahead != 0) ADVANCE(419);
      END_STATE();
    case 4:
      if (lookahead == '\n') ADVANCE(258);
      if (lookahead == '(') ADVANCE(602);
      if (lookahead == '/') ADVANCE(642);
      if (lookahead == '\\') ADVANCE(639);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(638);
      if (lookahead != 0) ADVANCE(644);
      END_STATE();
    case 5:
      if (lookahead == '\n') ADVANCE(258);
      if (lookahead == '/') ADVANCE(642);
      if (lookahead == '\\') ADVANCE(639);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(638);
      if (lookahead != 0) ADVANCE(644);
      END_STATE();
    case 6:
      if (lookahead == '\n') SKIP(40);
      if (lookahead == '/') ADVANCE(441);
      if (lookahead == '\\') ADVANCE(442);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(443);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(440);
      END_STATE();
    case 7:
      if (lookahead == '\r') ADVANCE(651);
      if (lookahead != 0) ADVANCE(650);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 367,
        '"', 322,
        '%', 246,
        '&', 378,
        '\'', 439,
        '(', 264,
        ')', 265,
        '*', 277,
        '+', 336,
        ',', 273,
        '-', 341,
        '.', 362,
        '/', 370,
        '0', 424,
        ':', 392,
        ';', 271,
        '<', 385,
        '=', 275,
        '>', 381,
        '?', 391,
        'F', 464,
        'L', 446,
        'N', 473,
        'T', 470,
        'U', 448,
        '[', 329,
        ']', 330,
        '^', 376,
        'e', 593,
        'f', 483,
        's', 522,
        't', 570,
        'u', 451,
        '{', 272,
        '|', 373,
        '}', 243,
        '~', 368,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '!', 366,
        '"', 322,
        '#', 101,
        '%', 28,
        '\'', 439,
        '(', 264,
        '+', 337,
        '-', 342,
        '.', 223,
        '/', 31,
        '0', 424,
        'F', 464,
        'L', 446,
        'N', 473,
        'T', 470,
        'U', 448,
        'b', 565,
        'c', 516,
        'd', 555,
        'e', 544,
        'f', 480,
        'i', 507,
        'l', 557,
        's', 520,
        't', 569,
        'u', 450,
        'v', 559,
        'w', 519,
        '{', 272,
        '}', 243,
        '~', 368,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '!', 366,
        '"', 322,
        '%', 28,
        '\'', 439,
        '(', 264,
        '+', 337,
        '-', 342,
        '.', 223,
        '/', 31,
        '0', 424,
        'F', 464,
        'L', 446,
        'N', 473,
        'T', 470,
        'U', 448,
        'b', 565,
        'c', 554,
        'e', 593,
        'f', 482,
        'i', 508,
        's', 522,
        't', 570,
        'u', 451,
        'w', 519,
        '{', 272,
        '}', 243,
        '~', 368,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '!', 366,
        '"', 322,
        '%', 28,
        '\'', 439,
        '(', 264,
        '+', 337,
        '-', 342,
        '.', 223,
        '/', 31,
        '0', 424,
        'F', 464,
        'L', 446,
        'N', 473,
        'T', 470,
        'U', 448,
        'b', 565,
        'c', 554,
        'e', 538,
        'f', 482,
        'i', 508,
        's', 522,
        't', 570,
        'u', 451,
        'w', 519,
        '{', 272,
        '}', 243,
        '~', 368,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '!', 366,
        '"', 322,
        '\'', 439,
        '(', 264,
        '+', 337,
        '-', 342,
        '.', 223,
        '/', 31,
        '0', 424,
        'F', 464,
        'L', 446,
        'N', 473,
        'T', 470,
        'U', 448,
        'c', 518,
        'd', 555,
        'e', 544,
        'f', 481,
        'i', 541,
        'l', 557,
        's', 520,
        't', 569,
        'u', 450,
        'v', 559,
        '~', 368,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '!', 366,
        '\'', 439,
        '(', 264,
        ')', 265,
        '+', 339,
        '-', 344,
        '.', 223,
        '/', 31,
        '0', 424,
        'L', 455,
        'U', 456,
        'd', 505,
        'u', 457,
        '~', 368,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(13);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '!', 46,
        '%', 246,
        '&', 378,
        '(', 264,
        ')', 265,
        '*', 277,
        '+', 338,
        ',', 273,
        '-', 343,
        '.', 360,
        '/', 370,
        ':', 392,
        ';', 271,
        '<', 385,
        '=', 275,
        '>', 381,
        '?', 391,
        '[', 329,
        ']', 330,
        '^', 376,
        'c', 517,
        'd', 555,
        'e', 545,
        'f', 534,
        'i', 541,
        'l', 557,
        's', 521,
        't', 594,
        'u', 529,
        'v', 559,
        '|', 373,
        '}', 243,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '!', 46,
        '%', 245,
        '&', 377,
        '(', 264,
        ')', 265,
        '*', 276,
        '+', 335,
        ',', 273,
        '-', 340,
        '/', 369,
        ';', 271,
        '<', 386,
        '=', 47,
        '>', 382,
        '[', 329,
        '^', 375,
        'c', 563,
        '{', 272,
        '|', 374,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 16:
      if (lookahead == '"') ADVANCE(322);
      if (lookahead == '/') ADVANCE(31);
      if (lookahead == '<') ADVANCE(48);
      if (lookahead == 'L') ADVANCE(447);
      if (lookahead == 'U') ADVANCE(449);
      if (lookahead == 'u') ADVANCE(452);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 17:
      if (lookahead == '"') ADVANCE(322);
      if (lookahead == '/') ADVANCE(31);
      if (lookahead == '\\') ADVANCE(58);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(17);
      END_STATE();
    case 18:
      if (lookahead == '"') ADVANCE(411);
      END_STATE();
    case 19:
      if (lookahead == '"') ADVANCE(411);
      if (lookahead == '\'') ADVANCE(435);
      END_STATE();
    case 20:
      if (lookahead == '"') ADVANCE(413);
      END_STATE();
    case 21:
      if (lookahead == '"') ADVANCE(413);
      if (lookahead == '\'') ADVANCE(437);
      END_STATE();
    case 22:
      if (lookahead == '"') ADVANCE(412);
      if (lookahead == '\'') ADVANCE(436);
      if (lookahead == '8') ADVANCE(25);
      if (lookahead == 'i') ADVANCE(160);
      if (lookahead == 'n') ADVANCE(133);
      END_STATE();
    case 23:
      if (lookahead == '"') ADVANCE(412);
      if (lookahead == '8') ADVANCE(24);
      END_STATE();
    case 24:
      if (lookahead == '"') ADVANCE(414);
      END_STATE();
    case 25:
      if (lookahead == '"') ADVANCE(414);
      if (lookahead == '\'') ADVANCE(438);
      END_STATE();
    case 26:
      ADVANCE_MAP(
        '#', 259,
        '%', 28,
        '+', 335,
        '-', 340,
        '/', 31,
        'c', 115,
        'd', 167,
        'e', 157,
        'f', 138,
        'i', 148,
        'l', 170,
        'p', 188,
        's', 121,
        't', 220,
        'u', 127,
        'v', 171,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(26);
      END_STATE();
    case 27:
      ADVANCE_MAP(
        '#', 260,
        '%', 28,
        '/', 31,
        'c', 115,
        'd', 167,
        'e', 157,
        'f', 138,
        'i', 148,
        'l', 170,
        'p', 188,
        's', 121,
        't', 220,
        'u', 127,
        'v', 171,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(27);
      END_STATE();
    case 28:
      if (lookahead == '%') ADVANCE(248);
      if (lookahead == '{') ADVANCE(239);
      END_STATE();
    case 29:
      if (lookahead == '%') ADVANCE(245);
      if (lookahead == '/') ADVANCE(241);
      if (lookahead == '}') ADVANCE(244);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(242);
      if (lookahead != 0) ADVANCE(240);
      END_STATE();
    case 30:
      if (lookahead == '(') ADVANCE(264);
      if (lookahead == ')') ADVANCE(265);
      if (lookahead == '.') ADVANCE(34);
      if (lookahead == '/') ADVANCE(31);
      if (lookahead == ';') ADVANCE(271);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(30);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 31:
      if (lookahead == '*') ADVANCE(33);
      if (lookahead == '/') ADVANCE(650);
      END_STATE();
    case 32:
      if (lookahead == '*') ADVANCE(32);
      if (lookahead == '/') ADVANCE(648);
      if (lookahead != 0) ADVANCE(33);
      END_STATE();
    case 33:
      if (lookahead == '*') ADVANCE(32);
      if (lookahead != 0) ADVANCE(33);
      END_STATE();
    case 34:
      if (lookahead == '.') ADVANCE(35);
      END_STATE();
    case 35:
      if (lookahead == '.') ADVANCE(603);
      END_STATE();
    case 36:
      ADVANCE_MAP(
        '.', 223,
        '/', 31,
        '0', 424,
        ';', 271,
        '[', 329,
        't', 556,
        '+', 37,
        '-', 37,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(36);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 37:
      if (lookahead == '.') ADVANCE(223);
      if (lookahead == '0') ADVANCE(424);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      END_STATE();
    case 38:
      if (lookahead == '.') ADVANCE(223);
      if (lookahead == '0') ADVANCE(421);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(422);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(431);
      END_STATE();
    case 39:
      if (lookahead == '.') ADVANCE(223);
      if (lookahead == '0') ADVANCE(423);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      END_STATE();
    case 40:
      if (lookahead == '/') ADVANCE(31);
      if (lookahead == '\\') ADVANCE(58);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(40);
      END_STATE();
    case 41:
      if (lookahead == '1') ADVANCE(45);
      if (lookahead == '3') ADVANCE(43);
      if (lookahead == '8') ADVANCE(64);
      END_STATE();
    case 42:
      if (lookahead == '2') ADVANCE(63);
      END_STATE();
    case 43:
      if (lookahead == '2') ADVANCE(66);
      END_STATE();
    case 44:
      if (lookahead == '6') ADVANCE(62);
      END_STATE();
    case 45:
      if (lookahead == '6') ADVANCE(65);
      END_STATE();
    case 46:
      if (lookahead == '=') ADVANCE(380);
      END_STATE();
    case 47:
      if (lookahead == '=') ADVANCE(379);
      END_STATE();
    case 48:
      if (lookahead == '>') ADVANCE(444);
      if (lookahead == '\\') ADVANCE(49);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(48);
      END_STATE();
    case 49:
      if (lookahead == '>') ADVANCE(445);
      if (lookahead == '\\') ADVANCE(49);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(48);
      END_STATE();
    case 50:
      if (lookahead == 'A') ADVANCE(53);
      END_STATE();
    case 51:
      if (lookahead == 'E') ADVANCE(405);
      END_STATE();
    case 52:
      if (lookahead == 'E') ADVANCE(407);
      END_STATE();
    case 53:
      if (lookahead == 'L') ADVANCE(57);
      END_STATE();
    case 54:
      if (lookahead == 'L') ADVANCE(409);
      END_STATE();
    case 55:
      if (lookahead == 'L') ADVANCE(54);
      END_STATE();
    case 56:
      if (lookahead == 'R') ADVANCE(59);
      END_STATE();
    case 57:
      if (lookahead == 'S') ADVANCE(52);
      END_STATE();
    case 58:
      if (lookahead == 'U') ADVANCE(235);
      if (lookahead == 'u') ADVANCE(231);
      if (lookahead == 'x') ADVANCE(229);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(599);
      if (lookahead != 0) ADVANCE(597);
      END_STATE();
    case 59:
      if (lookahead == 'U') ADVANCE(51);
      END_STATE();
    case 60:
      if (lookahead == 'U') ADVANCE(55);
      END_STATE();
    case 61:
      if (lookahead == '_') ADVANCE(204);
      END_STATE();
    case 62:
      if (lookahead == '_') ADVANCE(206);
      END_STATE();
    case 63:
      if (lookahead == '_') ADVANCE(207);
      END_STATE();
    case 64:
      if (lookahead == '_') ADVANCE(208);
      END_STATE();
    case 65:
      if (lookahead == '_') ADVANCE(209);
      END_STATE();
    case 66:
      if (lookahead == '_') ADVANCE(210);
      END_STATE();
    case 67:
      if (lookahead == 'a') ADVANCE(140);
      if (lookahead == 'l') ADVANCE(173);
      if (lookahead == 'o') ADVANCE(183);
      END_STATE();
    case 68:
      if (lookahead == 'a') ADVANCE(136);
      END_STATE();
    case 69:
      if (lookahead == 'a') ADVANCE(145);
      END_STATE();
    case 70:
      if (lookahead == 'a') ADVANCE(146);
      END_STATE();
    case 71:
      if (lookahead == 'a') ADVANCE(185);
      END_STATE();
    case 72:
      if (lookahead == 'a') ADVANCE(213);
      if (lookahead == 'r') ADVANCE(129);
      END_STATE();
    case 73:
      if (lookahead == 'a') ADVANCE(109);
      END_STATE();
    case 74:
      if (lookahead == 'a') ADVANCE(202);
      END_STATE();
    case 75:
      if (lookahead == 'b') ADVANCE(143);
      END_STATE();
    case 76:
      if (lookahead == 'c') ADVANCE(332);
      END_STATE();
    case 77:
      if (lookahead == 'c') ADVANCE(205);
      END_STATE();
    case 78:
      if (lookahead == 'd') ADVANCE(615);
      if (lookahead == 'e') ADVANCE(630);
      if (lookahead == 'i') ADVANCE(621);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(78);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 79:
      if (lookahead == 'd') ADVANCE(615);
      if (lookahead == 'e') ADVANCE(632);
      if (lookahead == 'i') ADVANCE(621);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 80:
      if (lookahead == 'd') ADVANCE(615);
      if (lookahead == 'i') ADVANCE(621);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(80);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 81:
      if (lookahead == 'd') ADVANCE(287);
      END_STATE();
    case 82:
      if (lookahead == 'd') ADVANCE(646);
      END_STATE();
    case 83:
      if (lookahead == 'd') ADVANCE(297);
      END_STATE();
    case 84:
      if (lookahead == 'd') ADVANCE(126);
      END_STATE();
    case 85:
      if (lookahead == 'e') ADVANCE(107);
      if (lookahead == 'o') ADVANCE(215);
      END_STATE();
    case 86:
      if (lookahead == 'e') ADVANCE(405);
      END_STATE();
    case 87:
      if (lookahead == 'e') ADVANCE(354);
      END_STATE();
    case 88:
      if (lookahead == 'e') ADVANCE(407);
      END_STATE();
    case 89:
      if (lookahead == 'e') ADVANCE(346);
      END_STATE();
    case 90:
      if (lookahead == 'e') ADVANCE(356);
      END_STATE();
    case 91:
      if (lookahead == 'e') ADVANCE(313);
      END_STATE();
    case 92:
      if (lookahead == 'e') ADVANCE(350);
      END_STATE();
    case 93:
      if (lookahead == 'e') ADVANCE(285);
      END_STATE();
    case 94:
      if (lookahead == 'e') ADVANCE(68);
      END_STATE();
    case 95:
      if (lookahead == 'e') ADVANCE(82);
      END_STATE();
    case 96:
      if (lookahead == 'e') ADVANCE(83);
      END_STATE();
    case 97:
      if (lookahead == 'e') ADVANCE(175);
      END_STATE();
    case 98:
      if (lookahead == 'e') ADVANCE(152);
      END_STATE();
    case 99:
      if (lookahead == 'e') ADVANCE(152);
      if (lookahead == 'i') ADVANCE(142);
      END_STATE();
    case 100:
      if (lookahead == 'e') ADVANCE(162);
      END_STATE();
    case 101:
      if (lookahead == 'e') ADVANCE(158);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(101);
      END_STATE();
    case 102:
      if (lookahead == 'e') ADVANCE(134);
      END_STATE();
    case 103:
      if (lookahead == 'f') ADVANCE(352);
      if (lookahead == 'n') ADVANCE(198);
      END_STATE();
    case 104:
      if (lookahead == 'f') ADVANCE(403);
      END_STATE();
    case 105:
      if (lookahead == 'f') ADVANCE(605);
      END_STATE();
    case 106:
      if (lookahead == 'f') ADVANCE(141);
      END_STATE();
    case 107:
      if (lookahead == 'f') ADVANCE(128);
      END_STATE();
    case 108:
      if (lookahead == 'g') ADVANCE(295);
      END_STATE();
    case 109:
      if (lookahead == 'g') ADVANCE(279);
      END_STATE();
    case 110:
      if (lookahead == 'g') ADVANCE(315);
      END_STATE();
    case 111:
      if (lookahead == 'g') ADVANCE(189);
      END_STATE();
    case 112:
      if (lookahead == 'g') ADVANCE(154);
      END_STATE();
    case 113:
      if (lookahead == 'g') ADVANCE(156);
      END_STATE();
    case 114:
      if (lookahead == 'g') ADVANCE(164);
      END_STATE();
    case 115:
      if (lookahead == 'h') ADVANCE(71);
      END_STATE();
    case 116:
      if (lookahead == 'h') ADVANCE(71);
      if (lookahead == 'o') ADVANCE(149);
      END_STATE();
    case 117:
      if (lookahead == 'h') ADVANCE(71);
      if (lookahead == 'o') ADVANCE(159);
      END_STATE();
    case 118:
      if (lookahead == 'h') ADVANCE(99);
      END_STATE();
    case 119:
      if (lookahead == 'h') ADVANCE(176);
      if (lookahead == 'i') ADVANCE(221);
      if (lookahead == 's') ADVANCE(345);
      if (lookahead == 't') ADVANCE(72);
      if (lookahead == 'y') ADVANCE(151);
      END_STATE();
    case 120:
      if (lookahead == 'h') ADVANCE(176);
      if (lookahead == 's') ADVANCE(345);
      if (lookahead == 't') ADVANCE(72);
      if (lookahead == 'y') ADVANCE(151);
      END_STATE();
    case 121:
      if (lookahead == 'h') ADVANCE(176);
      if (lookahead == 's') ADVANCE(345);
      if (lookahead == 't') ADVANCE(184);
      END_STATE();
    case 122:
      if (lookahead == 'h') ADVANCE(98);
      END_STATE();
    case 123:
      if (lookahead == 'i') ADVANCE(81);
      END_STATE();
    case 124:
      if (lookahead == 'i') ADVANCE(199);
      END_STATE();
    case 125:
      if (lookahead == 'i') ADVANCE(112);
      END_STATE();
    case 126:
      if (lookahead == 'i') ADVANCE(105);
      END_STATE();
    case 127:
      if (lookahead == 'i') ADVANCE(160);
      if (lookahead == 'n') ADVANCE(133);
      END_STATE();
    case 128:
      if (lookahead == 'i') ADVANCE(163);
      END_STATE();
    case 129:
      if (lookahead == 'i') ADVANCE(161);
      if (lookahead == 'u') ADVANCE(77);
      END_STATE();
    case 130:
      if (lookahead == 'i') ADVANCE(214);
      END_STATE();
    case 131:
      if (lookahead == 'i') ADVANCE(166);
      END_STATE();
    case 132:
      if (lookahead == 'i') ADVANCE(114);
      END_STATE();
    case 133:
      if (lookahead == 'i') ADVANCE(178);
      if (lookahead == 's') ADVANCE(132);
      END_STATE();
    case 134:
      if (lookahead == 'i') ADVANCE(113);
      END_STATE();
    case 135:
      if (lookahead == 'i') ADVANCE(179);
      END_STATE();
    case 136:
      if (lookahead == 'k') ADVANCE(348);
      END_STATE();
    case 137:
      if (lookahead == 'l') ADVANCE(193);
      if (lookahead == 'n') ADVANCE(211);
      if (lookahead == 'v') ADVANCE(106);
      if (lookahead == 'x') ADVANCE(124);
      END_STATE();
    case 138:
      if (lookahead == 'l') ADVANCE(173);
      END_STATE();
    case 139:
      if (lookahead == 'l') ADVANCE(173);
      if (lookahead == 'o') ADVANCE(191);
      END_STATE();
    case 140:
      if (lookahead == 'l') ADVANCE(195);
      END_STATE();
    case 141:
      if (lookahead == 'l') ADVANCE(73);
      END_STATE();
    case 142:
      if (lookahead == 'l') ADVANCE(90);
      END_STATE();
    case 143:
      if (lookahead == 'l') ADVANCE(91);
      END_STATE();
    case 144:
      if (lookahead == 'm') ADVANCE(281);
      END_STATE();
    case 145:
      if (lookahead == 'm') ADVANCE(263);
      END_STATE();
    case 146:
      if (lookahead == 'm') ADVANCE(93);
      END_STATE();
    case 147:
      if (lookahead == 'n') ADVANCE(211);
      if (lookahead == 'v') ADVANCE(106);
      if (lookahead == 'x') ADVANCE(124);
      END_STATE();
    case 148:
      if (lookahead == 'n') ADVANCE(198);
      END_STATE();
    case 149:
      if (lookahead == 'n') ADVANCE(197);
      END_STATE();
    case 150:
      if (lookahead == 'n') ADVANCE(108);
      END_STATE();
    case 151:
      if (lookahead == 'n') ADVANCE(76);
      END_STATE();
    case 152:
      if (lookahead == 'n') ADVANCE(347);
      END_STATE();
    case 153:
      if (lookahead == 'n') ADVANCE(283);
      END_STATE();
    case 154:
      if (lookahead == 'n') ADVANCE(319);
      END_STATE();
    case 155:
      if (lookahead == 'n') ADVANCE(334);
      END_STATE();
    case 156:
      if (lookahead == 'n') ADVANCE(278);
      END_STATE();
    case 157:
      if (lookahead == 'n') ADVANCE(216);
      if (lookahead == 'v') ADVANCE(106);
      if (lookahead == 'x') ADVANCE(124);
      END_STATE();
    case 158:
      if (lookahead == 'n') ADVANCE(84);
      END_STATE();
    case 159:
      if (lookahead == 'n') ADVANCE(196);
      END_STATE();
    case 160:
      if (lookahead == 'n') ADVANCE(200);
      END_STATE();
    case 161:
      if (lookahead == 'n') ADVANCE(110);
      END_STATE();
    case 162:
      if (lookahead == 'n') ADVANCE(70);
      END_STATE();
    case 163:
      if (lookahead == 'n') ADVANCE(95);
      END_STATE();
    case 164:
      if (lookahead == 'n') ADVANCE(96);
      END_STATE();
    case 165:
      if (lookahead == 'n') ADVANCE(130);
      END_STATE();
    case 166:
      if (lookahead == 'n') ADVANCE(218);
      END_STATE();
    case 167:
      if (lookahead == 'o') ADVANCE(215);
      END_STATE();
    case 168:
      if (lookahead == 'o') ADVANCE(320);
      if (lookahead == 'r') ADVANCE(217);
      if (lookahead == 'y') ADVANCE(181);
      END_STATE();
    case 169:
      if (lookahead == 'o') ADVANCE(320);
      if (lookahead == 'y') ADVANCE(181);
      END_STATE();
    case 170:
      if (lookahead == 'o') ADVANCE(150);
      END_STATE();
    case 171:
      if (lookahead == 'o') ADVANCE(123);
      END_STATE();
    case 172:
      if (lookahead == 'o') ADVANCE(111);
      END_STATE();
    case 173:
      if (lookahead == 'o') ADVANCE(74);
      END_STATE();
    case 174:
      if (lookahead == 'o') ADVANCE(165);
      END_STATE();
    case 175:
      if (lookahead == 'o') ADVANCE(104);
      END_STATE();
    case 176:
      if (lookahead == 'o') ADVANCE(190);
      END_STATE();
    case 177:
      if (lookahead == 'o') ADVANCE(187);
      END_STATE();
    case 178:
      if (lookahead == 'o') ADVANCE(153);
      END_STATE();
    case 179:
      if (lookahead == 'o') ADVANCE(155);
      END_STATE();
    case 180:
      if (lookahead == 'p') ADVANCE(212);
      END_STATE();
    case 181:
      if (lookahead == 'p') ADVANCE(100);
      END_STATE();
    case 182:
      if (lookahead == 'r') ADVANCE(94);
      END_STATE();
    case 183:
      if (lookahead == 'r') ADVANCE(358);
      END_STATE();
    case 184:
      if (lookahead == 'r') ADVANCE(129);
      END_STATE();
    case 185:
      if (lookahead == 'r') ADVANCE(289);
      END_STATE();
    case 186:
      if (lookahead == 'r') ADVANCE(219);
      END_STATE();
    case 187:
      if (lookahead == 'r') ADVANCE(331);
      END_STATE();
    case 188:
      if (lookahead == 'r') ADVANCE(172);
      END_STATE();
    case 189:
      if (lookahead == 'r') ADVANCE(69);
      END_STATE();
    case 190:
      if (lookahead == 'r') ADVANCE(203);
      END_STATE();
    case 191:
      if (lookahead == 'r') ADVANCE(102);
      END_STATE();
    case 192:
      if (lookahead == 's') ADVANCE(194);
      END_STATE();
    case 193:
      if (lookahead == 's') ADVANCE(87);
      END_STATE();
    case 194:
      if (lookahead == 's') ADVANCE(125);
      END_STATE();
    case 195:
      if (lookahead == 's') ADVANCE(88);
      END_STATE();
    case 196:
      if (lookahead == 's') ADVANCE(201);
      END_STATE();
    case 197:
      if (lookahead == 's') ADVANCE(201);
      if (lookahead == 't') ADVANCE(131);
      END_STATE();
    case 198:
      if (lookahead == 't') ADVANCE(293);
      END_STATE();
    case 199:
      if (lookahead == 't') ADVANCE(267);
      END_STATE();
    case 200:
      if (lookahead == 't') ADVANCE(41);
      END_STATE();
    case 201:
      if (lookahead == 't') ADVANCE(317);
      END_STATE();
    case 202:
      if (lookahead == 't') ADVANCE(311);
      END_STATE();
    case 203:
      if (lookahead == 't') ADVANCE(291);
      END_STATE();
    case 204:
      if (lookahead == 't') ADVANCE(299);
      END_STATE();
    case 205:
      if (lookahead == 't') ADVANCE(269);
      END_STATE();
    case 206:
      if (lookahead == 't') ADVANCE(303);
      END_STATE();
    case 207:
      if (lookahead == 't') ADVANCE(307);
      END_STATE();
    case 208:
      if (lookahead == 't') ADVANCE(301);
      END_STATE();
    case 209:
      if (lookahead == 't') ADVANCE(305);
      END_STATE();
    case 210:
      if (lookahead == 't') ADVANCE(309);
      END_STATE();
    case 211:
      if (lookahead == 't') ADVANCE(186);
      if (lookahead == 'u') ADVANCE(144);
      END_STATE();
    case 212:
      if (lookahead == 't') ADVANCE(135);
      END_STATE();
    case 213:
      if (lookahead == 't') ADVANCE(89);
      END_STATE();
    case 214:
      if (lookahead == 't') ADVANCE(177);
      END_STATE();
    case 215:
      if (lookahead == 'u') ADVANCE(75);
      END_STATE();
    case 216:
      if (lookahead == 'u') ADVANCE(144);
      END_STATE();
    case 217:
      if (lookahead == 'u') ADVANCE(86);
      END_STATE();
    case 218:
      if (lookahead == 'u') ADVANCE(92);
      END_STATE();
    case 219:
      if (lookahead == 'y') ADVANCE(266);
      END_STATE();
    case 220:
      if (lookahead == 'y') ADVANCE(181);
      END_STATE();
    case 221:
      if (lookahead == 'z') ADVANCE(97);
      END_STATE();
    case 222:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(425);
      END_STATE();
    case 223:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(420);
      END_STATE();
    case 224:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(422);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(431);
      END_STATE();
    case 225:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(597);
      END_STATE();
    case 226:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(428);
      END_STATE();
    case 227:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(431);
      END_STATE();
    case 228:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(426);
      END_STATE();
    case 229:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(225);
      END_STATE();
    case 230:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(229);
      END_STATE();
    case 231:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(230);
      END_STATE();
    case 232:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(231);
      END_STATE();
    case 233:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(232);
      END_STATE();
    case 234:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(233);
      END_STATE();
    case 235:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(234);
      END_STATE();
    case 236:
      if (eof) ADVANCE(238);
      ADVANCE_MAP(
        '!', 367,
        '"', 322,
        '#', 259,
        '%', 246,
        '&', 378,
        '\'', 439,
        '(', 264,
        ')', 265,
        '*', 277,
        '+', 338,
        ',', 273,
        '-', 343,
        '.', 361,
        '/', 370,
        ':', 392,
        ';', 271,
        '<', 385,
        '=', 275,
        '>', 381,
        '?', 391,
        'F', 50,
        'L', 19,
        'N', 60,
        'T', 56,
        'U', 21,
        '[', 329,
        '\\', 58,
        ']', 330,
        '^', 376,
        'a', 192,
        'b', 182,
        'c', 116,
        'd', 85,
        'e', 137,
        'f', 67,
        'i', 103,
        'l', 170,
        'm', 174,
        'o', 180,
        'p', 188,
        's', 119,
        't', 168,
        'u', 22,
        'v', 171,
        'w', 118,
        '{', 272,
        '|', 373,
        '}', 244,
        '~', 368,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(236);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(262);
      END_STATE();
    case 237:
      if (eof) ADVANCE(238);
      ADVANCE_MAP(
        '"', 322,
        '#', 261,
        '%', 28,
        '(', 264,
        ')', 265,
        '*', 276,
        ',', 273,
        '.', 223,
        '/', 31,
        '0', 424,
        ';', 271,
        '=', 274,
        '[', 329,
        'a', 192,
        'c', 117,
        'd', 167,
        'e', 147,
        'f', 139,
        'i', 148,
        'l', 170,
        'm', 174,
        'o', 180,
        'p', 188,
        's', 120,
        't', 169,
        'u', 127,
        'v', 171,
        'w', 122,
        '{', 272,
        '}', 243,
        '+', 37,
        '-', 37,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(237);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(anon_sym_PERCENT_LBRACE);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(aux_sym__c_code_token1);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(aux_sym__c_code_token1);
      if (lookahead == '*') ADVANCE(33);
      if (lookahead == '/') ADVANCE(650);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(aux_sym__c_code_token1);
      if (lookahead == '/') ADVANCE(241);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(242);
      if (lookahead != 0 &&
          lookahead != '%' &&
          lookahead != '}') ADVANCE(240);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      if (lookahead == '%') ADVANCE(247);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(395);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(anon_sym_RBRACE_PERCENT);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(anon_sym_PERCENT_PERCENT);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead == '\n') ADVANCE(33);
      if (lookahead == '*') ADVANCE(249);
      if (lookahead == '/') ADVANCE(256);
      if (lookahead != 0) ADVANCE(250);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead == '\n') ADVANCE(33);
      if (lookahead == '*') ADVANCE(249);
      if (lookahead != 0) ADVANCE(250);
      END_STATE();
    case 251:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead == '\n') ADVANCE(650);
      if (lookahead == '\r') ADVANCE(252);
      if (lookahead != 0) ADVANCE(255);
      END_STATE();
    case 252:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead == '\n') ADVANCE(650);
      if (lookahead == '\\') ADVANCE(251);
      if (lookahead != 0) ADVANCE(255);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead == '*') ADVANCE(250);
      if (lookahead == '/') ADVANCE(255);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(256);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead == '/') ADVANCE(253);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(254);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(256);
      END_STATE();
    case 255:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead == '\\') ADVANCE(251);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(255);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(256);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(257);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(258);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(638);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == 'd') ADVANCE(615);
      if (lookahead == 'e') ADVANCE(630);
      if (lookahead == 'i') ADVANCE(621);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(78);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 260:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == 'd') ADVANCE(615);
      if (lookahead == 'e') ADVANCE(632);
      if (lookahead == 'i') ADVANCE(621);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 261:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == 'd') ADVANCE(615);
      if (lookahead == 'i') ADVANCE(621);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(80);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(sym_line_number);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(262);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(anon_sym_program);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(anon_sym_entry);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(anon_sym_exit);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(anon_sym_exit);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(anon_sym_struct);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 275:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(379);
      END_STATE();
    case 276:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 277:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(393);
      END_STATE();
    case 278:
      ACCEPT_TOKEN(anon_sym_foreign);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(anon_sym_evflag);
      END_STATE();
    case 280:
      ACCEPT_TOKEN(anon_sym_evflag);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 281:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 282:
      ACCEPT_TOKEN(anon_sym_enum);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 283:
      ACCEPT_TOKEN(anon_sym_union);
      END_STATE();
    case 284:
      ACCEPT_TOKEN(anon_sym_union);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 285:
      ACCEPT_TOKEN(anon_sym_typename);
      END_STATE();
    case 286:
      ACCEPT_TOKEN(anon_sym_typename);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 287:
      ACCEPT_TOKEN(anon_sym_void);
      END_STATE();
    case 288:
      ACCEPT_TOKEN(anon_sym_void);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 289:
      ACCEPT_TOKEN(anon_sym_char);
      END_STATE();
    case 290:
      ACCEPT_TOKEN(anon_sym_char);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 291:
      ACCEPT_TOKEN(anon_sym_short);
      END_STATE();
    case 292:
      ACCEPT_TOKEN(anon_sym_short);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 293:
      ACCEPT_TOKEN(anon_sym_int);
      if (lookahead == '1') ADVANCE(44);
      if (lookahead == '3') ADVANCE(42);
      if (lookahead == '8') ADVANCE(61);
      END_STATE();
    case 294:
      ACCEPT_TOKEN(anon_sym_int);
      if (lookahead == '1') ADVANCE(462);
      if (lookahead == '3') ADVANCE(460);
      if (lookahead == '8') ADVANCE(474);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 295:
      ACCEPT_TOKEN(anon_sym_long);
      END_STATE();
    case 296:
      ACCEPT_TOKEN(anon_sym_long);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 297:
      ACCEPT_TOKEN(anon_sym_unsigned);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(anon_sym_unsigned);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 299:
      ACCEPT_TOKEN(anon_sym_int8_t);
      END_STATE();
    case 300:
      ACCEPT_TOKEN(anon_sym_int8_t);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 301:
      ACCEPT_TOKEN(anon_sym_uint8_t);
      END_STATE();
    case 302:
      ACCEPT_TOKEN(anon_sym_uint8_t);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 303:
      ACCEPT_TOKEN(anon_sym_int16_t);
      END_STATE();
    case 304:
      ACCEPT_TOKEN(anon_sym_int16_t);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 305:
      ACCEPT_TOKEN(anon_sym_uint16_t);
      END_STATE();
    case 306:
      ACCEPT_TOKEN(anon_sym_uint16_t);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 307:
      ACCEPT_TOKEN(anon_sym_int32_t);
      END_STATE();
    case 308:
      ACCEPT_TOKEN(anon_sym_int32_t);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 309:
      ACCEPT_TOKEN(anon_sym_uint32_t);
      END_STATE();
    case 310:
      ACCEPT_TOKEN(anon_sym_uint32_t);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 311:
      ACCEPT_TOKEN(anon_sym_float);
      END_STATE();
    case 312:
      ACCEPT_TOKEN(anon_sym_float);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 313:
      ACCEPT_TOKEN(anon_sym_double);
      END_STATE();
    case 314:
      ACCEPT_TOKEN(anon_sym_double);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 315:
      ACCEPT_TOKEN(anon_sym_string);
      END_STATE();
    case 316:
      ACCEPT_TOKEN(anon_sym_string);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 317:
      ACCEPT_TOKEN(anon_sym_const);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(anon_sym_const);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 319:
      ACCEPT_TOKEN(anon_sym_assign);
      END_STATE();
    case 320:
      ACCEPT_TOKEN(anon_sym_to);
      END_STATE();
    case 321:
      ACCEPT_TOKEN(anon_sym_to);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 322:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(aux_sym__expanded_string_literal_token1);
      if (lookahead == '*') ADVANCE(325);
      if (lookahead == '/') ADVANCE(327);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\' &&
          lookahead != '{') ADVANCE(327);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(aux_sym__expanded_string_literal_token1);
      if (lookahead == '*') ADVANCE(324);
      if (lookahead == '/') ADVANCE(327);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\' &&
          lookahead != '{') ADVANCE(325);
      END_STATE();
    case 325:
      ACCEPT_TOKEN(aux_sym__expanded_string_literal_token1);
      if (lookahead == '*') ADVANCE(324);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\' &&
          lookahead != '{') ADVANCE(325);
      END_STATE();
    case 326:
      ACCEPT_TOKEN(aux_sym__expanded_string_literal_token1);
      if (lookahead == '/') ADVANCE(323);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(326);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '"' &&
          lookahead != '\\' &&
          lookahead != '{') ADVANCE(327);
      END_STATE();
    case 327:
      ACCEPT_TOKEN(aux_sym__expanded_string_literal_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\' &&
          lookahead != '{') ADVANCE(327);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(anon_sym_LBRACE2);
      END_STATE();
    case 329:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 330:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 331:
      ACCEPT_TOKEN(anon_sym_monitor);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(anon_sym_sync);
      if (lookahead == 'q') ADVANCE(333);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(anon_sym_syncq);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(anon_sym_option);
      END_STATE();
    case 335:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 336:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(365);
      if (lookahead == '.') ADVANCE(223);
      if (lookahead == '0') ADVANCE(424);
      if (lookahead == '=') ADVANCE(396);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      END_STATE();
    case 337:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(365);
      if (lookahead == '.') ADVANCE(223);
      if (lookahead == '0') ADVANCE(424);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(365);
      if (lookahead == '=') ADVANCE(396);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '.') ADVANCE(223);
      if (lookahead == '0') ADVANCE(424);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      END_STATE();
    case 340:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(364);
      if (lookahead == '.') ADVANCE(223);
      if (lookahead == '0') ADVANCE(424);
      if (lookahead == '=') ADVANCE(397);
      if (lookahead == '>') ADVANCE(363);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(364);
      if (lookahead == '.') ADVANCE(223);
      if (lookahead == '0') ADVANCE(424);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      END_STATE();
    case 343:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(364);
      if (lookahead == '=') ADVANCE(397);
      if (lookahead == '>') ADVANCE(363);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '.') ADVANCE(223);
      if (lookahead == '0') ADVANCE(424);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(425);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(anon_sym_ss);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(anon_sym_state);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(anon_sym_when);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 349:
      ACCEPT_TOKEN(anon_sym_break);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 351:
      ACCEPT_TOKEN(anon_sym_continue);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 352:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 353:
      ACCEPT_TOKEN(anon_sym_if);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 354:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 355:
      ACCEPT_TOKEN(anon_sym_else);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 356:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 357:
      ACCEPT_TOKEN(anon_sym_while);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 358:
      ACCEPT_TOKEN(anon_sym_for);
      if (lookahead == 'e') ADVANCE(134);
      END_STATE();
    case 359:
      ACCEPT_TOKEN(anon_sym_for);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 360:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 361:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(35);
      END_STATE();
    case 362:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(420);
      END_STATE();
    case 363:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 364:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 365:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 366:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 367:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(380);
      END_STATE();
    case 368:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 369:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(33);
      if (lookahead == '/') ADVANCE(650);
      END_STATE();
    case 370:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(33);
      if (lookahead == '/') ADVANCE(650);
      if (lookahead == '=') ADVANCE(394);
      END_STATE();
    case 371:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 372:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(402);
      if (lookahead == '|') ADVANCE(371);
      END_STATE();
    case 374:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(371);
      END_STATE();
    case 375:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 376:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(401);
      END_STATE();
    case 377:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(372);
      END_STATE();
    case 378:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(372);
      if (lookahead == '=') ADVANCE(400);
      END_STATE();
    case 379:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 380:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(383);
      if (lookahead == '>') ADVANCE(390);
      END_STATE();
    case 382:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(383);
      if (lookahead == '>') ADVANCE(389);
      END_STATE();
    case 383:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 385:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(388);
      if (lookahead == '=') ADVANCE(384);
      END_STATE();
    case 386:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(387);
      if (lookahead == '=') ADVANCE(384);
      END_STATE();
    case 387:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(398);
      END_STATE();
    case 389:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(399);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 392:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 395:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 397:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 398:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 399:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 401:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 403:
      ACCEPT_TOKEN(anon_sym_sizeof);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(anon_sym_sizeof);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 405:
      ACCEPT_TOKEN(sym_true);
      END_STATE();
    case 406:
      ACCEPT_TOKEN(sym_true);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 407:
      ACCEPT_TOKEN(sym_false);
      END_STATE();
    case 408:
      ACCEPT_TOKEN(sym_false);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(sym_null);
      END_STATE();
    case 410:
      ACCEPT_TOKEN(sym_null);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(anon_sym_L_DQUOTE);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(anon_sym_u_DQUOTE);
      END_STATE();
    case 413:
      ACCEPT_TOKEN(anon_sym_U_DQUOTE);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(anon_sym_u8_DQUOTE);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(417);
      if (lookahead == '/') ADVANCE(419);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(419);
      END_STATE();
    case 416:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(416);
      if (lookahead == '/') ADVANCE(419);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(417);
      END_STATE();
    case 417:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(416);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(417);
      END_STATE();
    case 418:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '/') ADVANCE(415);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(418);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(419);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(419);
      END_STATE();
    case 420:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 223,
        'E', 432,
        'P', 432,
        'e', 432,
        'p', 432,
        'F', 434,
        'L', 434,
        'U', 434,
        'f', 434,
        'l', 434,
        'u', 434,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(420);
      END_STATE();
    case 421:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 224,
        '.', 433,
        'b', 430,
        'x', 227,
        'E', 429,
        'e', 429,
        'F', 431,
        'f', 431,
        'P', 432,
        'p', 432,
        'L', 434,
        'U', 434,
        'l', 434,
        'u', 434,
      );
      if (('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(431);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(422);
      END_STATE();
    case 422:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 224,
        '.', 433,
        'E', 429,
        'e', 429,
        'F', 431,
        'f', 431,
        'P', 432,
        'p', 432,
        'L', 434,
        'U', 434,
        'l', 434,
        'u', 434,
      );
      if (('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(431);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(422);
      END_STATE();
    case 423:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 222,
        '.', 433,
        'b', 222,
        'x', 227,
        'E', 432,
        'P', 432,
        'e', 432,
        'p', 432,
        'F', 434,
        'L', 434,
        'U', 434,
        'f', 434,
        'l', 434,
        'u', 434,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(425);
      END_STATE();
    case 424:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 222,
        '.', 433,
        'b', 39,
        'x', 38,
        'E', 432,
        'P', 432,
        'e', 432,
        'p', 432,
        'F', 434,
        'L', 434,
        'U', 434,
        'f', 434,
        'l', 434,
        'u', 434,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(425);
      END_STATE();
    case 425:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 222,
        '.', 433,
        'E', 432,
        'P', 432,
        'e', 432,
        'p', 432,
        'F', 434,
        'L', 434,
        'U', 434,
        'f', 434,
        'l', 434,
        'u', 434,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(425);
      END_STATE();
    case 426:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(228);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(426);
      if (lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(434);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'E') ||
          ('a' <= lookahead && lookahead <= 'e')) ADVANCE(426);
      END_STATE();
    case 427:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 226,
        '+', 228,
        '-', 228,
        'E', 427,
        'e', 427,
        'F', 428,
        'f', 428,
        'P', 432,
        'p', 432,
        'L', 434,
        'U', 434,
        'l', 434,
        'u', 434,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(428);
      END_STATE();
    case 428:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 226,
        'E', 427,
        'e', 427,
        'F', 428,
        'f', 428,
        'P', 432,
        'p', 432,
        'L', 434,
        'U', 434,
        'l', 434,
        'u', 434,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(428);
      END_STATE();
    case 429:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 227,
        '.', 433,
        '+', 228,
        '-', 228,
        'E', 429,
        'e', 429,
        'F', 431,
        'f', 431,
        'P', 432,
        'p', 432,
        'L', 434,
        'U', 434,
        'l', 434,
        'u', 434,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(431);
      END_STATE();
    case 430:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 227,
        '.', 433,
        'E', 429,
        'e', 429,
        'F', 431,
        'f', 431,
        'P', 432,
        'p', 432,
        'L', 434,
        'U', 434,
        'l', 434,
        'u', 434,
      );
      if (('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(431);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(422);
      END_STATE();
    case 431:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 227,
        '.', 433,
        'E', 429,
        'e', 429,
        'F', 431,
        'f', 431,
        'P', 432,
        'p', 432,
        'L', 434,
        'U', 434,
        'l', 434,
        'u', 434,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(431);
      END_STATE();
    case 432:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '+', 228,
        '-', 228,
        'F', 426,
        'f', 426,
        'L', 434,
        'U', 434,
        'l', 434,
        'u', 434,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'E') ||
          ('a' <= lookahead && lookahead <= 'e')) ADVANCE(426);
      END_STATE();
    case 433:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        'E', 427,
        'e', 427,
        'F', 428,
        'f', 428,
        'P', 432,
        'p', 432,
        'L', 434,
        'U', 434,
        'l', 434,
        'u', 434,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(428);
      END_STATE();
    case 434:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'F' ||
          lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'f' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(434);
      END_STATE();
    case 435:
      ACCEPT_TOKEN(anon_sym_L_SQUOTE);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(anon_sym_u_SQUOTE);
      END_STATE();
    case 437:
      ACCEPT_TOKEN(anon_sym_U_SQUOTE);
      END_STATE();
    case 438:
      ACCEPT_TOKEN(anon_sym_u8_SQUOTE);
      END_STATE();
    case 439:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 440:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      END_STATE();
    case 441:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      if (lookahead == '*') ADVANCE(33);
      if (lookahead == '/') ADVANCE(650);
      END_STATE();
    case 442:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      if (lookahead == 'U') ADVANCE(235);
      if (lookahead == 'u') ADVANCE(231);
      if (lookahead == 'x') ADVANCE(229);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(599);
      if (lookahead != 0) ADVANCE(597);
      END_STATE();
    case 443:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      if (lookahead == '\\') ADVANCE(58);
      END_STATE();
    case 444:
      ACCEPT_TOKEN(sym_system_lib_string);
      END_STATE();
    case 445:
      ACCEPT_TOKEN(sym_system_lib_string);
      if (lookahead == '>') ADVANCE(444);
      if (lookahead == '\\') ADVANCE(49);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(48);
      END_STATE();
    case 446:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(411);
      if (lookahead == '\'') ADVANCE(435);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 447:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(411);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 448:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(413);
      if (lookahead == '\'') ADVANCE(437);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 449:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(413);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 450:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(412);
      if (lookahead == '\'') ADVANCE(436);
      if (lookahead == '8') ADVANCE(453);
      if (lookahead == 'i') ADVANCE(549);
      if (lookahead == 'n') ADVANCE(530);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 451:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(412);
      if (lookahead == '\'') ADVANCE(436);
      if (lookahead == '8') ADVANCE(453);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 452:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(412);
      if (lookahead == '8') ADVANCE(454);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 453:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(414);
      if (lookahead == '\'') ADVANCE(438);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 454:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(414);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 455:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(435);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(437);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 457:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(436);
      if (lookahead == '8') ADVANCE(458);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 458:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(438);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 459:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '1') ADVANCE(463);
      if (lookahead == '3') ADVANCE(461);
      if (lookahead == '8') ADVANCE(477);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 460:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(476);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(479);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 462:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '6') ADVANCE(475);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '6') ADVANCE(478);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 464:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'A') ADVANCE(467);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E') ADVANCE(406);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E') ADVANCE(408);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 467:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L') ADVANCE(471);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L') ADVANCE(410);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L') ADVANCE(468);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 470:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'R') ADVANCE(472);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 471:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'S') ADVANCE(466);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'U') ADVANCE(465);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 473:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'U') ADVANCE(469);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '_') ADVANCE(580);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 475:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '_') ADVANCE(582);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '_') ADVANCE(583);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '_') ADVANCE(584);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 478:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '_') ADVANCE(585);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 479:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '_') ADVANCE(586);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(533);
      if (lookahead == 'l') ADVANCE(560);
      if (lookahead == 'o') ADVANCE(566);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(533);
      if (lookahead == 'l') ADVANCE(560);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(533);
      if (lookahead == 'o') ADVANCE(566);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(533);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 485:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(540);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(513);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(568);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(578);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'b') ADVANCE(537);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 490:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(581);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(288);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 492:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(298);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(647);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(406);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 495:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(408);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(357);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(314);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(351);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(286);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(355);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 501:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(484);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(492);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(493);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(551);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(558);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(353);
      if (lookahead == 'n') ADVANCE(575);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(353);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(404);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(535);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(531);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(296);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(280);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(316);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(552);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(487);
      if (lookahead == 'o') ADVANCE(546);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(487);
      if (lookahead == 'o') ADVANCE(547);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(487);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(526);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(561);
      if (lookahead == 'i') ADVANCE(595);
      if (lookahead == 't') ADVANCE(567);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(561);
      if (lookahead == 't') ADVANCE(567);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(595);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(491);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(515);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(550);
      if (lookahead == 'u') ADVANCE(490);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(536);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(576);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(548);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(549);
      if (lookahead == 'n') ADVANCE(530);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(562);
      if (lookahead == 's') ADVANCE(524);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(553);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'k') ADVANCE(349);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(572);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(560);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(496);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(497);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(573);
      if (lookahead == 'x') ADVANCE(527);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(282);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(499);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(575);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(512);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(284);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(590);
      if (lookahead == 'v') ADVANCE(510);
      if (lookahead == 'x') ADVANCE(527);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(590);
      if (lookahead == 'v') ADVANCE(510);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(588);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(574);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(592);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(577);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(514);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(485);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(502);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(503);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(546);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(589);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(321);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(542);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(509);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(523);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(488);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(571);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(543);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(547);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(504);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(501);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(359);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(525);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(290);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(591);
      if (lookahead == 'y') ADVANCE(564);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(591);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(579);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(495);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(500);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(587);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(294);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(268);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(459);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(312);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(292);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(300);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(270);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(304);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(308);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(302);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(306);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(310);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(318);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(528);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(489);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(539);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(494);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(498);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'x') ADVANCE(527);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'y') ADVANCE(564);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'z') ADVANCE(506);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'y')) ADVANCE(596);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(597);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(598);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(aux_sym_preproc_include_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(aux_sym_preproc_def_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(anon_sym_LPAREN2);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_DOT);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(aux_sym_preproc_if_token1);
      if (lookahead == 'd') ADVANCE(619);
      if (lookahead == 'n') ADVANCE(614);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(aux_sym_preproc_if_token2);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(aux_sym_preproc_if_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(aux_sym_preproc_ifdef_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(aux_sym_preproc_ifdef_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(aux_sym_preproc_else_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(aux_sym_preproc_elif_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'c') ADVANCE(631);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'd') ADVANCE(629);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'd') ADVANCE(618);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'd') ADVANCE(620);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(622);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(609);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(601);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(600);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(625);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(626);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 621:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(604);
      if (lookahead == 'n') ADVANCE(611);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 622:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(627);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(610);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(606);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(607);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(608);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'i') ADVANCE(633);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'i') ADVANCE(623);
      if (lookahead == 's') ADVANCE(616);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'i') ADVANCE(624);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'l') ADVANCE(628);
      if (lookahead == 'n') ADVANCE(612);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'l') ADVANCE(634);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'n') ADVANCE(612);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 633:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'n') ADVANCE(617);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'u') ADVANCE(613);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(635);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(33);
      if (lookahead == '*') ADVANCE(636);
      if (lookahead == '/') ADVANCE(648);
      if (lookahead == '\\') ADVANCE(640);
      if (lookahead != 0) ADVANCE(637);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(33);
      if (lookahead == '*') ADVANCE(636);
      if (lookahead == '\\') ADVANCE(640);
      if (lookahead != 0) ADVANCE(637);
      END_STATE();
    case 638:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(258);
      if (lookahead == '/') ADVANCE(642);
      if (lookahead == '\\') ADVANCE(639);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(638);
      if (lookahead != 0) ADVANCE(644);
      END_STATE();
    case 639:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\r') ADVANCE(645);
      if (lookahead == '\\') ADVANCE(639);
      if (lookahead != 0) ADVANCE(644);
      END_STATE();
    case 640:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\r') ADVANCE(643);
      if (lookahead == '*') ADVANCE(636);
      if (lookahead == '\\') ADVANCE(640);
      if (lookahead != 0) ADVANCE(637);
      END_STATE();
    case 641:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\r') ADVANCE(653);
      if (lookahead == '\\') ADVANCE(649);
      if (lookahead != 0) ADVANCE(652);
      END_STATE();
    case 642:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '*') ADVANCE(637);
      if (lookahead == '/') ADVANCE(652);
      if (lookahead == '\\') ADVANCE(639);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(644);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '*') ADVANCE(636);
      if (lookahead == '\\') ADVANCE(640);
      if (lookahead != 0) ADVANCE(637);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\\') ADVANCE(639);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(644);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\\') ADVANCE(639);
      if (lookahead != 0) ADVANCE(644);
      END_STATE();
    case 646:
      ACCEPT_TOKEN(anon_sym_defined);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(anon_sym_defined);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(596);
      END_STATE();
    case 648:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\r') ADVANCE(652);
      if (lookahead == '\\') ADVANCE(641);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(652);
      END_STATE();
    case 650:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\\') ADVANCE(7);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(650);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\\') ADVANCE(7);
      if (lookahead != 0) ADVANCE(650);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\\') ADVANCE(641);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(652);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\\') ADVANCE(641);
      if (lookahead != 0) ADVANCE(652);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 237},
  [2] = {.lex_state = 9},
  [3] = {.lex_state = 9},
  [4] = {.lex_state = 9},
  [5] = {.lex_state = 9},
  [6] = {.lex_state = 9},
  [7] = {.lex_state = 9},
  [8] = {.lex_state = 9},
  [9] = {.lex_state = 9},
  [10] = {.lex_state = 9},
  [11] = {.lex_state = 9},
  [12] = {.lex_state = 8},
  [13] = {.lex_state = 12},
  [14] = {.lex_state = 12},
  [15] = {.lex_state = 12},
  [16] = {.lex_state = 10},
  [17] = {.lex_state = 10},
  [18] = {.lex_state = 10},
  [19] = {.lex_state = 10},
  [20] = {.lex_state = 10},
  [21] = {.lex_state = 10},
  [22] = {.lex_state = 10},
  [23] = {.lex_state = 9},
  [24] = {.lex_state = 10},
  [25] = {.lex_state = 10},
  [26] = {.lex_state = 10},
  [27] = {.lex_state = 10},
  [28] = {.lex_state = 10},
  [29] = {.lex_state = 10},
  [30] = {.lex_state = 10},
  [31] = {.lex_state = 10},
  [32] = {.lex_state = 10},
  [33] = {.lex_state = 10},
  [34] = {.lex_state = 10},
  [35] = {.lex_state = 10},
  [36] = {.lex_state = 10},
  [37] = {.lex_state = 10},
  [38] = {.lex_state = 10},
  [39] = {.lex_state = 10},
  [40] = {.lex_state = 10},
  [41] = {.lex_state = 10},
  [42] = {.lex_state = 10},
  [43] = {.lex_state = 10},
  [44] = {.lex_state = 10},
  [45] = {.lex_state = 10},
  [46] = {.lex_state = 10},
  [47] = {.lex_state = 10},
  [48] = {.lex_state = 10},
  [49] = {.lex_state = 10},
  [50] = {.lex_state = 9},
  [51] = {.lex_state = 9},
  [52] = {.lex_state = 9},
  [53] = {.lex_state = 9},
  [54] = {.lex_state = 9},
  [55] = {.lex_state = 9},
  [56] = {.lex_state = 9},
  [57] = {.lex_state = 9},
  [58] = {.lex_state = 237},
  [59] = {.lex_state = 237},
  [60] = {.lex_state = 237},
  [61] = {.lex_state = 237},
  [62] = {.lex_state = 237},
  [63] = {.lex_state = 237},
  [64] = {.lex_state = 237},
  [65] = {.lex_state = 237},
  [66] = {.lex_state = 237},
  [67] = {.lex_state = 237},
  [68] = {.lex_state = 237},
  [69] = {.lex_state = 237},
  [70] = {.lex_state = 26},
  [71] = {.lex_state = 26},
  [72] = {.lex_state = 26},
  [73] = {.lex_state = 26},
  [74] = {.lex_state = 237},
  [75] = {.lex_state = 237},
  [76] = {.lex_state = 237},
  [77] = {.lex_state = 237},
  [78] = {.lex_state = 237},
  [79] = {.lex_state = 237},
  [80] = {.lex_state = 27},
  [81] = {.lex_state = 27},
  [82] = {.lex_state = 237},
  [83] = {.lex_state = 27},
  [84] = {.lex_state = 27},
  [85] = {.lex_state = 237},
  [86] = {.lex_state = 237},
  [87] = {.lex_state = 237},
  [88] = {.lex_state = 14},
  [89] = {.lex_state = 8},
  [90] = {.lex_state = 14},
  [91] = {.lex_state = 8},
  [92] = {.lex_state = 14},
  [93] = {.lex_state = 14},
  [94] = {.lex_state = 14},
  [95] = {.lex_state = 8},
  [96] = {.lex_state = 14},
  [97] = {.lex_state = 14},
  [98] = {.lex_state = 8},
  [99] = {.lex_state = 14},
  [100] = {.lex_state = 14},
  [101] = {.lex_state = 14},
  [102] = {.lex_state = 14},
  [103] = {.lex_state = 14},
  [104] = {.lex_state = 14},
  [105] = {.lex_state = 14},
  [106] = {.lex_state = 14},
  [107] = {.lex_state = 14},
  [108] = {.lex_state = 14},
  [109] = {.lex_state = 14},
  [110] = {.lex_state = 14},
  [111] = {.lex_state = 14},
  [112] = {.lex_state = 14},
  [113] = {.lex_state = 14},
  [114] = {.lex_state = 8},
  [115] = {.lex_state = 8},
  [116] = {.lex_state = 14},
  [117] = {.lex_state = 14},
  [118] = {.lex_state = 8},
  [119] = {.lex_state = 8},
  [120] = {.lex_state = 14},
  [121] = {.lex_state = 8},
  [122] = {.lex_state = 8},
  [123] = {.lex_state = 8},
  [124] = {.lex_state = 14},
  [125] = {.lex_state = 14},
  [126] = {.lex_state = 8},
  [127] = {.lex_state = 8},
  [128] = {.lex_state = 8},
  [129] = {.lex_state = 8},
  [130] = {.lex_state = 8},
  [131] = {.lex_state = 8},
  [132] = {.lex_state = 8},
  [133] = {.lex_state = 8},
  [134] = {.lex_state = 8},
  [135] = {.lex_state = 8},
  [136] = {.lex_state = 8},
  [137] = {.lex_state = 8},
  [138] = {.lex_state = 8},
  [139] = {.lex_state = 8},
  [140] = {.lex_state = 26},
  [141] = {.lex_state = 26},
  [142] = {.lex_state = 26},
  [143] = {.lex_state = 26},
  [144] = {.lex_state = 26},
  [145] = {.lex_state = 26},
  [146] = {.lex_state = 26},
  [147] = {.lex_state = 26},
  [148] = {.lex_state = 26},
  [149] = {.lex_state = 14},
  [150] = {.lex_state = 8},
  [151] = {.lex_state = 26},
  [152] = {.lex_state = 8},
  [153] = {.lex_state = 8},
  [154] = {.lex_state = 8},
  [155] = {.lex_state = 8},
  [156] = {.lex_state = 8},
  [157] = {.lex_state = 14},
  [158] = {.lex_state = 8},
  [159] = {.lex_state = 8},
  [160] = {.lex_state = 8},
  [161] = {.lex_state = 8},
  [162] = {.lex_state = 8},
  [163] = {.lex_state = 8},
  [164] = {.lex_state = 8},
  [165] = {.lex_state = 8},
  [166] = {.lex_state = 8},
  [167] = {.lex_state = 14},
  [168] = {.lex_state = 237},
  [169] = {.lex_state = 237},
  [170] = {.lex_state = 237},
  [171] = {.lex_state = 14},
  [172] = {.lex_state = 8},
  [173] = {.lex_state = 14},
  [174] = {.lex_state = 237},
  [175] = {.lex_state = 8},
  [176] = {.lex_state = 8},
  [177] = {.lex_state = 8},
  [178] = {.lex_state = 8},
  [179] = {.lex_state = 237},
  [180] = {.lex_state = 14},
  [181] = {.lex_state = 8},
  [182] = {.lex_state = 237},
  [183] = {.lex_state = 237},
  [184] = {.lex_state = 27},
  [185] = {.lex_state = 27},
  [186] = {.lex_state = 27},
  [187] = {.lex_state = 27},
  [188] = {.lex_state = 27},
  [189] = {.lex_state = 27},
  [190] = {.lex_state = 27},
  [191] = {.lex_state = 237},
  [192] = {.lex_state = 27},
  [193] = {.lex_state = 27},
  [194] = {.lex_state = 27},
  [195] = {.lex_state = 237},
  [196] = {.lex_state = 237},
  [197] = {.lex_state = 237},
  [198] = {.lex_state = 237},
  [199] = {.lex_state = 237},
  [200] = {.lex_state = 237},
  [201] = {.lex_state = 237},
  [202] = {.lex_state = 14},
  [203] = {.lex_state = 26},
  [204] = {.lex_state = 14},
  [205] = {.lex_state = 0},
  [206] = {.lex_state = 0},
  [207] = {.lex_state = 0},
  [208] = {.lex_state = 0},
  [209] = {.lex_state = 0},
  [210] = {.lex_state = 0},
  [211] = {.lex_state = 11},
  [212] = {.lex_state = 26},
  [213] = {.lex_state = 27},
  [214] = {.lex_state = 237},
  [215] = {.lex_state = 26},
  [216] = {.lex_state = 11},
  [217] = {.lex_state = 11},
  [218] = {.lex_state = 237},
  [219] = {.lex_state = 11},
  [220] = {.lex_state = 11},
  [221] = {.lex_state = 237},
  [222] = {.lex_state = 0},
  [223] = {.lex_state = 237},
  [224] = {.lex_state = 237},
  [225] = {.lex_state = 237},
  [226] = {.lex_state = 11},
  [227] = {.lex_state = 237},
  [228] = {.lex_state = 11},
  [229] = {.lex_state = 11},
  [230] = {.lex_state = 11},
  [231] = {.lex_state = 11},
  [232] = {.lex_state = 11},
  [233] = {.lex_state = 11},
  [234] = {.lex_state = 11},
  [235] = {.lex_state = 11},
  [236] = {.lex_state = 11},
  [237] = {.lex_state = 237},
  [238] = {.lex_state = 237},
  [239] = {.lex_state = 237},
  [240] = {.lex_state = 11},
  [241] = {.lex_state = 237},
  [242] = {.lex_state = 11},
  [243] = {.lex_state = 237},
  [244] = {.lex_state = 237},
  [245] = {.lex_state = 11},
  [246] = {.lex_state = 237},
  [247] = {.lex_state = 11},
  [248] = {.lex_state = 11},
  [249] = {.lex_state = 237},
  [250] = {.lex_state = 237},
  [251] = {.lex_state = 237},
  [252] = {.lex_state = 237},
  [253] = {.lex_state = 237},
  [254] = {.lex_state = 237},
  [255] = {.lex_state = 11},
  [256] = {.lex_state = 237},
  [257] = {.lex_state = 11},
  [258] = {.lex_state = 10},
  [259] = {.lex_state = 27},
  [260] = {.lex_state = 26},
  [261] = {.lex_state = 10},
  [262] = {.lex_state = 27},
  [263] = {.lex_state = 10},
  [264] = {.lex_state = 10},
  [265] = {.lex_state = 10},
  [266] = {.lex_state = 26},
  [267] = {.lex_state = 26},
  [268] = {.lex_state = 26},
  [269] = {.lex_state = 26},
  [270] = {.lex_state = 26},
  [271] = {.lex_state = 10},
  [272] = {.lex_state = 10},
  [273] = {.lex_state = 10},
  [274] = {.lex_state = 10},
  [275] = {.lex_state = 10},
  [276] = {.lex_state = 10},
  [277] = {.lex_state = 10},
  [278] = {.lex_state = 10},
  [279] = {.lex_state = 26},
  [280] = {.lex_state = 26},
  [281] = {.lex_state = 237},
  [282] = {.lex_state = 10},
  [283] = {.lex_state = 10},
  [284] = {.lex_state = 10},
  [285] = {.lex_state = 237},
  [286] = {.lex_state = 10},
  [287] = {.lex_state = 10},
  [288] = {.lex_state = 10},
  [289] = {.lex_state = 237},
  [290] = {.lex_state = 26},
  [291] = {.lex_state = 10},
  [292] = {.lex_state = 237},
  [293] = {.lex_state = 27},
  [294] = {.lex_state = 27},
  [295] = {.lex_state = 27},
  [296] = {.lex_state = 237},
  [297] = {.lex_state = 27},
  [298] = {.lex_state = 27},
  [299] = {.lex_state = 27},
  [300] = {.lex_state = 27},
  [301] = {.lex_state = 27},
  [302] = {.lex_state = 27},
  [303] = {.lex_state = 237},
  [304] = {.lex_state = 237},
  [305] = {.lex_state = 237},
  [306] = {.lex_state = 237},
  [307] = {.lex_state = 237},
  [308] = {.lex_state = 237},
  [309] = {.lex_state = 237},
  [310] = {.lex_state = 0},
  [311] = {.lex_state = 0},
  [312] = {.lex_state = 0},
  [313] = {.lex_state = 237},
  [314] = {.lex_state = 237},
  [315] = {.lex_state = 0},
  [316] = {.lex_state = 0},
  [317] = {.lex_state = 0},
  [318] = {.lex_state = 0},
  [319] = {.lex_state = 0},
  [320] = {.lex_state = 0},
  [321] = {.lex_state = 0},
  [322] = {.lex_state = 0},
  [323] = {.lex_state = 0},
  [324] = {.lex_state = 0},
  [325] = {.lex_state = 0},
  [326] = {.lex_state = 0},
  [327] = {.lex_state = 0},
  [328] = {.lex_state = 0},
  [329] = {.lex_state = 0},
  [330] = {.lex_state = 15},
  [331] = {.lex_state = 13},
  [332] = {.lex_state = 15},
  [333] = {.lex_state = 13},
  [334] = {.lex_state = 15},
  [335] = {.lex_state = 0},
  [336] = {.lex_state = 1},
  [337] = {.lex_state = 237},
  [338] = {.lex_state = 15},
  [339] = {.lex_state = 15},
  [340] = {.lex_state = 15},
  [341] = {.lex_state = 15},
  [342] = {.lex_state = 15},
  [343] = {.lex_state = 13},
  [344] = {.lex_state = 13},
  [345] = {.lex_state = 13},
  [346] = {.lex_state = 13},
  [347] = {.lex_state = 15},
  [348] = {.lex_state = 13},
  [349] = {.lex_state = 13},
  [350] = {.lex_state = 15},
  [351] = {.lex_state = 15},
  [352] = {.lex_state = 13},
  [353] = {.lex_state = 13},
  [354] = {.lex_state = 13},
  [355] = {.lex_state = 13},
  [356] = {.lex_state = 13},
  [357] = {.lex_state = 13},
  [358] = {.lex_state = 13},
  [359] = {.lex_state = 15},
  [360] = {.lex_state = 15},
  [361] = {.lex_state = 15},
  [362] = {.lex_state = 15},
  [363] = {.lex_state = 13},
  [364] = {.lex_state = 13},
  [365] = {.lex_state = 13},
  [366] = {.lex_state = 15},
  [367] = {.lex_state = 13},
  [368] = {.lex_state = 13},
  [369] = {.lex_state = 15},
  [370] = {.lex_state = 13},
  [371] = {.lex_state = 13},
  [372] = {.lex_state = 15},
  [373] = {.lex_state = 13},
  [374] = {.lex_state = 15},
  [375] = {.lex_state = 15},
  [376] = {.lex_state = 13},
  [377] = {.lex_state = 13},
  [378] = {.lex_state = 13},
  [379] = {.lex_state = 13},
  [380] = {.lex_state = 13},
  [381] = {.lex_state = 13},
  [382] = {.lex_state = 15},
  [383] = {.lex_state = 13},
  [384] = {.lex_state = 15},
  [385] = {.lex_state = 15},
  [386] = {.lex_state = 13},
  [387] = {.lex_state = 1},
  [388] = {.lex_state = 1},
  [389] = {.lex_state = 1},
  [390] = {.lex_state = 1},
  [391] = {.lex_state = 15},
  [392] = {.lex_state = 1},
  [393] = {.lex_state = 27},
  [394] = {.lex_state = 1},
  [395] = {.lex_state = 1},
  [396] = {.lex_state = 15},
  [397] = {.lex_state = 1},
  [398] = {.lex_state = 1},
  [399] = {.lex_state = 1},
  [400] = {.lex_state = 1},
  [401] = {.lex_state = 1},
  [402] = {.lex_state = 1},
  [403] = {.lex_state = 1},
  [404] = {.lex_state = 1},
  [405] = {.lex_state = 1},
  [406] = {.lex_state = 1},
  [407] = {.lex_state = 1},
  [408] = {.lex_state = 1},
  [409] = {.lex_state = 1},
  [410] = {.lex_state = 27},
  [411] = {.lex_state = 27},
  [412] = {.lex_state = 1},
  [413] = {.lex_state = 237},
  [414] = {.lex_state = 237},
  [415] = {.lex_state = 1},
  [416] = {.lex_state = 1},
  [417] = {.lex_state = 15},
  [418] = {.lex_state = 15},
  [419] = {.lex_state = 15},
  [420] = {.lex_state = 15},
  [421] = {.lex_state = 15},
  [422] = {.lex_state = 15},
  [423] = {.lex_state = 237},
  [424] = {.lex_state = 0},
  [425] = {.lex_state = 0},
  [426] = {.lex_state = 0},
  [427] = {.lex_state = 0},
  [428] = {.lex_state = 0},
  [429] = {.lex_state = 0},
  [430] = {.lex_state = 0},
  [431] = {.lex_state = 0},
  [432] = {.lex_state = 0},
  [433] = {.lex_state = 0},
  [434] = {.lex_state = 0},
  [435] = {.lex_state = 0},
  [436] = {.lex_state = 0},
  [437] = {.lex_state = 0},
  [438] = {.lex_state = 15},
  [439] = {.lex_state = 0},
  [440] = {.lex_state = 0},
  [441] = {.lex_state = 0},
  [442] = {.lex_state = 15},
  [443] = {.lex_state = 237},
  [444] = {.lex_state = 15},
  [445] = {.lex_state = 15},
  [446] = {.lex_state = 15},
  [447] = {.lex_state = 237},
  [448] = {.lex_state = 27},
  [449] = {.lex_state = 27},
  [450] = {.lex_state = 27},
  [451] = {.lex_state = 237},
  [452] = {.lex_state = 237},
  [453] = {.lex_state = 15},
  [454] = {.lex_state = 237},
  [455] = {.lex_state = 237},
  [456] = {.lex_state = 27},
  [457] = {.lex_state = 27},
  [458] = {.lex_state = 27},
  [459] = {.lex_state = 237},
  [460] = {.lex_state = 27},
  [461] = {.lex_state = 27},
  [462] = {.lex_state = 237},
  [463] = {.lex_state = 237},
  [464] = {.lex_state = 237},
  [465] = {.lex_state = 16},
  [466] = {.lex_state = 237},
  [467] = {.lex_state = 237},
  [468] = {.lex_state = 237},
  [469] = {.lex_state = 27},
  [470] = {.lex_state = 237},
  [471] = {.lex_state = 237},
  [472] = {.lex_state = 27},
  [473] = {.lex_state = 237},
  [474] = {.lex_state = 27},
  [475] = {.lex_state = 27},
  [476] = {.lex_state = 16},
  [477] = {.lex_state = 15},
  [478] = {.lex_state = 15},
  [479] = {.lex_state = 237},
  [480] = {.lex_state = 27},
  [481] = {.lex_state = 27},
  [482] = {.lex_state = 27},
  [483] = {.lex_state = 27},
  [484] = {.lex_state = 16},
  [485] = {.lex_state = 237},
  [486] = {.lex_state = 237},
  [487] = {.lex_state = 237},
  [488] = {.lex_state = 27},
  [489] = {.lex_state = 36},
  [490] = {.lex_state = 15},
  [491] = {.lex_state = 237},
  [492] = {.lex_state = 15},
  [493] = {.lex_state = 15},
  [494] = {.lex_state = 237},
  [495] = {.lex_state = 237},
  [496] = {.lex_state = 15},
  [497] = {.lex_state = 237},
  [498] = {.lex_state = 15},
  [499] = {.lex_state = 237},
  [500] = {.lex_state = 237},
  [501] = {.lex_state = 15},
  [502] = {.lex_state = 237},
  [503] = {.lex_state = 237},
  [504] = {.lex_state = 237},
  [505] = {.lex_state = 1},
  [506] = {.lex_state = 1},
  [507] = {.lex_state = 1},
  [508] = {.lex_state = 15},
  [509] = {.lex_state = 2},
  [510] = {.lex_state = 2},
  [511] = {.lex_state = 237},
  [512] = {.lex_state = 2},
  [513] = {.lex_state = 237},
  [514] = {.lex_state = 237},
  [515] = {.lex_state = 0},
  [516] = {.lex_state = 15},
  [517] = {.lex_state = 237},
  [518] = {.lex_state = 237},
  [519] = {.lex_state = 36},
  [520] = {.lex_state = 29},
  [521] = {.lex_state = 237},
  [522] = {.lex_state = 237},
  [523] = {.lex_state = 29},
  [524] = {.lex_state = 36},
  [525] = {.lex_state = 237},
  [526] = {.lex_state = 29},
  [527] = {.lex_state = 29},
  [528] = {.lex_state = 237},
  [529] = {.lex_state = 29},
  [530] = {.lex_state = 29},
  [531] = {.lex_state = 29},
  [532] = {.lex_state = 29},
  [533] = {.lex_state = 29},
  [534] = {.lex_state = 29},
  [535] = {.lex_state = 237},
  [536] = {.lex_state = 29},
  [537] = {.lex_state = 29},
  [538] = {.lex_state = 237},
  [539] = {.lex_state = 237},
  [540] = {.lex_state = 237},
  [541] = {.lex_state = 29},
  [542] = {.lex_state = 237},
  [543] = {.lex_state = 237},
  [544] = {.lex_state = 4},
  [545] = {.lex_state = 0},
  [546] = {.lex_state = 4},
  [547] = {.lex_state = 237},
  [548] = {.lex_state = 237},
  [549] = {.lex_state = 237},
  [550] = {.lex_state = 237},
  [551] = {.lex_state = 237},
  [552] = {.lex_state = 237},
  [553] = {.lex_state = 29},
  [554] = {.lex_state = 3},
  [555] = {.lex_state = 0},
  [556] = {.lex_state = 2},
  [557] = {.lex_state = 3},
  [558] = {.lex_state = 3},
  [559] = {.lex_state = 0},
  [560] = {.lex_state = 3},
  [561] = {.lex_state = 237},
  [562] = {.lex_state = 237},
  [563] = {.lex_state = 0},
  [564] = {.lex_state = 237},
  [565] = {.lex_state = 237},
  [566] = {.lex_state = 4},
  [567] = {.lex_state = 3},
  [568] = {.lex_state = 237},
  [569] = {.lex_state = 237},
  [570] = {.lex_state = 237},
  [571] = {.lex_state = 237},
  [572] = {.lex_state = 36},
  [573] = {.lex_state = 237},
  [574] = {.lex_state = 237},
  [575] = {.lex_state = 0},
  [576] = {.lex_state = 237},
  [577] = {.lex_state = 0},
  [578] = {.lex_state = 1},
  [579] = {.lex_state = 237},
  [580] = {.lex_state = 0},
  [581] = {.lex_state = 237},
  [582] = {.lex_state = 237},
  [583] = {.lex_state = 237},
  [584] = {.lex_state = 0},
  [585] = {.lex_state = 237},
  [586] = {.lex_state = 237},
  [587] = {.lex_state = 0},
  [588] = {.lex_state = 0},
  [589] = {.lex_state = 0},
  [590] = {.lex_state = 0},
  [591] = {.lex_state = 237},
  [592] = {.lex_state = 237},
  [593] = {.lex_state = 0},
  [594] = {.lex_state = 0},
  [595] = {.lex_state = 0},
  [596] = {.lex_state = 0},
  [597] = {.lex_state = 237},
  [598] = {.lex_state = 0},
  [599] = {.lex_state = 237},
  [600] = {.lex_state = 0},
  [601] = {.lex_state = 0},
  [602] = {.lex_state = 0},
  [603] = {.lex_state = 26},
  [604] = {.lex_state = 0},
  [605] = {.lex_state = 0},
  [606] = {.lex_state = 237},
  [607] = {.lex_state = 0},
  [608] = {.lex_state = 1},
  [609] = {.lex_state = 0},
  [610] = {.lex_state = 237},
  [611] = {.lex_state = 237},
  [612] = {.lex_state = 237},
  [613] = {.lex_state = 0},
  [614] = {.lex_state = 237},
  [615] = {.lex_state = 0},
  [616] = {.lex_state = 237},
  [617] = {.lex_state = 237},
  [618] = {.lex_state = 0},
  [619] = {.lex_state = 0},
  [620] = {.lex_state = 0},
  [621] = {.lex_state = 0},
  [622] = {.lex_state = 0},
  [623] = {.lex_state = 237},
  [624] = {.lex_state = 0},
  [625] = {.lex_state = 1},
  [626] = {.lex_state = 36},
  [627] = {.lex_state = 0},
  [628] = {.lex_state = 237},
  [629] = {.lex_state = 237},
  [630] = {.lex_state = 0},
  [631] = {.lex_state = 0},
  [632] = {.lex_state = 0},
  [633] = {.lex_state = 237},
  [634] = {.lex_state = 237},
  [635] = {.lex_state = 237},
  [636] = {.lex_state = 237},
  [637] = {.lex_state = 237},
  [638] = {.lex_state = 237},
  [639] = {.lex_state = 237},
  [640] = {.lex_state = 0},
  [641] = {.lex_state = 30},
  [642] = {.lex_state = 0},
  [643] = {.lex_state = 5},
  [644] = {.lex_state = 5},
  [645] = {.lex_state = 30},
  [646] = {.lex_state = 30},
  [647] = {.lex_state = 6},
  [648] = {.lex_state = 237},
  [649] = {.lex_state = 5},
  [650] = {.lex_state = 30},
  [651] = {.lex_state = 237},
  [652] = {.lex_state = 237},
  [653] = {.lex_state = 5},
  [654] = {.lex_state = 30},
  [655] = {.lex_state = 30},
  [656] = {.lex_state = 5},
  [657] = {.lex_state = 237},
  [658] = {.lex_state = 0},
  [659] = {.lex_state = 30},
  [660] = {.lex_state = 237},
  [661] = {.lex_state = 0},
  [662] = {.lex_state = 237},
  [663] = {.lex_state = 5},
  [664] = {.lex_state = 237},
  [665] = {.lex_state = 0},
  [666] = {.lex_state = 237},
  [667] = {.lex_state = 237},
  [668] = {.lex_state = 0},
  [669] = {.lex_state = 5},
  [670] = {.lex_state = 237},
  [671] = {.lex_state = 237},
  [672] = {.lex_state = 237},
  [673] = {.lex_state = 0},
  [674] = {.lex_state = 0},
  [675] = {.lex_state = 237},
  [676] = {.lex_state = 237},
  [677] = {.lex_state = 0},
  [678] = {.lex_state = 0},
  [679] = {.lex_state = 0},
  [680] = {.lex_state = 237},
  [681] = {.lex_state = 0},
  [682] = {.lex_state = 30},
  [683] = {.lex_state = 6},
  [684] = {.lex_state = 237},
  [685] = {.lex_state = 5},
  [686] = {.lex_state = 0},
  [687] = {.lex_state = 237},
  [688] = {.lex_state = 237},
  [689] = {.lex_state = 6},
  [690] = {.lex_state = 0},
  [691] = {.lex_state = 30},
  [692] = {.lex_state = 237},
  [693] = {.lex_state = 5},
  [694] = {.lex_state = 30},
  [695] = {.lex_state = 0},
  [696] = {.lex_state = 1},
  [697] = {.lex_state = 0},
  [698] = {.lex_state = 237},
  [699] = {.lex_state = 0},
  [700] = {.lex_state = 30},
  [701] = {.lex_state = 1},
  [702] = {.lex_state = 237},
  [703] = {.lex_state = 1},
  [704] = {.lex_state = 0},
  [705] = {.lex_state = 9},
  [706] = {.lex_state = 0},
  [707] = {.lex_state = 9},
  [708] = {.lex_state = 0},
  [709] = {.lex_state = 0},
  [710] = {.lex_state = 0},
  [711] = {.lex_state = 237},
  [712] = {.lex_state = 0},
  [713] = {.lex_state = 0},
  [714] = {.lex_state = 0},
  [715] = {.lex_state = 0},
  [716] = {.lex_state = 0},
  [717] = {.lex_state = 1},
  [718] = {.lex_state = 9},
  [719] = {.lex_state = 0},
  [720] = {.lex_state = 0},
  [721] = {.lex_state = 0},
  [722] = {.lex_state = 0},
  [723] = {.lex_state = 0},
  [724] = {.lex_state = 0},
  [725] = {.lex_state = 0},
  [726] = {.lex_state = 1},
  [727] = {.lex_state = 0},
  [728] = {.lex_state = 30},
  [729] = {.lex_state = 30},
  [730] = {.lex_state = 0},
  [731] = {.lex_state = 1},
  [732] = {.lex_state = 0},
  [733] = {.lex_state = 237},
  [734] = {.lex_state = 0},
  [735] = {.lex_state = 237},
  [736] = {.lex_state = 0},
  [737] = {.lex_state = 1},
  [738] = {.lex_state = 0},
  [739] = {.lex_state = 30},
  [740] = {.lex_state = 237},
  [741] = {.lex_state = 1},
  [742] = {.lex_state = 1},
  [743] = {.lex_state = 30},
  [744] = {.lex_state = 0},
  [745] = {.lex_state = 0},
  [746] = {.lex_state = 30},
  [747] = {.lex_state = 1},
  [748] = {.lex_state = 1},
  [749] = {.lex_state = 0},
  [750] = {.lex_state = 30},
  [751] = {.lex_state = 9},
  [752] = {.lex_state = 0},
  [753] = {.lex_state = 1},
  [754] = {.lex_state = 1},
  [755] = {.lex_state = 0},
  [756] = {.lex_state = 1},
  [757] = {.lex_state = 30},
  [758] = {.lex_state = 0},
  [759] = {.lex_state = 1},
  [760] = {.lex_state = 9},
  [761] = {.lex_state = 237},
  [762] = {.lex_state = 9},
  [763] = {.lex_state = 0},
  [764] = {.lex_state = 9},
  [765] = {.lex_state = 0},
  [766] = {.lex_state = 30},
  [767] = {.lex_state = 30},
  [768] = {.lex_state = 9},
  [769] = {.lex_state = 9},
  [770] = {.lex_state = 1},
  [771] = {.lex_state = 0},
  [772] = {.lex_state = 0},
  [773] = {.lex_state = 1},
  [774] = {.lex_state = 1},
  [775] = {.lex_state = 1},
  [776] = {.lex_state = 30},
  [777] = {.lex_state = 30},
  [778] = {.lex_state = 30},
  [779] = {.lex_state = 1},
  [780] = {.lex_state = 0},
  [781] = {.lex_state = 1},
  [782] = {.lex_state = 0},
  [783] = {.lex_state = 0},
  [784] = {.lex_state = 0},
  [785] = {.lex_state = 30},
  [786] = {.lex_state = 237},
  [787] = {.lex_state = 0},
  [788] = {.lex_state = 1},
  [789] = {.lex_state = 0},
  [790] = {.lex_state = 30},
  [791] = {.lex_state = 30},
  [792] = {.lex_state = 30},
  [793] = {.lex_state = 30},
  [794] = {.lex_state = 0},
  [795] = {.lex_state = 0},
  [796] = {.lex_state = 237},
  [797] = {.lex_state = 254},
  [798] = {.lex_state = 30},
  [799] = {.lex_state = 0},
  [800] = {.lex_state = 237},
  [801] = {.lex_state = 237},
  [802] = {.lex_state = 9},
  [803] = {.lex_state = 0},
  [804] = {.lex_state = 0},
  [805] = {.lex_state = 1},
  [806] = {.lex_state = 9},
  [807] = {.lex_state = 0},
  [808] = {.lex_state = 0},
  [809] = {.lex_state = 30},
  [810] = {.lex_state = 0},
  [811] = {.lex_state = 0},
  [812] = {.lex_state = 0},
  [813] = {.lex_state = 0},
  [814] = {.lex_state = 0},
  [815] = {.lex_state = 30},
  [816] = {.lex_state = 30},
  [817] = {.lex_state = 30},
  [818] = {.lex_state = 30},
  [819] = {.lex_state = 0},
  [820] = {.lex_state = 30},
  [821] = {.lex_state = 254},
  [822] = {.lex_state = 0},
  [823] = {.lex_state = 0},
  [824] = {.lex_state = 30},
  [825] = {.lex_state = 9},
  [826] = {.lex_state = 254},
  [827] = {.lex_state = 254},
  [828] = {.lex_state = 254},
  [829] = {.lex_state = 30},
  [830] = {.lex_state = 0},
  [831] = {.lex_state = 237},
  [832] = {.lex_state = 9},
  [833] = {.lex_state = 0},
  [834] = {.lex_state = 0},
  [835] = {.lex_state = 0},
  [836] = {.lex_state = 9},
  [837] = {.lex_state = 0},
  [838] = {.lex_state = 0},
  [839] = {.lex_state = 30},
  [840] = {.lex_state = 237},
  [841] = {.lex_state = 30},
  [842] = {.lex_state = 237},
  [843] = {.lex_state = 237},
  [844] = {.lex_state = 237},
  [845] = {.lex_state = 0},
  [846] = {.lex_state = 30},
  [847] = {.lex_state = 237},
  [848] = {.lex_state = 237},
  [849] = {.lex_state = 254},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_RBRACE_PERCENT] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(1),
    [sym_line_number] = ACTIONS(1),
    [anon_sym_program] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_entry] = ACTIONS(1),
    [anon_sym_exit] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_foreign] = ACTIONS(1),
    [anon_sym_evflag] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_union] = ACTIONS(1),
    [anon_sym_typename] = ACTIONS(1),
    [anon_sym_void] = ACTIONS(1),
    [anon_sym_char] = ACTIONS(1),
    [anon_sym_short] = ACTIONS(1),
    [anon_sym_int] = ACTIONS(1),
    [anon_sym_long] = ACTIONS(1),
    [anon_sym_unsigned] = ACTIONS(1),
    [anon_sym_int8_t] = ACTIONS(1),
    [anon_sym_uint8_t] = ACTIONS(1),
    [anon_sym_int16_t] = ACTIONS(1),
    [anon_sym_uint16_t] = ACTIONS(1),
    [anon_sym_int32_t] = ACTIONS(1),
    [anon_sym_uint32_t] = ACTIONS(1),
    [anon_sym_float] = ACTIONS(1),
    [anon_sym_double] = ACTIONS(1),
    [anon_sym_string] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_assign] = ACTIONS(1),
    [anon_sym_to] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_LBRACE2] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_monitor] = ACTIONS(1),
    [anon_sym_sync] = ACTIONS(1),
    [anon_sym_syncq] = ACTIONS(1),
    [anon_sym_option] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_ss] = ACTIONS(1),
    [anon_sym_state] = ACTIONS(1),
    [anon_sym_when] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_sizeof] = ACTIONS(1),
    [sym_true] = ACTIONS(1),
    [sym_false] = ACTIONS(1),
    [sym_null] = ACTIONS(1),
    [anon_sym_L_DQUOTE] = ACTIONS(1),
    [anon_sym_u_DQUOTE] = ACTIONS(1),
    [anon_sym_U_DQUOTE] = ACTIONS(1),
    [anon_sym_u8_DQUOTE] = ACTIONS(1),
    [anon_sym_L_SQUOTE] = ACTIONS(1),
    [anon_sym_u_SQUOTE] = ACTIONS(1),
    [anon_sym_U_SQUOTE] = ACTIONS(1),
    [anon_sym_u8_SQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [aux_sym_preproc_include_token1] = ACTIONS(1),
    [aux_sym_preproc_def_token1] = ACTIONS(1),
    [anon_sym_LPAREN2] = ACTIONS(1),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1),
    [aux_sym_preproc_if_token1] = ACTIONS(1),
    [aux_sym_preproc_if_token2] = ACTIONS(1),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1),
    [aux_sym_preproc_else_token1] = ACTIONS(1),
    [aux_sym_preproc_elif_token1] = ACTIONS(1),
    [sym_preproc_directive] = ACTIONS(1),
    [anon_sym_defined] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(787),
    [sym__top_level_item] = STATE(414),
    [sym_line_marker] = STATE(414),
    [sym_program] = STATE(414),
    [sym_preproc_include] = STATE(414),
    [sym_preproc_def] = STATE(414),
    [sym_preproc_function_def] = STATE(414),
    [sym_preproc_call] = STATE(414),
    [sym_preproc_if] = STATE(414),
    [sym_preproc_ifdef] = STATE(414),
    [aux_sym_source_file_repeat1] = STATE(414),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_POUND] = ACTIONS(7),
    [anon_sym_program] = ACTIONS(9),
    [aux_sym_preproc_include_token1] = ACTIONS(11),
    [aux_sym_preproc_def_token1] = ACTIONS(13),
    [aux_sym_preproc_if_token1] = ACTIONS(15),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(17),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(17),
    [sym_preproc_directive] = ACTIONS(19),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(2)] = {
    [sym__c_code] = STATE(53),
    [sym_declaration] = STATE(55),
    [sym_basetype] = STATE(422),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(271),
    [sym_block_defn] = STATE(6),
    [sym_statement] = STATE(17),
    [sym_break_statement] = STATE(271),
    [sym_continue_statement] = STATE(271),
    [sym_if_statement] = STATE(271),
    [sym_while_statement] = STATE(271),
    [sym_for_statement] = STATE(271),
    [sym__expr] = STATE(180),
    [sym_parenthesized_expression] = STATE(180),
    [sym_call_expression] = STATE(180),
    [sym_exit_expression] = STATE(180),
    [sym_subscript_expression] = STATE(180),
    [sym_field_expression] = STATE(180),
    [sym_update_expression] = STATE(180),
    [sym_unary_expression] = STATE(180),
    [sym_binary_expression] = STATE(180),
    [sym_conditional_expression] = STATE(180),
    [sym_assignment_expression] = STATE(180),
    [sym_cast_expression] = STATE(180),
    [sym_sizeof_expression] = STATE(180),
    [sym__comma_expr] = STATE(772),
    [sym_comma_expr] = STATE(772),
    [sym_string_literal] = STATE(180),
    [sym_char_literal] = STATE(180),
    [aux_sym_block_repeat1] = STATE(6),
    [aux_sym_block_repeat2] = STATE(17),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(23),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(3)] = {
    [sym__c_code] = STATE(53),
    [sym_declaration] = STATE(55),
    [sym_basetype] = STATE(422),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(271),
    [sym_block_defn] = STATE(23),
    [sym_statement] = STATE(19),
    [sym_break_statement] = STATE(271),
    [sym_continue_statement] = STATE(271),
    [sym_if_statement] = STATE(271),
    [sym_while_statement] = STATE(271),
    [sym_for_statement] = STATE(271),
    [sym__expr] = STATE(180),
    [sym_parenthesized_expression] = STATE(180),
    [sym_call_expression] = STATE(180),
    [sym_exit_expression] = STATE(180),
    [sym_subscript_expression] = STATE(180),
    [sym_field_expression] = STATE(180),
    [sym_update_expression] = STATE(180),
    [sym_unary_expression] = STATE(180),
    [sym_binary_expression] = STATE(180),
    [sym_conditional_expression] = STATE(180),
    [sym_assignment_expression] = STATE(180),
    [sym_cast_expression] = STATE(180),
    [sym_sizeof_expression] = STATE(180),
    [sym__comma_expr] = STATE(772),
    [sym_comma_expr] = STATE(772),
    [sym_string_literal] = STATE(180),
    [sym_char_literal] = STATE(180),
    [aux_sym_block_repeat1] = STATE(23),
    [aux_sym_block_repeat2] = STATE(19),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(67),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(4)] = {
    [sym__c_code] = STATE(53),
    [sym_declaration] = STATE(55),
    [sym_basetype] = STATE(422),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(271),
    [sym_block_defn] = STATE(23),
    [sym_statement] = STATE(25),
    [sym_break_statement] = STATE(271),
    [sym_continue_statement] = STATE(271),
    [sym_if_statement] = STATE(271),
    [sym_while_statement] = STATE(271),
    [sym_for_statement] = STATE(271),
    [sym__expr] = STATE(180),
    [sym_parenthesized_expression] = STATE(180),
    [sym_call_expression] = STATE(180),
    [sym_exit_expression] = STATE(180),
    [sym_subscript_expression] = STATE(180),
    [sym_field_expression] = STATE(180),
    [sym_update_expression] = STATE(180),
    [sym_unary_expression] = STATE(180),
    [sym_binary_expression] = STATE(180),
    [sym_conditional_expression] = STATE(180),
    [sym_assignment_expression] = STATE(180),
    [sym_cast_expression] = STATE(180),
    [sym_sizeof_expression] = STATE(180),
    [sym__comma_expr] = STATE(772),
    [sym_comma_expr] = STATE(772),
    [sym_string_literal] = STATE(180),
    [sym_char_literal] = STATE(180),
    [aux_sym_block_repeat1] = STATE(23),
    [aux_sym_block_repeat2] = STATE(25),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(5)] = {
    [sym__c_code] = STATE(53),
    [sym_declaration] = STATE(55),
    [sym_basetype] = STATE(422),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(271),
    [sym_block_defn] = STATE(3),
    [sym_statement] = STATE(26),
    [sym_break_statement] = STATE(271),
    [sym_continue_statement] = STATE(271),
    [sym_if_statement] = STATE(271),
    [sym_while_statement] = STATE(271),
    [sym_for_statement] = STATE(271),
    [sym__expr] = STATE(180),
    [sym_parenthesized_expression] = STATE(180),
    [sym_call_expression] = STATE(180),
    [sym_exit_expression] = STATE(180),
    [sym_subscript_expression] = STATE(180),
    [sym_field_expression] = STATE(180),
    [sym_update_expression] = STATE(180),
    [sym_unary_expression] = STATE(180),
    [sym_binary_expression] = STATE(180),
    [sym_conditional_expression] = STATE(180),
    [sym_assignment_expression] = STATE(180),
    [sym_cast_expression] = STATE(180),
    [sym_sizeof_expression] = STATE(180),
    [sym__comma_expr] = STATE(772),
    [sym_comma_expr] = STATE(772),
    [sym_string_literal] = STATE(180),
    [sym_char_literal] = STATE(180),
    [aux_sym_block_repeat1] = STATE(3),
    [aux_sym_block_repeat2] = STATE(26),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(71),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(6)] = {
    [sym__c_code] = STATE(53),
    [sym_declaration] = STATE(55),
    [sym_basetype] = STATE(422),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(271),
    [sym_block_defn] = STATE(23),
    [sym_statement] = STATE(18),
    [sym_break_statement] = STATE(271),
    [sym_continue_statement] = STATE(271),
    [sym_if_statement] = STATE(271),
    [sym_while_statement] = STATE(271),
    [sym_for_statement] = STATE(271),
    [sym__expr] = STATE(180),
    [sym_parenthesized_expression] = STATE(180),
    [sym_call_expression] = STATE(180),
    [sym_exit_expression] = STATE(180),
    [sym_subscript_expression] = STATE(180),
    [sym_field_expression] = STATE(180),
    [sym_update_expression] = STATE(180),
    [sym_unary_expression] = STATE(180),
    [sym_binary_expression] = STATE(180),
    [sym_conditional_expression] = STATE(180),
    [sym_assignment_expression] = STATE(180),
    [sym_cast_expression] = STATE(180),
    [sym_sizeof_expression] = STATE(180),
    [sym__comma_expr] = STATE(772),
    [sym_comma_expr] = STATE(772),
    [sym_string_literal] = STATE(180),
    [sym_char_literal] = STATE(180),
    [aux_sym_block_repeat1] = STATE(23),
    [aux_sym_block_repeat2] = STATE(18),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(7)] = {
    [sym__c_code] = STATE(53),
    [sym_declaration] = STATE(55),
    [sym_basetype] = STATE(422),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(271),
    [sym_block_defn] = STATE(8),
    [sym_statement] = STATE(21),
    [sym_break_statement] = STATE(271),
    [sym_continue_statement] = STATE(271),
    [sym_if_statement] = STATE(271),
    [sym_while_statement] = STATE(271),
    [sym_for_statement] = STATE(271),
    [sym__expr] = STATE(180),
    [sym_parenthesized_expression] = STATE(180),
    [sym_call_expression] = STATE(180),
    [sym_exit_expression] = STATE(180),
    [sym_subscript_expression] = STATE(180),
    [sym_field_expression] = STATE(180),
    [sym_update_expression] = STATE(180),
    [sym_unary_expression] = STATE(180),
    [sym_binary_expression] = STATE(180),
    [sym_conditional_expression] = STATE(180),
    [sym_assignment_expression] = STATE(180),
    [sym_cast_expression] = STATE(180),
    [sym_sizeof_expression] = STATE(180),
    [sym__comma_expr] = STATE(772),
    [sym_comma_expr] = STATE(772),
    [sym_string_literal] = STATE(180),
    [sym_char_literal] = STATE(180),
    [aux_sym_block_repeat1] = STATE(8),
    [aux_sym_block_repeat2] = STATE(21),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(75),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(8)] = {
    [sym__c_code] = STATE(53),
    [sym_declaration] = STATE(55),
    [sym_basetype] = STATE(422),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(271),
    [sym_block_defn] = STATE(23),
    [sym_statement] = STATE(22),
    [sym_break_statement] = STATE(271),
    [sym_continue_statement] = STATE(271),
    [sym_if_statement] = STATE(271),
    [sym_while_statement] = STATE(271),
    [sym_for_statement] = STATE(271),
    [sym__expr] = STATE(180),
    [sym_parenthesized_expression] = STATE(180),
    [sym_call_expression] = STATE(180),
    [sym_exit_expression] = STATE(180),
    [sym_subscript_expression] = STATE(180),
    [sym_field_expression] = STATE(180),
    [sym_update_expression] = STATE(180),
    [sym_unary_expression] = STATE(180),
    [sym_binary_expression] = STATE(180),
    [sym_conditional_expression] = STATE(180),
    [sym_assignment_expression] = STATE(180),
    [sym_cast_expression] = STATE(180),
    [sym_sizeof_expression] = STATE(180),
    [sym__comma_expr] = STATE(772),
    [sym_comma_expr] = STATE(772),
    [sym_string_literal] = STATE(180),
    [sym_char_literal] = STATE(180),
    [aux_sym_block_repeat1] = STATE(23),
    [aux_sym_block_repeat2] = STATE(22),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(77),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(9)] = {
    [sym__c_code] = STATE(53),
    [sym_declaration] = STATE(55),
    [sym_basetype] = STATE(422),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(271),
    [sym_block_defn] = STATE(4),
    [sym_statement] = STATE(24),
    [sym_break_statement] = STATE(271),
    [sym_continue_statement] = STATE(271),
    [sym_if_statement] = STATE(271),
    [sym_while_statement] = STATE(271),
    [sym_for_statement] = STATE(271),
    [sym__expr] = STATE(180),
    [sym_parenthesized_expression] = STATE(180),
    [sym_call_expression] = STATE(180),
    [sym_exit_expression] = STATE(180),
    [sym_subscript_expression] = STATE(180),
    [sym_field_expression] = STATE(180),
    [sym_update_expression] = STATE(180),
    [sym_unary_expression] = STATE(180),
    [sym_binary_expression] = STATE(180),
    [sym_conditional_expression] = STATE(180),
    [sym_assignment_expression] = STATE(180),
    [sym_cast_expression] = STATE(180),
    [sym_sizeof_expression] = STATE(180),
    [sym__comma_expr] = STATE(772),
    [sym_comma_expr] = STATE(772),
    [sym_string_literal] = STATE(180),
    [sym_char_literal] = STATE(180),
    [aux_sym_block_repeat1] = STATE(4),
    [aux_sym_block_repeat2] = STATE(24),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(79),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(10)] = {
    [sym__c_code] = STATE(53),
    [sym_declaration] = STATE(55),
    [sym_basetype] = STATE(422),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(271),
    [sym_block_defn] = STATE(11),
    [sym_statement] = STATE(27),
    [sym_break_statement] = STATE(271),
    [sym_continue_statement] = STATE(271),
    [sym_if_statement] = STATE(271),
    [sym_while_statement] = STATE(271),
    [sym_for_statement] = STATE(271),
    [sym__expr] = STATE(180),
    [sym_parenthesized_expression] = STATE(180),
    [sym_call_expression] = STATE(180),
    [sym_exit_expression] = STATE(180),
    [sym_subscript_expression] = STATE(180),
    [sym_field_expression] = STATE(180),
    [sym_update_expression] = STATE(180),
    [sym_unary_expression] = STATE(180),
    [sym_binary_expression] = STATE(180),
    [sym_conditional_expression] = STATE(180),
    [sym_assignment_expression] = STATE(180),
    [sym_cast_expression] = STATE(180),
    [sym_sizeof_expression] = STATE(180),
    [sym__comma_expr] = STATE(772),
    [sym_comma_expr] = STATE(772),
    [sym_string_literal] = STATE(180),
    [sym_char_literal] = STATE(180),
    [aux_sym_block_repeat1] = STATE(11),
    [aux_sym_block_repeat2] = STATE(27),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(81),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(11)] = {
    [sym__c_code] = STATE(53),
    [sym_declaration] = STATE(55),
    [sym_basetype] = STATE(422),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(271),
    [sym_block_defn] = STATE(23),
    [sym_statement] = STATE(16),
    [sym_break_statement] = STATE(271),
    [sym_continue_statement] = STATE(271),
    [sym_if_statement] = STATE(271),
    [sym_while_statement] = STATE(271),
    [sym_for_statement] = STATE(271),
    [sym__expr] = STATE(180),
    [sym_parenthesized_expression] = STATE(180),
    [sym_call_expression] = STATE(180),
    [sym_exit_expression] = STATE(180),
    [sym_subscript_expression] = STATE(180),
    [sym_field_expression] = STATE(180),
    [sym_update_expression] = STATE(180),
    [sym_unary_expression] = STATE(180),
    [sym_binary_expression] = STATE(180),
    [sym_conditional_expression] = STATE(180),
    [sym_assignment_expression] = STATE(180),
    [sym_cast_expression] = STATE(180),
    [sym_sizeof_expression] = STATE(180),
    [sym__comma_expr] = STATE(772),
    [sym_comma_expr] = STATE(772),
    [sym_string_literal] = STATE(180),
    [sym_char_literal] = STATE(180),
    [aux_sym_block_repeat1] = STATE(23),
    [aux_sym_block_repeat2] = STATE(16),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(83),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(12)] = {
    [sym__expr] = STATE(112),
    [sym_parenthesized_expression] = STATE(112),
    [sym_call_expression] = STATE(112),
    [sym_exit_expression] = STATE(112),
    [sym_subscript_expression] = STATE(112),
    [sym_field_expression] = STATE(112),
    [sym_update_expression] = STATE(112),
    [sym_unary_expression] = STATE(112),
    [sym_binary_expression] = STATE(112),
    [sym_conditional_expression] = STATE(112),
    [sym_assignment_expression] = STATE(112),
    [sym_cast_expression] = STATE(112),
    [sym_sizeof_expression] = STATE(112),
    [sym_string_literal] = STATE(112),
    [sym_char_literal] = STATE(112),
    [anon_sym_RBRACE] = ACTIONS(85),
    [anon_sym_PERCENT] = ACTIONS(87),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_RPAREN] = ACTIONS(85),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(85),
    [anon_sym_COMMA] = ACTIONS(85),
    [anon_sym_EQ] = ACTIONS(87),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(85),
    [anon_sym_RBRACK] = ACTIONS(85),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_DOT] = ACTIONS(87),
    [anon_sym_DASH_GT] = ACTIONS(85),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_SLASH] = ACTIONS(87),
    [anon_sym_PIPE_PIPE] = ACTIONS(85),
    [anon_sym_AMP_AMP] = ACTIONS(85),
    [anon_sym_PIPE] = ACTIONS(87),
    [anon_sym_CARET] = ACTIONS(87),
    [anon_sym_AMP] = ACTIONS(87),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(87),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_LT] = ACTIONS(87),
    [anon_sym_LT_LT] = ACTIONS(87),
    [anon_sym_GT_GT] = ACTIONS(87),
    [anon_sym_QMARK] = ACTIONS(85),
    [anon_sym_COLON] = ACTIONS(85),
    [anon_sym_STAR_EQ] = ACTIONS(85),
    [anon_sym_SLASH_EQ] = ACTIONS(85),
    [anon_sym_PERCENT_EQ] = ACTIONS(85),
    [anon_sym_PLUS_EQ] = ACTIONS(85),
    [anon_sym_DASH_EQ] = ACTIONS(85),
    [anon_sym_LT_LT_EQ] = ACTIONS(85),
    [anon_sym_GT_GT_EQ] = ACTIONS(85),
    [anon_sym_AMP_EQ] = ACTIONS(85),
    [anon_sym_CARET_EQ] = ACTIONS(85),
    [anon_sym_PIPE_EQ] = ACTIONS(85),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(89),
    [sym_false] = ACTIONS(89),
    [sym_null] = ACTIONS(89),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(91),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(89),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(13)] = {
    [sym_basetype] = STATE(423),
    [sym_prim_type] = STATE(525),
    [sym_type_expr] = STATE(716),
    [sym__expr] = STATE(180),
    [sym_parenthesized_expression] = STATE(180),
    [sym_call_expression] = STATE(180),
    [sym_exit_expression] = STATE(180),
    [sym_subscript_expression] = STATE(180),
    [sym_field_expression] = STATE(180),
    [sym_update_expression] = STATE(180),
    [sym_unary_expression] = STATE(180),
    [sym_binary_expression] = STATE(180),
    [sym_conditional_expression] = STATE(180),
    [sym_assignment_expression] = STATE(180),
    [sym_cast_expression] = STATE(180),
    [sym_sizeof_expression] = STATE(180),
    [sym__comma_expr] = STATE(732),
    [sym_comma_expr] = STATE(732),
    [sym_string_literal] = STATE(180),
    [sym_char_literal] = STATE(180),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(93),
    [anon_sym_evflag] = ACTIONS(95),
    [anon_sym_enum] = ACTIONS(93),
    [anon_sym_union] = ACTIONS(93),
    [anon_sym_typename] = ACTIONS(93),
    [anon_sym_void] = ACTIONS(95),
    [anon_sym_char] = ACTIONS(97),
    [anon_sym_short] = ACTIONS(97),
    [anon_sym_int] = ACTIONS(97),
    [anon_sym_long] = ACTIONS(97),
    [anon_sym_unsigned] = ACTIONS(99),
    [anon_sym_int8_t] = ACTIONS(97),
    [anon_sym_uint8_t] = ACTIONS(97),
    [anon_sym_int16_t] = ACTIONS(97),
    [anon_sym_uint16_t] = ACTIONS(97),
    [anon_sym_int32_t] = ACTIONS(97),
    [anon_sym_uint32_t] = ACTIONS(97),
    [anon_sym_float] = ACTIONS(97),
    [anon_sym_double] = ACTIONS(97),
    [anon_sym_string] = ACTIONS(97),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(14)] = {
    [sym_basetype] = STATE(423),
    [sym_prim_type] = STATE(525),
    [sym_type_expr] = STATE(755),
    [sym__expr] = STATE(180),
    [sym_parenthesized_expression] = STATE(180),
    [sym_call_expression] = STATE(180),
    [sym_exit_expression] = STATE(180),
    [sym_subscript_expression] = STATE(180),
    [sym_field_expression] = STATE(180),
    [sym_update_expression] = STATE(180),
    [sym_unary_expression] = STATE(180),
    [sym_binary_expression] = STATE(180),
    [sym_conditional_expression] = STATE(180),
    [sym_assignment_expression] = STATE(180),
    [sym_cast_expression] = STATE(180),
    [sym_sizeof_expression] = STATE(180),
    [sym__comma_expr] = STATE(732),
    [sym_comma_expr] = STATE(732),
    [sym_string_literal] = STATE(180),
    [sym_char_literal] = STATE(180),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(93),
    [anon_sym_evflag] = ACTIONS(95),
    [anon_sym_enum] = ACTIONS(93),
    [anon_sym_union] = ACTIONS(93),
    [anon_sym_typename] = ACTIONS(93),
    [anon_sym_void] = ACTIONS(95),
    [anon_sym_char] = ACTIONS(97),
    [anon_sym_short] = ACTIONS(97),
    [anon_sym_int] = ACTIONS(97),
    [anon_sym_long] = ACTIONS(97),
    [anon_sym_unsigned] = ACTIONS(99),
    [anon_sym_int8_t] = ACTIONS(97),
    [anon_sym_uint8_t] = ACTIONS(97),
    [anon_sym_int16_t] = ACTIONS(97),
    [anon_sym_uint16_t] = ACTIONS(97),
    [anon_sym_int32_t] = ACTIONS(97),
    [anon_sym_uint32_t] = ACTIONS(97),
    [anon_sym_float] = ACTIONS(97),
    [anon_sym_double] = ACTIONS(97),
    [anon_sym_string] = ACTIONS(97),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(15)] = {
    [sym_basetype] = STATE(423),
    [sym_prim_type] = STATE(525),
    [sym_type_expr] = STATE(771),
    [sym__expr] = STATE(180),
    [sym_parenthesized_expression] = STATE(180),
    [sym_call_expression] = STATE(180),
    [sym_exit_expression] = STATE(180),
    [sym_subscript_expression] = STATE(180),
    [sym_field_expression] = STATE(180),
    [sym_update_expression] = STATE(180),
    [sym_unary_expression] = STATE(180),
    [sym_binary_expression] = STATE(180),
    [sym_conditional_expression] = STATE(180),
    [sym_assignment_expression] = STATE(180),
    [sym_cast_expression] = STATE(180),
    [sym_sizeof_expression] = STATE(180),
    [sym__comma_expr] = STATE(732),
    [sym_comma_expr] = STATE(732),
    [sym_string_literal] = STATE(180),
    [sym_char_literal] = STATE(180),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(93),
    [anon_sym_evflag] = ACTIONS(95),
    [anon_sym_enum] = ACTIONS(93),
    [anon_sym_union] = ACTIONS(93),
    [anon_sym_typename] = ACTIONS(93),
    [anon_sym_void] = ACTIONS(95),
    [anon_sym_char] = ACTIONS(97),
    [anon_sym_short] = ACTIONS(97),
    [anon_sym_int] = ACTIONS(97),
    [anon_sym_long] = ACTIONS(97),
    [anon_sym_unsigned] = ACTIONS(99),
    [anon_sym_int8_t] = ACTIONS(97),
    [anon_sym_uint8_t] = ACTIONS(97),
    [anon_sym_int16_t] = ACTIONS(97),
    [anon_sym_uint16_t] = ACTIONS(97),
    [anon_sym_int32_t] = ACTIONS(97),
    [anon_sym_uint32_t] = ACTIONS(97),
    [anon_sym_float] = ACTIONS(97),
    [anon_sym_double] = ACTIONS(97),
    [anon_sym_string] = ACTIONS(97),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(103), 1,
      anon_sym_RBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [109] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(73), 1,
      anon_sym_RBRACE,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [218] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(107), 1,
      anon_sym_RBRACE,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [327] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(109), 1,
      anon_sym_RBRACE,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [436] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(111), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(114), 1,
      anon_sym_RBRACE,
    ACTIONS(116), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(119), 1,
      anon_sym_LPAREN,
    ACTIONS(122), 1,
      anon_sym_exit,
    ACTIONS(125), 1,
      anon_sym_LBRACE,
    ACTIONS(134), 1,
      anon_sym_break,
    ACTIONS(137), 1,
      anon_sym_continue,
    ACTIONS(140), 1,
      anon_sym_if,
    ACTIONS(143), 1,
      anon_sym_while,
    ACTIONS(146), 1,
      anon_sym_for,
    ACTIONS(155), 1,
      anon_sym_sizeof,
    ACTIONS(161), 1,
      sym_number_literal,
    ACTIONS(131), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(149), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(152), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(158), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(128), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(164), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [545] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(77), 1,
      anon_sym_RBRACE,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [654] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(167), 1,
      anon_sym_RBRACE,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [763] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(169), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(174), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(188), 1,
      anon_sym_unsigned,
    STATE(52), 1,
      sym__c_code,
    STATE(55), 1,
      sym_declaration,
    STATE(422), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(182), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(23), 2,
      sym_block_defn,
      aux_sym_block_repeat1,
    ACTIONS(179), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    ACTIONS(177), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(185), 13,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
    ACTIONS(172), 18,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [852] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(69), 1,
      anon_sym_RBRACE,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [961] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(191), 1,
      anon_sym_RBRACE,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1070] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(67), 1,
      anon_sym_RBRACE,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1179] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(83), 1,
      anon_sym_RBRACE,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1288] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(229), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(710), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(255), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1393] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(261), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1498] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(284), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1603] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(230), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(710), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(255), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1708] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(231), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(710), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(255), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1813] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(232), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(710), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(255), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1918] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(233), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(710), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(255), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2023] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(234), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(710), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(255), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2128] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(235), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(710), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(255), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2233] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(236), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(710), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(255), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2338] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(275), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2443] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(276), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2548] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(277), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2653] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(216), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(710), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(255), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2758] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(263), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2863] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(211), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(710), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(255), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2968] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(272), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [3073] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(258), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [3178] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(287), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [3283] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(291), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(772), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(271), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [3388] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(226), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(710), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(255), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [3493] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(228), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(710), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(255), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [3598] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(209), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(211), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [3659] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(213), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(215), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [3720] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(217), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(219), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [3781] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(217), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(219), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [3842] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(221), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(223), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [3903] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(217), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(219), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [3964] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(225), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(227), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [4025] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(229), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(231), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [4086] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(237), 1,
      anon_sym_LPAREN,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(263), 1,
      anon_sym_ss,
    STATE(69), 1,
      sym_program_param,
    STATE(421), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(584), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(67), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(72), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(307), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4187] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(237), 1,
      anon_sym_LPAREN,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(265), 1,
      anon_sym_ss,
    STATE(64), 1,
      sym_program_param,
    STATE(421), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(632), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(63), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(77), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(307), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4288] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(237), 1,
      anon_sym_LPAREN,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(267), 1,
      anon_sym_ss,
    STATE(65), 1,
      sym_program_param,
    STATE(421), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(642), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(62), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(80), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(307), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4389] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(265), 1,
      anon_sym_ss,
    STATE(421), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(630), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(74), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(87), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(307), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4484] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(267), 1,
      anon_sym_ss,
    STATE(421), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(615), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(74), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(84), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(307), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4579] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(265), 1,
      anon_sym_ss,
    STATE(421), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(631), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(74), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(85), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(307), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4674] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(265), 1,
      anon_sym_ss,
    STATE(421), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(631), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(61), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(85), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(307), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4769] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(267), 1,
      anon_sym_ss,
    STATE(421), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(615), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(66), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(84), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(307), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4864] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(267), 1,
      anon_sym_ss,
    STATE(421), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(620), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(74), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(83), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(307), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4959] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(263), 1,
      anon_sym_ss,
    STATE(421), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(593), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(73), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    STATE(74), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(307), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5054] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(263), 1,
      anon_sym_ss,
    STATE(421), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(598), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(70), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    STATE(74), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(307), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5149] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(263), 1,
      anon_sym_ss,
    STATE(421), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(593), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(68), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(73), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(307), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5244] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(263), 1,
      anon_sym_ss,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(275), 1,
      anon_sym_program,
    ACTIONS(277), 1,
      anon_sym_exit,
    ACTIONS(279), 1,
      anon_sym_struct,
    STATE(144), 1,
      sym_exit,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(145), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(203), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(279), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5329] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(263), 1,
      anon_sym_ss,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(277), 1,
      anon_sym_exit,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(283), 1,
      anon_sym_program,
    STATE(147), 1,
      sym_exit,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(146), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(203), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(279), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(281), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5414] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(263), 1,
      anon_sym_ss,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(277), 1,
      anon_sym_exit,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(287), 1,
      anon_sym_program,
    STATE(151), 1,
      sym_exit,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(140), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(203), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(279), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(285), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5499] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(263), 1,
      anon_sym_ss,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(277), 1,
      anon_sym_exit,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(291), 1,
      anon_sym_program,
    STATE(141), 1,
      sym_exit,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(142), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(203), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(279), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5584] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(296), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(301), 1,
      anon_sym_struct,
    ACTIONS(304), 1,
      anon_sym_foreign,
    ACTIONS(316), 1,
      anon_sym_int,
    ACTIONS(319), 1,
      anon_sym_unsigned,
    ACTIONS(322), 1,
      anon_sym_assign,
    ACTIONS(325), 1,
      anon_sym_monitor,
    ACTIONS(328), 1,
      anon_sym_sync,
    ACTIONS(331), 1,
      anon_sym_syncq,
    ACTIONS(334), 1,
      anon_sym_option,
    STATE(421), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(299), 2,
      anon_sym_entry,
      anon_sym_ss,
    ACTIONS(307), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(74), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    ACTIONS(310), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(307), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(313), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5670] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(337), 1,
      anon_sym_RBRACE,
    ACTIONS(339), 1,
      anon_sym_exit,
    ACTIONS(341), 1,
      anon_sym_when,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(513), 1,
      sym_entry,
    STATE(740), 1,
      sym_exit,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(78), 2,
      sym_state_defn,
      aux_sym_state_block_repeat1,
    STATE(514), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(308), 6,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5759] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(345), 9,
      anon_sym_POUND,
      anon_sym_int,
      anon_sym_sync,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(343), 34,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [5810] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(265), 1,
      anon_sym_ss,
    ACTIONS(339), 1,
      anon_sym_exit,
    STATE(191), 1,
      sym_exit,
    STATE(445), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(287), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(195), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(214), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(285), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5893] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(339), 1,
      anon_sym_exit,
    ACTIONS(341), 1,
      anon_sym_when,
    ACTIONS(347), 1,
      anon_sym_RBRACE,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(518), 1,
      sym_entry,
    STATE(800), 1,
      sym_exit,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(169), 2,
      sym_state_defn,
      aux_sym_state_block_repeat1,
    STATE(517), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(308), 6,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(351), 9,
      anon_sym_POUND,
      anon_sym_int,
      anon_sym_sync,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(349), 34,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [6033] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(267), 1,
      anon_sym_ss,
    ACTIONS(287), 1,
      anon_sym_program,
    ACTIONS(353), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(355), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(357), 1,
      anon_sym_exit,
    ACTIONS(359), 1,
      anon_sym_struct,
    STATE(184), 1,
      sym_exit,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(185), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(213), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(295), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(285), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [6116] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(267), 1,
      anon_sym_ss,
    ACTIONS(283), 1,
      anon_sym_program,
    ACTIONS(353), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(355), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(357), 1,
      anon_sym_exit,
    ACTIONS(359), 1,
      anon_sym_struct,
    STATE(193), 1,
      sym_exit,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(192), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(213), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(295), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(281), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [6199] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(265), 1,
      anon_sym_ss,
    ACTIONS(339), 1,
      anon_sym_exit,
    STATE(196), 1,
      sym_exit,
    STATE(445), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(283), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(201), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(214), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(281), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [6282] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(267), 1,
      anon_sym_ss,
    ACTIONS(275), 1,
      anon_sym_program,
    ACTIONS(353), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(355), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(357), 1,
      anon_sym_exit,
    ACTIONS(359), 1,
      anon_sym_struct,
    STATE(189), 1,
      sym_exit,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(190), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(213), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(295), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [6365] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(267), 1,
      anon_sym_ss,
    ACTIONS(291), 1,
      anon_sym_program,
    ACTIONS(353), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(355), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(357), 1,
      anon_sym_exit,
    ACTIONS(359), 1,
      anon_sym_struct,
    STATE(186), 1,
      sym_exit,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(187), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(213), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(295), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [6448] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(265), 1,
      anon_sym_ss,
    ACTIONS(339), 1,
      anon_sym_exit,
    STATE(182), 1,
      sym_exit,
    STATE(445), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(291), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(199), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(214), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [6531] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 9,
      anon_sym_POUND,
      anon_sym_int,
      anon_sym_sync,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(361), 34,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [6582] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(265), 1,
      anon_sym_ss,
    ACTIONS(339), 1,
      anon_sym_exit,
    STATE(200), 1,
      sym_exit,
    STATE(445), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(275), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(183), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(214), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [6665] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(367), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(365), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [6715] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(369), 1,
      anon_sym_SEMI,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(837), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [6787] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(373), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(371), 28,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [6839] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(377), 1,
      anon_sym_SEMI,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(738), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [6911] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(381), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(379), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [6965] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(389), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(385), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7025] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(397), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(395), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7075] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(399), 1,
      anon_sym_RBRACE,
    ACTIONS(401), 1,
      anon_sym_LPAREN,
    ACTIONS(403), 1,
      anon_sym_LBRACE,
    ACTIONS(407), 1,
      sym_number_literal,
    STATE(597), 1,
      sym_init_expr,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(405), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(171), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [7149] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(411), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(409), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7199] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(413), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7249] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(417), 1,
      anon_sym_SEMI,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(722), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [7321] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(421), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(419), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7375] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(425), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(423), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7425] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(429), 1,
      anon_sym_EQ,
    ACTIONS(431), 1,
      anon_sym_LBRACK,
    ACTIONS(435), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(437), 1,
      anon_sym_AMP_AMP,
    ACTIONS(439), 1,
      anon_sym_PIPE,
    ACTIONS(441), 1,
      anon_sym_CARET,
    ACTIONS(443), 1,
      anon_sym_AMP,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(433), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(427), 7,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_COLON,
    ACTIONS(451), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7507] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(421), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(419), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(455), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(453), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7613] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(421), 1,
      anon_sym_EQ,
    ACTIONS(437), 1,
      anon_sym_AMP_AMP,
    ACTIONS(439), 1,
      anon_sym_PIPE,
    ACTIONS(441), 1,
      anon_sym_CARET,
    ACTIONS(443), 1,
      anon_sym_AMP,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(419), 21,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7687] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(421), 1,
      anon_sym_EQ,
    ACTIONS(439), 1,
      anon_sym_PIPE,
    ACTIONS(441), 1,
      anon_sym_CARET,
    ACTIONS(443), 1,
      anon_sym_AMP,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(419), 22,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7759] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(441), 1,
      anon_sym_CARET,
    ACTIONS(443), 1,
      anon_sym_AMP,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(421), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(419), 22,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7829] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(443), 1,
      anon_sym_AMP,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(421), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(419), 22,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7897] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(421), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(419), 22,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7963] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(421), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(419), 24,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8027] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(421), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(419), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8087] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(421), 8,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(419), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8145] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(459), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(457), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8199] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(463), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(461), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8249] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(465), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(724), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [8321] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(467), 1,
      anon_sym_SEMI,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(727), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [8393] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(469), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8443] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(475), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(473), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8493] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(477), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(782), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [8565] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(479), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(784), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [8637] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(429), 1,
      anon_sym_EQ,
    ACTIONS(431), 1,
      anon_sym_LBRACK,
    ACTIONS(435), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(437), 1,
      anon_sym_AMP_AMP,
    ACTIONS(439), 1,
      anon_sym_PIPE,
    ACTIONS(441), 1,
      anon_sym_CARET,
    ACTIONS(443), 1,
      anon_sym_AMP,
    ACTIONS(483), 1,
      anon_sym_QMARK,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(433), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(481), 6,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(451), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8721] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(401), 1,
      anon_sym_LPAREN,
    ACTIONS(403), 1,
      anon_sym_LBRACE,
    ACTIONS(407), 1,
      sym_number_literal,
    ACTIONS(485), 1,
      anon_sym_RBRACE,
    STATE(637), 1,
      sym_init_expr,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(405), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(171), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [8795] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(487), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(834), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [8867] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(489), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(838), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [8939] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(493), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(491), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8989] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(495), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [9039] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(499), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(807), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9111] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(501), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(810), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9183] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(503), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(811), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9255] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(505), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(813), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9327] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(507), 1,
      anon_sym_SEMI,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(835), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9399] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(509), 1,
      anon_sym_SEMI,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(845), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9471] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(401), 1,
      anon_sym_LPAREN,
    ACTIONS(403), 1,
      anon_sym_LBRACE,
    ACTIONS(407), 1,
      sym_number_literal,
    STATE(673), 1,
      sym_init_expr,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(405), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(171), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9542] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(401), 1,
      anon_sym_LPAREN,
    ACTIONS(403), 1,
      anon_sym_LBRACE,
    ACTIONS(407), 1,
      sym_number_literal,
    STATE(670), 1,
      sym_init_expr,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(405), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(171), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9613] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(695), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9682] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(819), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9751] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(511), 1,
      anon_sym_RPAREN,
    ACTIONS(515), 1,
      sym_number_literal,
    STATE(763), 1,
      sym_args,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(513), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(173), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9822] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(804), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9891] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(515), 1,
      sym_number_literal,
    ACTIONS(517), 1,
      anon_sym_RPAREN,
    STATE(803), 1,
      sym_args,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(513), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(173), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9962] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(833), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(180), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [10031] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(291), 1,
      anon_sym_program,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(143), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(279), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10103] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(275), 1,
      anon_sym_program,
    ACTIONS(279), 1,
      anon_sym_struct,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(145), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(279), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10175] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(275), 1,
      anon_sym_program,
    ACTIONS(279), 1,
      anon_sym_struct,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(143), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(279), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10247] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(519), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(522), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(527), 1,
      anon_sym_program,
    ACTIONS(529), 1,
      anon_sym_struct,
    ACTIONS(541), 1,
      anon_sym_int,
    ACTIONS(544), 1,
      anon_sym_unsigned,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(532), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(143), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(535), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(279), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(525), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(538), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10319] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(283), 1,
      anon_sym_program,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(146), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(279), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(281), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10391] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(283), 1,
      anon_sym_program,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(143), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(279), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(281), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10463] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(549), 1,
      anon_sym_program,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(143), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(279), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(547), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10535] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(549), 1,
      anon_sym_program,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(148), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(279), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(547), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10607] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(553), 1,
      anon_sym_program,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(143), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(279), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(551), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10679] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(429), 1,
      anon_sym_EQ,
    ACTIONS(431), 1,
      anon_sym_LBRACK,
    ACTIONS(435), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(437), 1,
      anon_sym_AMP_AMP,
    ACTIONS(439), 1,
      anon_sym_PIPE,
    ACTIONS(441), 1,
      anon_sym_CARET,
    ACTIONS(443), 1,
      anon_sym_AMP,
    ACTIONS(483), 1,
      anon_sym_QMARK,
    ACTIONS(557), 1,
      anon_sym_COMMA,
    STATE(555), 1,
      aux_sym_comma_expr_repeat1,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(433), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(555), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(451), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [10765] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(91), 1,
      sym_number_literal,
    ACTIONS(559), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(112), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [10833] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(291), 1,
      anon_sym_program,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(142), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(279), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10905] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(563), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(561), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(99), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [10970] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(567), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(565), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(202), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11035] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(571), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(569), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(102), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11100] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(575), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(573), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(104), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11165] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(577), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(105), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11230] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(39), 1,
      anon_sym_unsigned,
    ACTIONS(581), 1,
      anon_sym_LPAREN,
    ACTIONS(583), 1,
      anon_sym_RPAREN,
    ACTIONS(585), 1,
      anon_sym_STAR,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(591), 1,
      sym_identifier,
    STATE(417), 1,
      sym_basetype,
    STATE(418), 1,
      sym_type_qualifier,
    STATE(496), 1,
      sym_prim_type,
    STATE(590), 1,
      sym_param_decl,
    STATE(677), 1,
      sym_type_expr,
    ACTIONS(35), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(31), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(551), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
    STATE(574), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
    ACTIONS(37), 13,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [11307] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(595), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(593), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(106), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11372] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(599), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(597), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(167), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11437] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(603), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(601), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(107), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11502] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(607), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(605), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(108), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11567] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(611), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(609), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(109), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11632] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(615), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(613), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(110), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11697] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(619), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(617), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(111), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11762] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(623), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(621), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(120), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11827] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(627), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(625), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(204), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11892] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(429), 1,
      anon_sym_EQ,
    ACTIONS(431), 1,
      anon_sym_LBRACK,
    ACTIONS(435), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(437), 1,
      anon_sym_AMP_AMP,
    ACTIONS(439), 1,
      anon_sym_PIPE,
    ACTIONS(441), 1,
      anon_sym_CARET,
    ACTIONS(443), 1,
      anon_sym_AMP,
    ACTIONS(483), 1,
      anon_sym_QMARK,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(433), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(629), 3,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(451), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [11973] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 9,
      anon_sym_POUND,
      anon_sym_int,
      anon_sym_sync,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(631), 30,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [12020] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(646), 1,
      anon_sym_int,
    ACTIONS(649), 1,
      anon_sym_unsigned,
    ACTIONS(652), 1,
      anon_sym_assign,
    ACTIONS(655), 1,
      anon_sym_monitor,
    ACTIONS(658), 1,
      anon_sym_sync,
    ACTIONS(661), 1,
      anon_sym_syncq,
    ACTIONS(664), 1,
      anon_sym_option,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(640), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(169), 2,
      sym_state_defn,
      aux_sym_state_block_repeat1,
    ACTIONS(635), 4,
      anon_sym_RBRACE,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_when,
    ACTIONS(637), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(308), 6,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(643), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [12093] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(211), 9,
      anon_sym_POUND,
      anon_sym_int,
      anon_sym_sync,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(209), 30,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [12140] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(429), 1,
      anon_sym_EQ,
    ACTIONS(431), 1,
      anon_sym_LBRACK,
    ACTIONS(435), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(437), 1,
      anon_sym_AMP_AMP,
    ACTIONS(439), 1,
      anon_sym_PIPE,
    ACTIONS(441), 1,
      anon_sym_CARET,
    ACTIONS(443), 1,
      anon_sym_AMP,
    ACTIONS(483), 1,
      anon_sym_QMARK,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(433), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(667), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(451), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [12221] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(91), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(112), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12286] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(429), 1,
      anon_sym_EQ,
    ACTIONS(431), 1,
      anon_sym_LBRACK,
    ACTIONS(435), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(437), 1,
      anon_sym_AMP_AMP,
    ACTIONS(439), 1,
      anon_sym_PIPE,
    ACTIONS(441), 1,
      anon_sym_CARET,
    ACTIONS(443), 1,
      anon_sym_AMP,
    ACTIONS(483), 1,
      anon_sym_QMARK,
    ACTIONS(557), 1,
      anon_sym_COMMA,
    ACTIONS(669), 1,
      anon_sym_RPAREN,
    STATE(613), 1,
      aux_sym_comma_expr_repeat1,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(433), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(451), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [12371] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(227), 9,
      anon_sym_POUND,
      anon_sym_int,
      anon_sym_sync,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(225), 30,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [12418] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(673), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(671), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(90), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12483] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(677), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(675), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(92), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12548] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(679), 1,
      anon_sym_LPAREN,
    ACTIONS(683), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(681), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(93), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12613] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(687), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(685), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(101), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12678] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(691), 9,
      anon_sym_POUND,
      anon_sym_int,
      anon_sym_sync,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(689), 30,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [12725] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(429), 1,
      anon_sym_EQ,
    ACTIONS(431), 1,
      anon_sym_LBRACK,
    ACTIONS(435), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(437), 1,
      anon_sym_AMP_AMP,
    ACTIONS(439), 1,
      anon_sym_PIPE,
    ACTIONS(441), 1,
      anon_sym_CARET,
    ACTIONS(443), 1,
      anon_sym_AMP,
    ACTIONS(483), 1,
      anon_sym_QMARK,
    ACTIONS(695), 1,
      anon_sym_COMMA,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(433), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(693), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(451), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [12808] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(699), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(697), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(149), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12873] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(445), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(275), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(183), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [12943] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(445), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(283), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(197), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(281), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13013] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(291), 1,
      anon_sym_program,
    ACTIONS(353), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(355), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(359), 1,
      anon_sym_struct,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(187), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(295), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13083] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(291), 1,
      anon_sym_program,
    ACTIONS(353), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(355), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(359), 1,
      anon_sym_struct,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(188), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(295), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13153] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(275), 1,
      anon_sym_program,
    ACTIONS(353), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(355), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(359), 1,
      anon_sym_struct,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(190), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(295), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13223] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(275), 1,
      anon_sym_program,
    ACTIONS(353), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(355), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(359), 1,
      anon_sym_struct,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(188), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(295), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13293] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(527), 1,
      anon_sym_program,
    ACTIONS(541), 1,
      anon_sym_int,
    ACTIONS(544), 1,
      anon_sym_unsigned,
    ACTIONS(701), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(704), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(707), 1,
      anon_sym_struct,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(532), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(188), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(535), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(295), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(525), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(538), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13363] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(283), 1,
      anon_sym_program,
    ACTIONS(353), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(355), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(359), 1,
      anon_sym_struct,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(192), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(295), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(281), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13433] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(283), 1,
      anon_sym_program,
    ACTIONS(353), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(355), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(359), 1,
      anon_sym_struct,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(188), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(295), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(281), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13503] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(445), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(291), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(199), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13573] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(353), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(355), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(359), 1,
      anon_sym_struct,
    ACTIONS(549), 1,
      anon_sym_program,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(188), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(295), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(547), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13643] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(353), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(355), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(359), 1,
      anon_sym_struct,
    ACTIONS(549), 1,
      anon_sym_program,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(194), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(295), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(547), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13713] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(353), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(355), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(359), 1,
      anon_sym_struct,
    ACTIONS(553), 1,
      anon_sym_program,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(188), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(295), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(551), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13783] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(445), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(291), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(197), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13853] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(445), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(549), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(198), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(547), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13923] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(541), 1,
      anon_sym_int,
    ACTIONS(544), 1,
      anon_sym_unsigned,
    ACTIONS(710), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(713), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(716), 1,
      anon_sym_struct,
    STATE(445), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(527), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(532), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(197), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(535), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(525), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(538), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13993] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(445), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(553), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(197), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(551), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14063] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(445), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(275), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(197), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14133] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(445), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(283), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(201), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(281), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14203] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(445), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(549), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(197), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(547), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14273] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(429), 1,
      anon_sym_EQ,
    ACTIONS(431), 1,
      anon_sym_LBRACK,
    ACTIONS(435), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(437), 1,
      anon_sym_AMP_AMP,
    ACTIONS(439), 1,
      anon_sym_PIPE,
    ACTIONS(441), 1,
      anon_sym_CARET,
    ACTIONS(443), 1,
      anon_sym_AMP,
    ACTIONS(483), 1,
      anon_sym_QMARK,
    ACTIONS(719), 1,
      anon_sym_RBRACK,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(433), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(451), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [14352] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(725), 1,
      anon_sym_ss,
    STATE(203), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(723), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(721), 23,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14401] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(429), 1,
      anon_sym_EQ,
    ACTIONS(431), 1,
      anon_sym_LBRACK,
    ACTIONS(435), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(437), 1,
      anon_sym_AMP_AMP,
    ACTIONS(439), 1,
      anon_sym_PIPE,
    ACTIONS(441), 1,
      anon_sym_CARET,
    ACTIONS(443), 1,
      anon_sym_AMP,
    ACTIONS(483), 1,
      anon_sym_QMARK,
    ACTIONS(728), 1,
      anon_sym_COLON,
    ACTIONS(383), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(391), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(393), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(433), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(449), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(387), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(451), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [14480] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(730), 1,
      anon_sym_state,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(222), 2,
      sym_ss_defn,
      aux_sym_state_set_repeat1,
    STATE(570), 2,
      sym_state,
      aux_sym_state_set_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(311), 5,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14550] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(730), 1,
      anon_sym_state,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(205), 2,
      sym_ss_defn,
      aux_sym_state_set_repeat1,
    STATE(569), 2,
      sym_state,
      aux_sym_state_set_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(311), 5,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14620] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(730), 1,
      anon_sym_state,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(222), 2,
      sym_ss_defn,
      aux_sym_state_set_repeat1,
    STATE(547), 2,
      sym_state,
      aux_sym_state_set_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(311), 5,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14690] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(730), 1,
      anon_sym_state,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(207), 2,
      sym_ss_defn,
      aux_sym_state_set_repeat1,
    STATE(571), 2,
      sym_state,
      aux_sym_state_set_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(311), 5,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14760] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(730), 1,
      anon_sym_state,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(222), 2,
      sym_ss_defn,
      aux_sym_state_set_repeat1,
    STATE(565), 2,
      sym_state,
      aux_sym_state_set_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(311), 5,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14830] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(730), 1,
      anon_sym_state,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(209), 2,
      sym_ss_defn,
      aux_sym_state_set_repeat1,
    STATE(564), 2,
      sym_state,
      aux_sym_state_set_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(311), 5,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14900] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(736), 1,
      anon_sym_else,
    STATE(283), 1,
      sym_else_statement,
    ACTIONS(734), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(732), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [14947] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(740), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(738), 24,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_ss,
  [14990] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(742), 1,
      anon_sym_ss,
    STATE(213), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(723), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(721), 23,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [15037] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(745), 1,
      anon_sym_ss,
    STATE(214), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(723), 8,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(721), 24,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [15084] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(748), 24,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_ss,
  [15127] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(752), 1,
      anon_sym_else,
    STATE(217), 1,
      sym_else_statement,
    ACTIONS(734), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(732), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15174] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(756), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(754), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15216] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(760), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(758), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15258] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(764), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(762), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15300] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(766), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15342] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(583), 1,
      anon_sym_RPAREN,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(770), 1,
      anon_sym_LPAREN,
    ACTIONS(772), 1,
      anon_sym_STAR,
    ACTIONS(774), 1,
      anon_sym_const,
    STATE(417), 1,
      sym_basetype,
    STATE(447), 1,
      sym_type_qualifier,
    STATE(496), 1,
      sym_prim_type,
    STATE(590), 1,
      sym_param_decl,
    STATE(677), 1,
      sym_type_expr,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(551), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [15412] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(785), 1,
      anon_sym_int,
    ACTIONS(788), 1,
      anon_sym_unsigned,
    ACTIONS(791), 1,
      anon_sym_assign,
    ACTIONS(794), 1,
      anon_sym_monitor,
    ACTIONS(797), 1,
      anon_sym_sync,
    ACTIONS(800), 1,
      anon_sym_syncq,
    ACTIONS(803), 1,
      anon_sym_state,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(779), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(222), 2,
      sym_ss_defn,
      aux_sym_state_set_repeat1,
    ACTIONS(776), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(311), 5,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
    ACTIONS(782), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [15478] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(223), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(221), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15520] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(807), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(805), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15562] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(811), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(809), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15604] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(815), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(813), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15646] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(819), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(817), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15688] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(823), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(821), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15730] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(827), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(825), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15772] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(831), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(829), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15814] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(835), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(833), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15856] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(839), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(837), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15898] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(843), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(841), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15940] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(847), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(845), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(851), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(849), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16024] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(855), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(853), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16066] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(859), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(857), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16108] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(863), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(861), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16150] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(867), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(865), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16192] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(351), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(349), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16234] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(871), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(869), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16276] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(345), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(343), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16318] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(875), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(873), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16360] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(879), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(877), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16402] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(361), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16444] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(883), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(881), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(211), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(209), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16528] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(227), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(225), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16570] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(887), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(885), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16612] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(891), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(889), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16654] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(893), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16696] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(231), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(229), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16738] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(899), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(897), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16780] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(903), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(901), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16822] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(907), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(905), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16864] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(215), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(213), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(911), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(909), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16948] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(839), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(837), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16989] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(748), 24,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_ss,
  [17030] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(915), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(913), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17071] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(827), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(825), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17112] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(740), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(738), 24,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_ss,
  [17153] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(831), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(829), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17194] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(345), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(343), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17235] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(766), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17276] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(351), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(349), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17317] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(345), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(343), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17358] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(361), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17399] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(211), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(209), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17440] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(227), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(225), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(907), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(905), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17522] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(835), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(833), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(911), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(909), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17604] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(764), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(762), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17645] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(847), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(845), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17686] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(851), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(849), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17727] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(855), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(853), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17768] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(227), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(225), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17809] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(919), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(917), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17850] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(631), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17891] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(740), 8,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(738), 25,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_ss,
  [17932] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(361), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17973] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(756), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(754), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [18014] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(823), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(821), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [18055] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 8,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(748), 25,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_ss,
  [18096] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(351), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(349), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [18137] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(815), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(813), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [18178] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(211), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(209), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [18219] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(923), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(921), 31,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_when,
  [18260] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(691), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(689), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18301] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(843), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(841), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [18342] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(915), 8,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(913), 24,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18382] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(227), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(225), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18421] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(211), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(209), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18460] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(919), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(917), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(919), 8,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(917), 23,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18538] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(691), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(689), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18577] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(915), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(913), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18616] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(631), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18655] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(351), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(349), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18694] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(345), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(343), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18733] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(361), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18772] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(927), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(925), 28,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [18810] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(931), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(929), 28,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [18848] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(933), 28,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [18886] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(939), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(937), 28,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [18924] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(943), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(941), 28,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [18962] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(947), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(945), 27,
      anon_sym_RBRACE,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_when,
  [18999] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(949), 1,
      anon_sym_RBRACE,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(313), 2,
      sym_member_decl,
      aux_sym_field_declaration_list_repeat1,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [19046] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(951), 1,
      anon_sym_RPAREN,
    STATE(417), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(596), 1,
      sym_param_decl,
    STATE(677), 1,
      sym_type_expr,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [19095] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(955), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(953), 23,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_state,
  [19128] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(957), 1,
      anon_sym_RPAREN,
    STATE(417), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(609), 1,
      sym_param_decl,
    STATE(677), 1,
      sym_type_expr,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [19177] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(959), 1,
      anon_sym_RBRACE,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(314), 2,
      sym_member_decl,
      aux_sym_field_declaration_list_repeat1,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [19224] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(961), 1,
      anon_sym_RBRACE,
    ACTIONS(972), 1,
      anon_sym_int,
    ACTIONS(975), 1,
      anon_sym_unsigned,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(966), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(314), 2,
      sym_member_decl,
      aux_sym_field_declaration_list_repeat1,
    ACTIONS(963), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    ACTIONS(969), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [19271] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(417), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(658), 1,
      sym_param_decl,
    STATE(677), 1,
      sym_type_expr,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [19317] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(988), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(707), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(335), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19368] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(998), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(836), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(316), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19419] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1000), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(806), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(329), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19470] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1002), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(705), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(320), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19521] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1004), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(718), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(335), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19572] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1006), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(764), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(335), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19623] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1008), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(751), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(324), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19674] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1010), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(760), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(325), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19725] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1012), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(762), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(335), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19776] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1014), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(768), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(335), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19827] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1016), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(769), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(321), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19878] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1018), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(825), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(328), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19929] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1020), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(832), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(335), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19980] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1022), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(802), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(335), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [20031] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1026), 1,
      anon_sym_LPAREN,
    STATE(359), 1,
      sym_preproc_argument_list,
    ACTIONS(1028), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1024), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20065] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1032), 1,
      anon_sym_RPAREN,
    ACTIONS(1038), 1,
      sym_number_literal,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(332), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20108] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1048), 1,
      anon_sym_RPAREN,
    ACTIONS(1050), 1,
      anon_sym_COMMA,
    ACTIONS(1054), 1,
      anon_sym_SLASH,
    ACTIONS(1056), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1058), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1060), 1,
      anon_sym_PIPE,
    ACTIONS(1062), 1,
      anon_sym_CARET,
    ACTIONS(1064), 1,
      anon_sym_AMP,
    STATE(600), 1,
      aux_sym_preproc_argument_list_repeat1,
    ACTIONS(1046), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1052), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1066), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1068), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1070), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1072), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20163] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1074), 1,
      anon_sym_RPAREN,
    ACTIONS(1076), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(334), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20206] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1050), 1,
      anon_sym_COMMA,
    ACTIONS(1054), 1,
      anon_sym_SLASH,
    ACTIONS(1056), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1058), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1060), 1,
      anon_sym_PIPE,
    ACTIONS(1062), 1,
      anon_sym_CARET,
    ACTIONS(1064), 1,
      anon_sym_AMP,
    ACTIONS(1078), 1,
      anon_sym_RPAREN,
    STATE(621), 1,
      aux_sym_preproc_argument_list_repeat1,
    ACTIONS(1046), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1052), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1066), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1068), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1070), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1072), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20261] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1080), 1,
      anon_sym_POUND,
    ACTIONS(1083), 1,
      anon_sym_program,
    ACTIONS(1086), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(1089), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(1092), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(1100), 1,
      sym_preproc_directive,
    ACTIONS(1097), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    ACTIONS(1095), 3,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(335), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [20304] = 5,
    ACTIONS(1024), 1,
      anon_sym_LF,
    ACTIONS(1103), 1,
      anon_sym_LPAREN,
    ACTIONS(1105), 1,
      sym_comment,
    STATE(389), 1,
      sym_preproc_argument_list,
    ACTIONS(1028), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20337] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1109), 1,
      anon_sym_int,
    ACTIONS(1107), 20,
      anon_sym_RBRACE,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [20366] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 1,
      anon_sym_SLASH,
    ACTIONS(1064), 1,
      anon_sym_AMP,
    ACTIONS(1113), 1,
      anon_sym_PIPE,
    ACTIONS(1046), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1052), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1066), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1068), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1070), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1072), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1111), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
  [20410] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 1,
      anon_sym_SLASH,
    ACTIONS(1060), 1,
      anon_sym_PIPE,
    ACTIONS(1062), 1,
      anon_sym_CARET,
    ACTIONS(1064), 1,
      anon_sym_AMP,
    ACTIONS(1046), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1052), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1066), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1068), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1070), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1072), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1111), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
  [20456] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 1,
      anon_sym_SLASH,
    ACTIONS(1062), 1,
      anon_sym_CARET,
    ACTIONS(1064), 1,
      anon_sym_AMP,
    ACTIONS(1113), 1,
      anon_sym_PIPE,
    ACTIONS(1046), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1052), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1066), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1068), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1070), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1072), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1111), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
  [20502] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1117), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1115), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20530] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 1,
      anon_sym_SLASH,
    ACTIONS(1046), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1052), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1066), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1068), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1070), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1072), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1113), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1111), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
  [20572] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1119), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(362), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20612] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1121), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(339), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20652] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1123), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(340), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20692] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1125), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(338), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20732] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 1,
      anon_sym_SLASH,
    ACTIONS(1046), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1052), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1068), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1070), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1072), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1113), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1111), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [20772] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1127), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(360), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20812] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1129), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(342), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20852] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 1,
      anon_sym_SLASH,
    ACTIONS(1046), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1052), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1072), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1113), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1111), 9,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [20888] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 1,
      anon_sym_SLASH,
    ACTIONS(1046), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1052), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1113), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1111), 11,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20922] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1131), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(347), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20962] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1139), 1,
      sym_number_literal,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(404), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21002] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1147), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(350), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21042] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1149), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(351), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21082] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1151), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(391), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21122] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1153), 1,
      sym_number_literal,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(412), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21162] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1155), 1,
      sym_number_literal,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(390), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21202] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1159), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1157), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [21230] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1163), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1161), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [21258] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1167), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1165), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [21286] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 1,
      anon_sym_SLASH,
    ACTIONS(1058), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1060), 1,
      anon_sym_PIPE,
    ACTIONS(1062), 1,
      anon_sym_CARET,
    ACTIONS(1064), 1,
      anon_sym_AMP,
    ACTIONS(1046), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1052), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1066), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1068), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1070), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1072), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1111), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
  [21334] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1169), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(385), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21374] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1171), 1,
      sym_number_literal,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(401), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21414] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1173), 1,
      sym_number_literal,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(405), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21454] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 1,
      anon_sym_SLASH,
    ACTIONS(1056), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1058), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1060), 1,
      anon_sym_PIPE,
    ACTIONS(1062), 1,
      anon_sym_CARET,
    ACTIONS(1064), 1,
      anon_sym_AMP,
    ACTIONS(1046), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1052), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1066), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1068), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1070), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1072), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1175), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [21504] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1177), 1,
      sym_number_literal,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(402), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21544] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1179), 1,
      sym_number_literal,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(416), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21584] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1183), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1181), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [21612] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1185), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(396), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21652] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1187), 1,
      sym_number_literal,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(406), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21692] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1189), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [21720] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1193), 1,
      sym_number_literal,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(407), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21760] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1195), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [21788] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1201), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1199), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [21816] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1203), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(366), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21856] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1205), 1,
      sym_number_literal,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(403), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21896] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1207), 1,
      sym_number_literal,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(408), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21936] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1209), 1,
      sym_number_literal,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(415), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21976] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1211), 1,
      sym_number_literal,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(409), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [22016] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1213), 1,
      sym_number_literal,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(400), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [22056] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(495), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22084] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_LPAREN,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1145), 1,
      anon_sym_defined,
    ACTIONS(1215), 1,
      sym_number_literal,
    ACTIONS(1135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1137), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1141), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(388), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [22124] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1113), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1111), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22152] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 1,
      anon_sym_SLASH,
    ACTIONS(1046), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1113), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1111), 13,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22184] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      sym_identifier,
    ACTIONS(1044), 1,
      anon_sym_defined,
    ACTIONS(1217), 1,
      sym_number_literal,
    ACTIONS(1034), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1036), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1040), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(384), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [22224] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1199), 1,
      anon_sym_LF,
    ACTIONS(1201), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22251] = 12,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1221), 1,
      anon_sym_LF,
    ACTIONS(1225), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1227), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1229), 1,
      anon_sym_PIPE,
    ACTIONS(1231), 1,
      anon_sym_CARET,
    ACTIONS(1233), 1,
      anon_sym_AMP,
    ACTIONS(1223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1235), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1239), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1237), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [22296] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1157), 1,
      anon_sym_LF,
    ACTIONS(1159), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22323] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1161), 1,
      anon_sym_LF,
    ACTIONS(1163), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22350] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 1,
      anon_sym_SLASH,
    ACTIONS(1056), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1058), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1060), 1,
      anon_sym_PIPE,
    ACTIONS(1062), 1,
      anon_sym_CARET,
    ACTIONS(1064), 1,
      anon_sym_AMP,
    ACTIONS(1241), 1,
      anon_sym_RPAREN,
    ACTIONS(1046), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1052), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1066), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1068), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1070), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1072), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22399] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1165), 1,
      anon_sym_LF,
    ACTIONS(1167), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22426] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1243), 1,
      anon_sym_POUND,
    ACTIONS(1245), 1,
      anon_sym_program,
    ACTIONS(1247), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(1249), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(1251), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(1253), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(1257), 1,
      sym_preproc_directive,
    ACTIONS(1255), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(411), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [22467] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1195), 1,
      anon_sym_LF,
    ACTIONS(1197), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22494] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1115), 1,
      anon_sym_LF,
    ACTIONS(1117), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22521] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 1,
      anon_sym_SLASH,
    ACTIONS(1056), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1058), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1060), 1,
      anon_sym_PIPE,
    ACTIONS(1062), 1,
      anon_sym_CARET,
    ACTIONS(1064), 1,
      anon_sym_AMP,
    ACTIONS(1259), 1,
      anon_sym_RPAREN,
    ACTIONS(1046), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1052), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1066), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1068), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1070), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1072), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22570] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1181), 1,
      anon_sym_LF,
    ACTIONS(1183), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22597] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1189), 1,
      anon_sym_LF,
    ACTIONS(1191), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22624] = 3,
    ACTIONS(495), 1,
      anon_sym_LF,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(497), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22651] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1113), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22678] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1113), 15,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22707] = 12,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1113), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1227), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1229), 1,
      anon_sym_PIPE,
    ACTIONS(1231), 1,
      anon_sym_CARET,
    ACTIONS(1233), 1,
      anon_sym_AMP,
    ACTIONS(1223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1235), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1239), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1237), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [22752] = 11,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1229), 1,
      anon_sym_PIPE,
    ACTIONS(1231), 1,
      anon_sym_CARET,
    ACTIONS(1233), 1,
      anon_sym_AMP,
    ACTIONS(1113), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(1223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1235), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1239), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1237), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [22795] = 10,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1231), 1,
      anon_sym_CARET,
    ACTIONS(1233), 1,
      anon_sym_AMP,
    ACTIONS(1223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1235), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1239), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1113), 3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1237), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [22836] = 9,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1233), 1,
      anon_sym_AMP,
    ACTIONS(1223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1235), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1239), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1113), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1237), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [22875] = 8,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1235), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1239), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1237), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(1113), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
  [22912] = 7,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1239), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1237), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(1113), 7,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [22947] = 6,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1239), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1113), 11,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [22980] = 5,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1113), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [23011] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1095), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(1261), 1,
      anon_sym_POUND,
    ACTIONS(1264), 1,
      anon_sym_program,
    ACTIONS(1267), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(1270), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(1273), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(1279), 1,
      sym_preproc_directive,
    ACTIONS(1276), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(410), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [23052] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1243), 1,
      anon_sym_POUND,
    ACTIONS(1245), 1,
      anon_sym_program,
    ACTIONS(1247), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(1249), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(1251), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(1257), 1,
      sym_preproc_directive,
    ACTIONS(1282), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(1255), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(410), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [23093] = 12,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1225), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1227), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1229), 1,
      anon_sym_PIPE,
    ACTIONS(1231), 1,
      anon_sym_CARET,
    ACTIONS(1233), 1,
      anon_sym_AMP,
    ACTIONS(1284), 1,
      anon_sym_LF,
    ACTIONS(1223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1235), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1239), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1237), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [23138] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 1,
      ts_builtin_sym_end,
    ACTIONS(1288), 1,
      anon_sym_POUND,
    ACTIONS(1291), 1,
      anon_sym_program,
    ACTIONS(1294), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(1297), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(1300), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(1306), 1,
      sym_preproc_directive,
    ACTIONS(1303), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(413), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [23179] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_POUND,
    ACTIONS(9), 1,
      anon_sym_program,
    ACTIONS(11), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(19), 1,
      sym_preproc_directive,
    ACTIONS(1309), 1,
      ts_builtin_sym_end,
    ACTIONS(17), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(413), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [23220] = 12,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1225), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1227), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1229), 1,
      anon_sym_PIPE,
    ACTIONS(1231), 1,
      anon_sym_CARET,
    ACTIONS(1233), 1,
      anon_sym_AMP,
    ACTIONS(1311), 1,
      anon_sym_LF,
    ACTIONS(1223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1235), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1239), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1237), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [23265] = 12,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1225), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1227), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1229), 1,
      anon_sym_PIPE,
    ACTIONS(1231), 1,
      anon_sym_CARET,
    ACTIONS(1233), 1,
      anon_sym_AMP,
    ACTIONS(1313), 1,
      anon_sym_LF,
    ACTIONS(1223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1235), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1239), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1237), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [23310] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(581), 1,
      anon_sym_LPAREN,
    ACTIONS(585), 1,
      anon_sym_STAR,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1317), 1,
      sym_identifier,
    STATE(418), 1,
      sym_type_qualifier,
    STATE(679), 1,
      sym_declarator,
    STATE(690), 1,
      sym_abs_decl,
    ACTIONS(1315), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(494), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
    STATE(522), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
  [23354] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(581), 1,
      anon_sym_LPAREN,
    ACTIONS(585), 1,
      anon_sym_STAR,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1321), 1,
      sym_identifier,
    STATE(418), 1,
      sym_type_qualifier,
    ACTIONS(1319), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(495), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
    STATE(535), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
  [23392] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(581), 1,
      anon_sym_LPAREN,
    ACTIONS(585), 1,
      anon_sym_STAR,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1325), 1,
      sym_identifier,
    STATE(418), 1,
      sym_type_qualifier,
    ACTIONS(1323), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(491), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
    STATE(528), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
  [23430] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1329), 1,
      anon_sym_SEMI,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(453), 1,
      sym_type_qualifier,
    STATE(577), 1,
      sym_init_declarator,
    STATE(605), 1,
      sym_declarator,
    STATE(494), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [23464] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1329), 1,
      anon_sym_SEMI,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(453), 1,
      sym_type_qualifier,
    STATE(538), 1,
      sym_declarator,
    STATE(577), 1,
      sym_init_declarator,
    STATE(494), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [23498] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    ACTIONS(1333), 1,
      anon_sym_SEMI,
    STATE(453), 1,
      sym_type_qualifier,
    STATE(595), 1,
      sym_init_declarator,
    STATE(605), 1,
      sym_declarator,
    STATE(494), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [23532] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(770), 1,
      anon_sym_LPAREN,
    ACTIONS(772), 1,
      anon_sym_STAR,
    ACTIONS(774), 1,
      anon_sym_const,
    ACTIONS(1315), 1,
      anon_sym_RPAREN,
    STATE(447), 1,
      sym_type_qualifier,
    STATE(690), 1,
      sym_abs_decl,
    STATE(522), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
  [23563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1337), 1,
      anon_sym_program,
    ACTIONS(1335), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23582] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1341), 1,
      anon_sym_program,
    ACTIONS(1339), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23601] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1345), 1,
      anon_sym_program,
    ACTIONS(1343), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23620] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1349), 1,
      anon_sym_program,
    ACTIONS(1347), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23639] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1353), 1,
      anon_sym_program,
    ACTIONS(1351), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1357), 1,
      anon_sym_program,
    ACTIONS(1355), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23677] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1361), 1,
      anon_sym_program,
    ACTIONS(1359), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23696] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1365), 1,
      anon_sym_program,
    ACTIONS(1363), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23715] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1369), 1,
      anon_sym_program,
    ACTIONS(1367), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23734] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1373), 1,
      anon_sym_program,
    ACTIONS(1371), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23753] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1377), 1,
      anon_sym_program,
    ACTIONS(1375), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23772] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1381), 1,
      anon_sym_program,
    ACTIONS(1379), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23791] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 1,
      anon_sym_program,
    ACTIONS(1383), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23810] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1389), 1,
      anon_sym_program,
    ACTIONS(1387), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23829] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(453), 1,
      sym_type_qualifier,
    STATE(605), 1,
      sym_declarator,
    STATE(668), 1,
      sym_init_declarator,
    STATE(494), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [23860] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 1,
      anon_sym_program,
    ACTIONS(1391), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23879] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 1,
      anon_sym_program,
    ACTIONS(1395), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23898] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1401), 1,
      anon_sym_program,
    ACTIONS(1399), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23917] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(453), 1,
      sym_type_qualifier,
    STATE(676), 1,
      sym_declarator,
    STATE(494), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [23945] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(770), 1,
      anon_sym_LPAREN,
    ACTIONS(772), 1,
      anon_sym_STAR,
    ACTIONS(774), 1,
      anon_sym_const,
    ACTIONS(1323), 1,
      anon_sym_RPAREN,
    STATE(447), 1,
      sym_type_qualifier,
    STATE(528), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
  [23973] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(453), 1,
      sym_type_qualifier,
    STATE(714), 1,
      sym_declarator,
    STATE(494), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [24001] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(453), 1,
      sym_type_qualifier,
    STATE(688), 1,
      sym_declarator,
    STATE(494), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [24029] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(453), 1,
      sym_type_qualifier,
    STATE(664), 1,
      sym_declarator,
    STATE(494), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [24057] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(770), 1,
      anon_sym_LPAREN,
    ACTIONS(772), 1,
      anon_sym_STAR,
    ACTIONS(774), 1,
      anon_sym_const,
    ACTIONS(1319), 1,
      anon_sym_RPAREN,
    STATE(447), 1,
      sym_type_qualifier,
    STATE(535), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
  [24085] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1345), 1,
      anon_sym_program,
    ACTIONS(1343), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24102] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 1,
      anon_sym_program,
    ACTIONS(1395), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24119] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1369), 1,
      anon_sym_program,
    ACTIONS(1367), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24136] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1337), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1335), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24153] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1341), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1339), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24170] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1321), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(453), 1,
      sym_type_qualifier,
    STATE(495), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [24195] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1389), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1387), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24212] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1391), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24229] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 1,
      anon_sym_program,
    ACTIONS(1383), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24246] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1377), 1,
      anon_sym_program,
    ACTIONS(1375), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24263] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1365), 1,
      anon_sym_program,
    ACTIONS(1363), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24280] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1369), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1367), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24297] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1381), 1,
      anon_sym_program,
    ACTIONS(1379), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1401), 1,
      anon_sym_program,
    ACTIONS(1399), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24331] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1381), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1379), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24348] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1383), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24365] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1365), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1363), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24382] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1405), 1,
      sym_system_lib_string,
    ACTIONS(1407), 1,
      sym_identifier,
    STATE(756), 2,
      sym_string_literal,
      sym_preproc_call_expression,
    ACTIONS(1403), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
  [24403] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1357), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1355), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24420] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1401), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1399), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24437] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1377), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1375), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24454] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1361), 1,
      anon_sym_program,
    ACTIONS(1359), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24471] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1349), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1347), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24488] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1345), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1343), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24505] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1373), 1,
      anon_sym_program,
    ACTIONS(1371), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24522] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1395), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24539] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1337), 1,
      anon_sym_program,
    ACTIONS(1335), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24556] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1341), 1,
      anon_sym_program,
    ACTIONS(1339), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24573] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1409), 1,
      sym_system_lib_string,
    ACTIONS(1411), 1,
      sym_identifier,
    STATE(737), 2,
      sym_string_literal,
      sym_preproc_call_expression,
    ACTIONS(1403), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
  [24594] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1325), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(453), 1,
      sym_type_qualifier,
    STATE(491), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [24619] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(591), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(453), 1,
      sym_type_qualifier,
    STATE(574), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [24644] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1373), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1371), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24661] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1349), 1,
      anon_sym_program,
    ACTIONS(1347), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24678] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1389), 1,
      anon_sym_program,
    ACTIONS(1387), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24695] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 1,
      anon_sym_program,
    ACTIONS(1391), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24712] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1353), 1,
      anon_sym_program,
    ACTIONS(1351), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24729] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1413), 1,
      sym_system_lib_string,
    ACTIONS(1415), 1,
      sym_identifier,
    STATE(753), 2,
      sym_string_literal,
      sym_preproc_call_expression,
    ACTIONS(1403), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
  [24750] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1353), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1351), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24767] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1361), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1359), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24784] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1417), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_to,
      anon_sym_DQUOTE,
      anon_sym_LBRACK,
  [24799] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1357), 1,
      anon_sym_program,
    ACTIONS(1355), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24816] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1419), 1,
      anon_sym_SEMI,
    ACTIONS(1421), 1,
      anon_sym_to,
    ACTIONS(1423), 1,
      anon_sym_LBRACK,
    ACTIONS(1425), 1,
      sym_number_literal,
    ACTIONS(1427), 1,
      sym_identifier,
    STATE(519), 1,
      sym_subscript,
    STATE(628), 1,
      sym_event_flag,
    STATE(697), 1,
      sym_syncq_size,
  [24844] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1431), 2,
      anon_sym_const,
      sym_identifier,
    ACTIONS(1429), 6,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [24860] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1433), 1,
      anon_sym_LPAREN,
    STATE(502), 1,
      sym_subscript,
    ACTIONS(1435), 5,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
  [24880] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 2,
      anon_sym_const,
      sym_identifier,
    ACTIONS(1437), 6,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [24896] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1443), 2,
      anon_sym_const,
      sym_identifier,
    ACTIONS(1441), 6,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [24912] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1433), 1,
      anon_sym_LPAREN,
    STATE(502), 1,
      sym_subscript,
    ACTIONS(1445), 5,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
  [24932] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1433), 1,
      anon_sym_LPAREN,
    STATE(502), 1,
      sym_subscript,
    ACTIONS(1447), 5,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
  [24952] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1451), 2,
      anon_sym_const,
      sym_identifier,
    ACTIONS(1449), 6,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [24968] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1453), 7,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [24981] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1455), 1,
      anon_sym_LBRACE,
    STATE(808), 1,
      sym_field_declaration_list,
    ACTIONS(1443), 2,
      anon_sym_const,
      sym_identifier,
    ACTIONS(1441), 3,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_STAR,
  [25000] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1457), 1,
      anon_sym_SEMI,
    ACTIONS(1459), 1,
      anon_sym_LBRACE,
    ACTIONS(1461), 1,
      anon_sym_to,
    ACTIONS(1463), 1,
      anon_sym_DQUOTE,
    STATE(624), 1,
      sym_subscript,
    STATE(758), 1,
      sym__expanded_string_literal,
  [25025] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1465), 7,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [25038] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1469), 2,
      anon_sym_const,
      sym_identifier,
    ACTIONS(1467), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [25053] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1471), 7,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [25066] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1473), 7,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [25079] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1475), 7,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [25092] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1477), 1,
      anon_sym_LF,
    STATE(775), 1,
      sym_string_literal,
    ACTIONS(1479), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
  [25109] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1481), 1,
      anon_sym_LF,
    STATE(742), 1,
      sym_string_literal,
    ACTIONS(1479), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
  [25126] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1483), 1,
      anon_sym_LF,
    STATE(779), 1,
      sym_string_literal,
    ACTIONS(1479), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
  [25143] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1455), 1,
      anon_sym_LBRACE,
    STATE(765), 1,
      sym_field_declaration_list,
    ACTIONS(1441), 2,
      anon_sym_LPAREN,
      anon_sym_STAR,
    ACTIONS(1443), 2,
      anon_sym_const,
      sym_identifier,
  [25161] = 6,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1485), 1,
      anon_sym_DQUOTE,
    ACTIONS(1487), 1,
      aux_sym__expanded_string_literal_token1,
    ACTIONS(1490), 1,
      anon_sym_LBRACE2,
    ACTIONS(1493), 1,
      sym_escape_sequence,
    STATE(509), 2,
      sym_parameter_expansion,
      aux_sym__expanded_string_literal_repeat1,
  [25181] = 6,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1496), 1,
      anon_sym_DQUOTE,
    ACTIONS(1498), 1,
      aux_sym__expanded_string_literal_token1,
    ACTIONS(1500), 1,
      anon_sym_LBRACE2,
    ACTIONS(1502), 1,
      sym_escape_sequence,
    STATE(509), 2,
      sym_parameter_expansion,
      aux_sym__expanded_string_literal_repeat1,
  [25201] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(339), 1,
      anon_sym_exit,
    ACTIONS(341), 1,
      anon_sym_when,
    ACTIONS(1504), 1,
      anon_sym_RBRACE,
    STATE(711), 1,
      sym_exit,
    STATE(542), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
  [25221] = 6,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1500), 1,
      anon_sym_LBRACE2,
    ACTIONS(1506), 1,
      anon_sym_DQUOTE,
    ACTIONS(1508), 1,
      aux_sym__expanded_string_literal_token1,
    ACTIONS(1510), 1,
      sym_escape_sequence,
    STATE(510), 2,
      sym_parameter_expansion,
      aux_sym__expanded_string_literal_repeat1,
  [25241] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(339), 1,
      anon_sym_exit,
    ACTIONS(341), 1,
      anon_sym_when,
    ACTIONS(347), 1,
      anon_sym_RBRACE,
    STATE(800), 1,
      sym_exit,
    STATE(517), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
  [25261] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(339), 1,
      anon_sym_exit,
    ACTIONS(341), 1,
      anon_sym_when,
    ACTIONS(347), 1,
      anon_sym_RBRACE,
    STATE(800), 1,
      sym_exit,
    STATE(542), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
  [25281] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(719), 1,
      sym_string_literal,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
  [25295] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1455), 1,
      anon_sym_LBRACE,
    STATE(713), 1,
      sym_field_declaration_list,
    ACTIONS(1441), 2,
      anon_sym_LPAREN,
      anon_sym_STAR,
    ACTIONS(1443), 2,
      anon_sym_const,
      sym_identifier,
  [25313] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(339), 1,
      anon_sym_exit,
    ACTIONS(341), 1,
      anon_sym_when,
    ACTIONS(1512), 1,
      anon_sym_RBRACE,
    STATE(844), 1,
      sym_exit,
    STATE(542), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
  [25333] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(339), 1,
      anon_sym_exit,
    ACTIONS(341), 1,
      anon_sym_when,
    ACTIONS(1512), 1,
      anon_sym_RBRACE,
    STATE(844), 1,
      sym_exit,
    STATE(511), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
  [25353] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1425), 1,
      sym_number_literal,
    ACTIONS(1427), 1,
      sym_identifier,
    ACTIONS(1514), 1,
      anon_sym_SEMI,
    ACTIONS(1516), 1,
      anon_sym_to,
    STATE(623), 1,
      sym_event_flag,
    STATE(794), 1,
      sym_syncq_size,
  [25375] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1520), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(537), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25390] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1467), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_const,
      anon_sym_LBRACK,
  [25401] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1522), 1,
      anon_sym_LPAREN,
    STATE(552), 1,
      sym_subscript,
    ACTIONS(1524), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [25418] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1526), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(537), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25433] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1423), 1,
      anon_sym_LBRACK,
    ACTIONS(1427), 1,
      sym_identifier,
    ACTIONS(1528), 1,
      anon_sym_to,
    STATE(626), 1,
      sym_subscript,
    STATE(799), 1,
      sym_event_flag,
  [25452] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1449), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_const,
      anon_sym_LBRACK,
  [25463] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1530), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(537), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25478] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1532), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(529), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25493] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1522), 1,
      anon_sym_LPAREN,
    STATE(552), 1,
      sym_subscript,
    ACTIONS(1534), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [25510] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1536), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(537), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25525] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1538), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(531), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25540] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1540), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(537), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25555] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1542), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(526), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25570] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1544), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(534), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25585] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1546), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(537), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25600] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1522), 1,
      anon_sym_LPAREN,
    STATE(552), 1,
      sym_subscript,
    ACTIONS(1548), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [25617] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1550), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(520), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25632] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1555), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(537), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1552), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25647] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1559), 1,
      anon_sym_LBRACE,
    ACTIONS(1561), 1,
      anon_sym_EQ,
    STATE(179), 1,
      sym_block,
    ACTIONS(1557), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [25664] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1441), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_const,
      anon_sym_LBRACK,
  [25675] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1437), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_const,
      anon_sym_LBRACK,
  [25686] = 4,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1563), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(523), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25701] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1567), 1,
      anon_sym_when,
    ACTIONS(1565), 2,
      anon_sym_RBRACE,
      anon_sym_exit,
    STATE(542), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
  [25716] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1429), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_const,
      anon_sym_LBRACK,
  [25727] = 5,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1570), 1,
      anon_sym_LF,
    ACTIONS(1572), 1,
      anon_sym_LPAREN2,
    ACTIONS(1574), 1,
      sym_preproc_arg,
    STATE(643), 1,
      sym_preproc_params,
  [25743] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1576), 4,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
  [25753] = 5,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1572), 1,
      anon_sym_LPAREN2,
    ACTIONS(1578), 1,
      anon_sym_LF,
    ACTIONS(1580), 1,
      sym_preproc_arg,
    STATE(656), 1,
      sym_preproc_params,
  [25769] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(730), 1,
      anon_sym_state,
    ACTIONS(1582), 1,
      anon_sym_RBRACE,
    STATE(548), 2,
      sym_state,
      aux_sym_state_set_repeat2,
  [25783] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1584), 1,
      anon_sym_RBRACE,
    ACTIONS(1586), 1,
      anon_sym_state,
    STATE(548), 2,
      sym_state,
      aux_sym_state_set_repeat2,
  [25797] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1589), 4,
      anon_sym_RBRACE,
      anon_sym_exit,
      anon_sym_ss,
      anon_sym_when,
  [25807] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [25817] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1522), 1,
      anon_sym_LPAREN,
    ACTIONS(1593), 1,
      anon_sym_RPAREN,
    STATE(552), 1,
      sym_subscript,
  [25833] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1548), 4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [25843] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1595), 4,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
      anon_sym_RBRACE_PERCENT,
  [25853] = 5,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1597), 1,
      anon_sym_DQUOTE,
    ACTIONS(1599), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1601), 1,
      sym_escape_sequence,
    STATE(558), 1,
      aux_sym_string_literal_repeat1,
  [25869] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(557), 1,
      anon_sym_COMMA,
    STATE(563), 1,
      aux_sym_comma_expr_repeat1,
    ACTIONS(1603), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [25883] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1605), 2,
      anon_sym_DQUOTE,
      sym_escape_sequence,
    ACTIONS(1607), 2,
      aux_sym__expanded_string_literal_token1,
      anon_sym_LBRACE2,
  [25895] = 5,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1609), 1,
      anon_sym_DQUOTE,
    ACTIONS(1611), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1613), 1,
      sym_escape_sequence,
    STATE(560), 1,
      aux_sym_string_literal_repeat1,
  [25911] = 5,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1615), 1,
      anon_sym_DQUOTE,
    ACTIONS(1617), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1620), 1,
      sym_escape_sequence,
    STATE(558), 1,
      aux_sym_string_literal_repeat1,
  [25927] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1623), 4,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
  [25937] = 5,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1599), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1601), 1,
      sym_escape_sequence,
    ACTIONS(1625), 1,
      anon_sym_DQUOTE,
    STATE(558), 1,
      aux_sym_string_literal_repeat1,
  [25953] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1627), 4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [25963] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1629), 4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [25973] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1631), 1,
      anon_sym_COMMA,
    STATE(563), 1,
      aux_sym_comma_expr_repeat1,
    ACTIONS(629), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [25987] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(730), 1,
      anon_sym_state,
    ACTIONS(1634), 1,
      anon_sym_RBRACE,
    STATE(548), 2,
      sym_state,
      aux_sym_state_set_repeat2,
  [26001] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(730), 1,
      anon_sym_state,
    ACTIONS(1636), 1,
      anon_sym_RBRACE,
    STATE(548), 2,
      sym_state,
      aux_sym_state_set_repeat2,
  [26015] = 5,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1572), 1,
      anon_sym_LPAREN2,
    ACTIONS(1638), 1,
      anon_sym_LF,
    ACTIONS(1640), 1,
      sym_preproc_arg,
    STATE(669), 1,
      sym_preproc_params,
  [26031] = 5,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1642), 1,
      anon_sym_DQUOTE,
    ACTIONS(1644), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1646), 1,
      sym_escape_sequence,
    STATE(554), 1,
      aux_sym_string_literal_repeat1,
  [26047] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1648), 4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [26057] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(730), 1,
      anon_sym_state,
    ACTIONS(1650), 1,
      anon_sym_RBRACE,
    STATE(548), 2,
      sym_state,
      aux_sym_state_set_repeat2,
  [26071] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(730), 1,
      anon_sym_state,
    ACTIONS(1652), 1,
      anon_sym_RBRACE,
    STATE(548), 2,
      sym_state,
      aux_sym_state_set_repeat2,
  [26085] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(730), 1,
      anon_sym_state,
    ACTIONS(1654), 1,
      anon_sym_RBRACE,
    STATE(548), 2,
      sym_state,
      aux_sym_state_set_repeat2,
  [26099] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1417), 2,
      anon_sym_SEMI,
      sym_number_literal,
    ACTIONS(1656), 2,
      anon_sym_to,
      sym_identifier,
  [26111] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1658), 4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [26121] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1433), 1,
      anon_sym_LPAREN,
    ACTIONS(1660), 1,
      anon_sym_RPAREN,
    STATE(502), 1,
      sym_subscript,
  [26137] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1662), 1,
      anon_sym_SEMI,
    ACTIONS(1664), 1,
      anon_sym_COMMA,
    STATE(640), 1,
      aux_sym_declaration_repeat1,
  [26150] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1666), 1,
      anon_sym_RBRACE,
    ACTIONS(1668), 1,
      anon_sym_COMMA,
    STATE(633), 1,
      aux_sym_assign_repeat1,
  [26163] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1664), 1,
      anon_sym_COMMA,
    ACTIONS(1670), 1,
      anon_sym_SEMI,
    STATE(627), 1,
      aux_sym_declaration_repeat1,
  [26176] = 4,
    ACTIONS(1103), 1,
      anon_sym_LPAREN,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1672), 1,
      anon_sym_LF,
    STATE(389), 1,
      sym_preproc_argument_list,
  [26189] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1674), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26198] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1676), 1,
      anon_sym_RPAREN,
    ACTIONS(1678), 1,
      anon_sym_COMMA,
    STATE(589), 1,
      aux_sym_function_declarator_repeat1,
  [26211] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1680), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26220] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1463), 1,
      anon_sym_DQUOTE,
    ACTIONS(1666), 1,
      anon_sym_RBRACE,
    STATE(634), 1,
      sym__expanded_string_literal,
  [26233] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1425), 1,
      sym_number_literal,
    ACTIONS(1682), 1,
      anon_sym_SEMI,
    STATE(712), 1,
      sym_syncq_size,
  [26246] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(263), 1,
      anon_sym_ss,
    STATE(73), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26257] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1684), 1,
      anon_sym_RBRACE,
    ACTIONS(1686), 1,
      anon_sym_COMMA,
    STATE(617), 1,
      aux_sym_init_expr_repeat1,
  [26270] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1688), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26279] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1175), 1,
      anon_sym_RPAREN,
    ACTIONS(1690), 1,
      anon_sym_COMMA,
    STATE(587), 1,
      aux_sym_preproc_argument_list_repeat1,
  [26292] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1693), 1,
      anon_sym_RPAREN,
    ACTIONS(1695), 1,
      anon_sym_COMMA,
    STATE(588), 1,
      aux_sym_preproc_params_repeat1,
  [26305] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1698), 1,
      anon_sym_RPAREN,
    ACTIONS(1700), 1,
      anon_sym_COMMA,
    STATE(589), 1,
      aux_sym_function_declarator_repeat1,
  [26318] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(951), 1,
      anon_sym_RPAREN,
    ACTIONS(1678), 1,
      anon_sym_COMMA,
    STATE(594), 1,
      aux_sym_function_declarator_repeat1,
  [26331] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1703), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26340] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1705), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26349] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(263), 1,
      anon_sym_ss,
    STATE(70), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26360] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1678), 1,
      anon_sym_COMMA,
    ACTIONS(1707), 1,
      anon_sym_RPAREN,
    STATE(589), 1,
      aux_sym_function_declarator_repeat1,
  [26373] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1664), 1,
      anon_sym_COMMA,
    ACTIONS(1709), 1,
      anon_sym_SEMI,
    STATE(575), 1,
      aux_sym_declaration_repeat1,
  [26386] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1678), 1,
      anon_sym_COMMA,
    ACTIONS(1707), 1,
      anon_sym_RPAREN,
    STATE(619), 1,
      aux_sym_function_declarator_repeat1,
  [26399] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1686), 1,
      anon_sym_COMMA,
    ACTIONS(1711), 1,
      anon_sym_RBRACE,
    STATE(585), 1,
      aux_sym_init_expr_repeat1,
  [26412] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(263), 1,
      anon_sym_ss,
    STATE(71), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26423] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1686), 1,
      anon_sym_COMMA,
    ACTIONS(1713), 1,
      anon_sym_RBRACE,
    STATE(617), 1,
      aux_sym_init_expr_repeat1,
  [26436] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1050), 1,
      anon_sym_COMMA,
    ACTIONS(1715), 1,
      anon_sym_RPAREN,
    STATE(587), 1,
      aux_sym_preproc_argument_list_repeat1,
  [26449] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1717), 1,
      anon_sym_RPAREN,
    ACTIONS(1719), 1,
      anon_sym_COMMA,
    STATE(622), 1,
      aux_sym_preproc_params_repeat1,
  [26462] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1721), 1,
      anon_sym_SEMI,
    ACTIONS(1723), 1,
      anon_sym_COMMA,
    STATE(607), 1,
      aux_sym_foreign_declaration_repeat1,
  [26475] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(700), 1,
      sym_option_value,
    ACTIONS(1725), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [26486] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1727), 1,
      anon_sym_SEMI,
    STATE(780), 1,
      sym_subscript,
  [26499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1561), 1,
      anon_sym_EQ,
    ACTIONS(1557), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26510] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1729), 3,
      anon_sym_RBRACE,
      anon_sym_exit,
      anon_sym_when,
  [26519] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1723), 1,
      anon_sym_COMMA,
    ACTIONS(1731), 1,
      anon_sym_SEMI,
    STATE(618), 1,
      aux_sym_foreign_declaration_repeat1,
  [26532] = 4,
    ACTIONS(1103), 1,
      anon_sym_LPAREN,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1733), 1,
      anon_sym_LF,
    STATE(389), 1,
      sym_preproc_argument_list,
  [26545] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1678), 1,
      anon_sym_COMMA,
    ACTIONS(1735), 1,
      anon_sym_RPAREN,
    STATE(580), 1,
      aux_sym_function_declarator_repeat1,
  [26558] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1737), 3,
      anon_sym_RBRACE,
      anon_sym_exit,
      anon_sym_when,
  [26567] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1739), 3,
      anon_sym_RBRACE,
      anon_sym_exit,
      anon_sym_when,
  [26576] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1463), 1,
      anon_sym_DQUOTE,
    ACTIONS(1741), 1,
      anon_sym_RBRACE,
    STATE(576), 1,
      sym__expanded_string_literal,
  [26589] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(557), 1,
      anon_sym_COMMA,
    ACTIONS(1743), 1,
      anon_sym_RPAREN,
    STATE(563), 1,
      aux_sym_comma_expr_repeat1,
  [26602] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1463), 1,
      anon_sym_DQUOTE,
    ACTIONS(1745), 1,
      anon_sym_LBRACE,
    STATE(736), 1,
      sym__expanded_string_literal,
  [26615] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(267), 1,
      anon_sym_ss,
    STATE(83), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26626] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1747), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26635] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1749), 1,
      anon_sym_RBRACE,
    ACTIONS(1751), 1,
      anon_sym_COMMA,
    STATE(617), 1,
      aux_sym_init_expr_repeat1,
  [26648] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1754), 1,
      anon_sym_SEMI,
    ACTIONS(1756), 1,
      anon_sym_COMMA,
    STATE(618), 1,
      aux_sym_foreign_declaration_repeat1,
  [26661] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1678), 1,
      anon_sym_COMMA,
    ACTIONS(1759), 1,
      anon_sym_RPAREN,
    STATE(589), 1,
      aux_sym_function_declarator_repeat1,
  [26674] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(267), 1,
      anon_sym_ss,
    STATE(81), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26685] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1050), 1,
      anon_sym_COMMA,
    ACTIONS(1761), 1,
      anon_sym_RPAREN,
    STATE(587), 1,
      aux_sym_preproc_argument_list_repeat1,
  [26698] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1719), 1,
      anon_sym_COMMA,
    ACTIONS(1763), 1,
      anon_sym_RPAREN,
    STATE(588), 1,
      aux_sym_preproc_params_repeat1,
  [26711] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1425), 1,
      sym_number_literal,
    ACTIONS(1765), 1,
      anon_sym_SEMI,
    STATE(752), 1,
      sym_syncq_size,
  [26724] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1463), 1,
      anon_sym_DQUOTE,
    ACTIONS(1767), 1,
      anon_sym_to,
    STATE(736), 1,
      sym__expanded_string_literal,
  [26737] = 4,
    ACTIONS(1103), 1,
      anon_sym_LPAREN,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1769), 1,
      anon_sym_LF,
    STATE(389), 1,
      sym_preproc_argument_list,
  [26750] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1427), 1,
      sym_identifier,
    ACTIONS(1771), 1,
      anon_sym_to,
    STATE(812), 1,
      sym_event_flag,
  [26763] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1664), 1,
      anon_sym_COMMA,
    ACTIONS(1773), 1,
      anon_sym_SEMI,
    STATE(640), 1,
      aux_sym_declaration_repeat1,
  [26776] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1425), 1,
      sym_number_literal,
    ACTIONS(1514), 1,
      anon_sym_SEMI,
    STATE(794), 1,
      sym_syncq_size,
  [26789] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1775), 1,
      anon_sym_RBRACE,
    ACTIONS(1777), 1,
      anon_sym_COMMA,
    STATE(629), 1,
      aux_sym_assign_repeat1,
  [26802] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(265), 1,
      anon_sym_ss,
    STATE(82), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26813] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(265), 1,
      anon_sym_ss,
    STATE(87), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26824] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(265), 1,
      anon_sym_ss,
    STATE(85), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26835] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1668), 1,
      anon_sym_COMMA,
    ACTIONS(1780), 1,
      anon_sym_RBRACE,
    STATE(629), 1,
      aux_sym_assign_repeat1,
  [26848] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1668), 1,
      anon_sym_COMMA,
    ACTIONS(1780), 1,
      anon_sym_RBRACE,
    STATE(638), 1,
      aux_sym_assign_repeat1,
  [26861] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1782), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26870] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1784), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26879] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1686), 1,
      anon_sym_COMMA,
    ACTIONS(1786), 1,
      anon_sym_RBRACE,
    STATE(599), 1,
      aux_sym_init_expr_repeat1,
  [26892] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1668), 1,
      anon_sym_COMMA,
    ACTIONS(1788), 1,
      anon_sym_RBRACE,
    STATE(629), 1,
      aux_sym_assign_repeat1,
  [26905] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1790), 3,
      anon_sym_RBRACE,
      anon_sym_exit,
      anon_sym_when,
  [26914] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1792), 1,
      anon_sym_SEMI,
    ACTIONS(1794), 1,
      anon_sym_COMMA,
    STATE(640), 1,
      aux_sym_declaration_repeat1,
  [26927] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1797), 1,
      anon_sym_RPAREN,
    ACTIONS(1799), 2,
      sym_identifier,
      anon_sym_DOT_DOT_DOT,
  [26938] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(267), 1,
      anon_sym_ss,
    STATE(84), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26949] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1801), 1,
      anon_sym_LF,
    ACTIONS(1803), 1,
      sym_preproc_arg,
  [26959] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1805), 2,
      anon_sym_LF,
      sym_preproc_arg,
  [26967] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1807), 2,
      sym_identifier,
      anon_sym_DOT_DOT_DOT,
  [26975] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1809), 1,
      sym_identifier,
    STATE(583), 1,
      sym_event_flag,
  [26985] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1811), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [26993] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1559), 1,
      anon_sym_LBRACE,
    STATE(292), 1,
      sym_block,
  [27003] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1813), 1,
      anon_sym_LF,
    ACTIONS(1815), 1,
      sym_preproc_arg,
  [27013] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1817), 1,
      anon_sym_LPAREN,
    ACTIONS(1819), 1,
      sym_identifier,
  [27023] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1775), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [27031] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 2,
      anon_sym_RBRACE,
      anon_sym_state,
  [27039] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1823), 1,
      anon_sym_LF,
    ACTIONS(1825), 1,
      sym_preproc_arg,
  [27049] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1827), 1,
      anon_sym_LPAREN,
    ACTIONS(1829), 1,
      sym_identifier,
  [27059] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1809), 1,
      sym_identifier,
    STATE(812), 1,
      sym_event_flag,
  [27069] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1831), 1,
      anon_sym_LF,
    ACTIONS(1833), 1,
      sym_preproc_arg,
  [27079] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1835), 2,
      anon_sym_SEMI,
      sym_number_literal,
  [27087] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1698), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [27095] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1809), 1,
      sym_identifier,
    STATE(623), 1,
      sym_event_flag,
  [27105] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1837), 2,
      anon_sym_RBRACE,
      anon_sym_state,
  [27113] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1754), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [27121] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1839), 1,
      anon_sym_LBRACE,
    STATE(260), 1,
      sym_block,
  [27131] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1841), 2,
      anon_sym_LF,
      sym_preproc_arg,
  [27139] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1839), 1,
      anon_sym_LBRACE,
    STATE(290), 1,
      sym_block,
  [27149] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1463), 1,
      anon_sym_DQUOTE,
    STATE(651), 1,
      sym__expanded_string_literal,
  [27159] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1843), 2,
      anon_sym_RBRACE,
      anon_sym_state,
  [27167] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1845), 2,
      anon_sym_RBRACE,
      anon_sym_state,
  [27175] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1792), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [27183] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1847), 1,
      anon_sym_LF,
    ACTIONS(1849), 1,
      sym_preproc_arg,
  [27193] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1749), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [27201] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1851), 1,
      anon_sym_LBRACE,
    STATE(652), 1,
      sym_state_block,
  [27211] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1853), 1,
      anon_sym_LBRACE,
    STATE(298), 1,
      sym_block,
  [27221] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1855), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [27229] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1857), 1,
      anon_sym_exit,
    ACTIONS(1859), 1,
      anon_sym_state,
  [27239] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1861), 2,
      anon_sym_RBRACE,
      anon_sym_state,
  [27247] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1853), 1,
      anon_sym_LBRACE,
    STATE(297), 1,
      sym_block,
  [27257] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1863), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [27265] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1865), 1,
      anon_sym_exit,
    ACTIONS(1867), 1,
      anon_sym_state,
  [27275] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1869), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [27283] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1559), 1,
      anon_sym_LBRACE,
    STATE(549), 1,
      sym_block,
  [27293] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1693), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [27301] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1871), 1,
      anon_sym_SEMI,
    ACTIONS(1873), 1,
      sym_identifier,
  [27311] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1875), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [27319] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1877), 2,
      anon_sym_RBRACE,
      anon_sym_state,
  [27327] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1879), 2,
      anon_sym_LF,
      sym_preproc_arg,
  [27335] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1463), 1,
      anon_sym_DQUOTE,
    STATE(721), 1,
      sym__expanded_string_literal,
  [27345] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1559), 1,
      anon_sym_LBRACE,
    STATE(674), 1,
      sym_block,
  [27355] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1559), 1,
      anon_sym_LBRACE,
    STATE(179), 1,
      sym_block,
  [27365] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1881), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [27373] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1883), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [27381] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1809), 1,
      sym_identifier,
    STATE(745), 1,
      sym_event_flag,
  [27391] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1559), 1,
      anon_sym_LBRACE,
    STATE(678), 1,
      sym_block,
  [27401] = 3,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1885), 1,
      anon_sym_LF,
    ACTIONS(1887), 1,
      sym_preproc_arg,
  [27411] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1889), 1,
      sym_identifier,
  [27418] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 1,
      anon_sym_RPAREN,
  [27425] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1893), 1,
      anon_sym_LF,
  [27432] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1514), 1,
      anon_sym_SEMI,
  [27439] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 1,
      sym_number_literal,
  [27446] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1897), 1,
      anon_sym_SEMI,
  [27453] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1899), 1,
      sym_identifier,
  [27460] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1901), 1,
      anon_sym_LF,
  [27467] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_LBRACE,
  [27474] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1905), 1,
      anon_sym_LF,
  [27481] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1907), 1,
      anon_sym_RPAREN,
  [27488] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1909), 1,
      aux_sym_preproc_if_token2,
  [27495] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1911), 1,
      sym_line_number,
  [27502] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1913), 1,
      aux_sym_preproc_if_token2,
  [27509] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1915), 1,
      anon_sym_SEMI,
  [27516] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1917), 1,
      anon_sym_SEMI,
  [27523] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1919), 1,
      anon_sym_SEMI,
  [27530] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1921), 1,
      anon_sym_RBRACE,
  [27537] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1923), 1,
      anon_sym_SEMI,
  [27544] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1925), 1,
      anon_sym_SEMI,
  [27551] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1927), 1,
      anon_sym_SEMI,
  [27558] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1929), 1,
      anon_sym_SEMI,
  [27565] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1931), 1,
      anon_sym_RPAREN,
  [27572] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1933), 1,
      anon_sym_LF,
  [27579] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1935), 1,
      aux_sym_preproc_if_token2,
  [27586] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1937), 1,
      anon_sym_RPAREN,
  [27593] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_RBRACK,
  [27600] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
  [27607] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1943), 1,
      anon_sym_SEMI,
  [27614] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1945), 1,
      anon_sym_SEMI,
  [27621] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1947), 1,
      anon_sym_RPAREN,
  [27628] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1949), 1,
      anon_sym_SQUOTE,
  [27635] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1951), 1,
      anon_sym_LF,
  [27642] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1953), 1,
      anon_sym_SEMI,
  [27649] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1955), 1,
      sym_identifier,
  [27656] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      sym_identifier,
  [27663] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 1,
      anon_sym_SEMI,
  [27670] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1961), 1,
      anon_sym_LF,
  [27677] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1963), 1,
      anon_sym_RPAREN,
  [27684] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1965), 1,
      anon_sym_LPAREN,
  [27691] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1967), 1,
      anon_sym_SEMI,
  [27698] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1969), 1,
      anon_sym_RBRACE,
  [27705] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1971), 1,
      anon_sym_SEMI,
  [27712] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1733), 1,
      anon_sym_LF,
  [27719] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1973), 1,
      anon_sym_SEMI,
  [27726] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1975), 1,
      sym_identifier,
  [27733] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(347), 1,
      anon_sym_RBRACE,
  [27740] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1977), 1,
      anon_sym_LF,
  [27747] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1979), 1,
      anon_sym_LF,
  [27754] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1981), 1,
      sym_identifier,
  [27761] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      anon_sym_RPAREN,
  [27768] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1985), 1,
      anon_sym_SEMI,
  [27775] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1987), 1,
      sym_identifier,
  [27782] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1989), 1,
      anon_sym_LF,
  [27789] = 2,
    ACTIONS(491), 1,
      anon_sym_LF,
    ACTIONS(1105), 1,
      sym_comment,
  [27796] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1991), 1,
      anon_sym_SQUOTE,
  [27803] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1993), 1,
      sym_identifier,
  [27810] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1995), 1,
      aux_sym_preproc_if_token2,
  [27817] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1682), 1,
      anon_sym_SEMI,
  [27824] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1769), 1,
      anon_sym_LF,
  [27831] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1997), 1,
      anon_sym_LF,
  [27838] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1999), 1,
      anon_sym_RPAREN,
  [27845] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(1672), 1,
      anon_sym_LF,
  [27852] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2001), 1,
      sym_identifier,
  [27859] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2003), 1,
      anon_sym_SEMI,
  [27866] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(2005), 1,
      anon_sym_LF,
  [27873] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2007), 1,
      aux_sym_preproc_if_token2,
  [27880] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2009), 1,
      anon_sym_LPAREN,
  [27887] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2011), 1,
      aux_sym_preproc_if_token2,
  [27894] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2013), 1,
      anon_sym_RPAREN,
  [27901] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2015), 1,
      aux_sym_preproc_if_token2,
  [27908] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2017), 1,
      anon_sym_SEMI,
  [27915] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2019), 1,
      sym_identifier,
  [27922] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2021), 1,
      sym_identifier,
  [27929] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2023), 1,
      aux_sym_preproc_if_token2,
  [27936] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2025), 1,
      aux_sym_preproc_if_token2,
  [27943] = 2,
    ACTIONS(365), 1,
      anon_sym_LF,
    ACTIONS(1105), 1,
      sym_comment,
  [27950] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2027), 1,
      anon_sym_RPAREN,
  [27957] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2029), 1,
      anon_sym_SEMI,
  [27964] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(2031), 1,
      anon_sym_LF,
  [27971] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(2033), 1,
      anon_sym_LF,
  [27978] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(2035), 1,
      anon_sym_LF,
  [27985] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2037), 1,
      sym_identifier,
  [27992] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2039), 1,
      sym_identifier,
  [27999] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2041), 1,
      sym_identifier,
  [28006] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(2043), 1,
      anon_sym_LF,
  [28013] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2045), 1,
      anon_sym_SEMI,
  [28020] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(2047), 1,
      anon_sym_LF,
  [28027] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2049), 1,
      anon_sym_RPAREN,
  [28034] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2051), 1,
      anon_sym_RBRACK,
  [28041] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2053), 1,
      anon_sym_RPAREN,
  [28048] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2055), 1,
      sym_identifier,
  [28055] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2057), 1,
      anon_sym_LPAREN,
  [28062] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2059), 1,
      ts_builtin_sym_end,
  [28069] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(2061), 1,
      anon_sym_LF,
  [28076] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2063), 1,
      sym_line_number,
  [28083] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2065), 1,
      sym_identifier,
  [28090] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2067), 1,
      sym_identifier,
  [28097] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2069), 1,
      sym_identifier,
  [28104] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2071), 1,
      sym_identifier,
  [28111] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1765), 1,
      anon_sym_SEMI,
  [28118] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2073), 1,
      anon_sym_SEMI,
  [28125] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2075), 1,
      anon_sym_LPAREN,
  [28132] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(2077), 1,
      aux_sym__c_code_token2,
  [28139] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2079), 1,
      sym_identifier,
  [28146] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      anon_sym_SEMI,
  [28153] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1512), 1,
      anon_sym_RBRACE,
  [28160] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2083), 1,
      sym_number_literal,
  [28167] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      aux_sym_preproc_if_token2,
  [28174] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2087), 1,
      anon_sym_RPAREN,
  [28181] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2089), 1,
      anon_sym_RPAREN,
  [28188] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(2091), 1,
      anon_sym_LF,
  [28195] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2093), 1,
      aux_sym_preproc_if_token2,
  [28202] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2095), 1,
      anon_sym_RPAREN,
  [28209] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2097), 1,
      anon_sym_SEMI,
  [28216] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2099), 1,
      sym_identifier,
  [28223] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2101), 1,
      anon_sym_RPAREN,
  [28230] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2103), 1,
      anon_sym_RPAREN,
  [28237] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2105), 1,
      anon_sym_SEMI,
  [28244] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2107), 1,
      anon_sym_RPAREN,
  [28251] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2109), 1,
      sym_line_number,
  [28258] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      sym_identifier,
  [28265] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2113), 1,
      sym_identifier,
  [28272] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2115), 1,
      sym_identifier,
  [28279] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2117), 1,
      sym_identifier,
  [28286] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2119), 1,
      anon_sym_RPAREN,
  [28293] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2121), 1,
      sym_identifier,
  [28300] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(2123), 1,
      aux_sym__c_code_token2,
  [28307] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2125), 1,
      anon_sym_SQUOTE,
  [28314] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2127), 1,
      anon_sym_SEMI,
  [28321] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2129), 1,
      sym_identifier,
  [28328] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2131), 1,
      aux_sym_preproc_if_token2,
  [28335] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(2133), 1,
      aux_sym__c_code_token2,
  [28342] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(2135), 1,
      aux_sym__c_code_token2,
  [28349] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(2137), 1,
      aux_sym__c_code_token2,
  [28356] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2139), 1,
      sym_identifier,
  [28363] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2141), 1,
      anon_sym_SEMI,
  [28370] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2143), 1,
      anon_sym_LBRACE,
  [28377] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2145), 1,
      aux_sym_preproc_if_token2,
  [28384] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2147), 1,
      anon_sym_RPAREN,
  [28391] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2149), 1,
      anon_sym_RPAREN,
  [28398] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2151), 1,
      anon_sym_SEMI,
  [28405] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2153), 1,
      aux_sym_preproc_if_token2,
  [28412] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2155), 1,
      anon_sym_SEMI,
  [28419] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2157), 1,
      anon_sym_RPAREN,
  [28426] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2159), 1,
      sym_identifier,
  [28433] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2161), 1,
      anon_sym_LBRACE,
  [28440] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2163), 1,
      sym_identifier,
  [28447] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2165), 1,
      anon_sym_LPAREN,
  [28454] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2167), 1,
      anon_sym_LPAREN,
  [28461] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1504), 1,
      anon_sym_RBRACE,
  [28468] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2169), 1,
      anon_sym_SEMI,
  [28475] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2171), 1,
      sym_identifier,
  [28482] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2173), 1,
      anon_sym_LPAREN,
  [28489] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2175), 1,
      anon_sym_LPAREN,
  [28496] = 2,
    ACTIONS(1105), 1,
      sym_comment,
    ACTIONS(2177), 1,
      aux_sym__c_code_token2,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(16)] = 0,
  [SMALL_STATE(17)] = 109,
  [SMALL_STATE(18)] = 218,
  [SMALL_STATE(19)] = 327,
  [SMALL_STATE(20)] = 436,
  [SMALL_STATE(21)] = 545,
  [SMALL_STATE(22)] = 654,
  [SMALL_STATE(23)] = 763,
  [SMALL_STATE(24)] = 852,
  [SMALL_STATE(25)] = 961,
  [SMALL_STATE(26)] = 1070,
  [SMALL_STATE(27)] = 1179,
  [SMALL_STATE(28)] = 1288,
  [SMALL_STATE(29)] = 1393,
  [SMALL_STATE(30)] = 1498,
  [SMALL_STATE(31)] = 1603,
  [SMALL_STATE(32)] = 1708,
  [SMALL_STATE(33)] = 1813,
  [SMALL_STATE(34)] = 1918,
  [SMALL_STATE(35)] = 2023,
  [SMALL_STATE(36)] = 2128,
  [SMALL_STATE(37)] = 2233,
  [SMALL_STATE(38)] = 2338,
  [SMALL_STATE(39)] = 2443,
  [SMALL_STATE(40)] = 2548,
  [SMALL_STATE(41)] = 2653,
  [SMALL_STATE(42)] = 2758,
  [SMALL_STATE(43)] = 2863,
  [SMALL_STATE(44)] = 2968,
  [SMALL_STATE(45)] = 3073,
  [SMALL_STATE(46)] = 3178,
  [SMALL_STATE(47)] = 3283,
  [SMALL_STATE(48)] = 3388,
  [SMALL_STATE(49)] = 3493,
  [SMALL_STATE(50)] = 3598,
  [SMALL_STATE(51)] = 3659,
  [SMALL_STATE(52)] = 3720,
  [SMALL_STATE(53)] = 3781,
  [SMALL_STATE(54)] = 3842,
  [SMALL_STATE(55)] = 3903,
  [SMALL_STATE(56)] = 3964,
  [SMALL_STATE(57)] = 4025,
  [SMALL_STATE(58)] = 4086,
  [SMALL_STATE(59)] = 4187,
  [SMALL_STATE(60)] = 4288,
  [SMALL_STATE(61)] = 4389,
  [SMALL_STATE(62)] = 4484,
  [SMALL_STATE(63)] = 4579,
  [SMALL_STATE(64)] = 4674,
  [SMALL_STATE(65)] = 4769,
  [SMALL_STATE(66)] = 4864,
  [SMALL_STATE(67)] = 4959,
  [SMALL_STATE(68)] = 5054,
  [SMALL_STATE(69)] = 5149,
  [SMALL_STATE(70)] = 5244,
  [SMALL_STATE(71)] = 5329,
  [SMALL_STATE(72)] = 5414,
  [SMALL_STATE(73)] = 5499,
  [SMALL_STATE(74)] = 5584,
  [SMALL_STATE(75)] = 5670,
  [SMALL_STATE(76)] = 5759,
  [SMALL_STATE(77)] = 5810,
  [SMALL_STATE(78)] = 5893,
  [SMALL_STATE(79)] = 5982,
  [SMALL_STATE(80)] = 6033,
  [SMALL_STATE(81)] = 6116,
  [SMALL_STATE(82)] = 6199,
  [SMALL_STATE(83)] = 6282,
  [SMALL_STATE(84)] = 6365,
  [SMALL_STATE(85)] = 6448,
  [SMALL_STATE(86)] = 6531,
  [SMALL_STATE(87)] = 6582,
  [SMALL_STATE(88)] = 6665,
  [SMALL_STATE(89)] = 6715,
  [SMALL_STATE(90)] = 6787,
  [SMALL_STATE(91)] = 6839,
  [SMALL_STATE(92)] = 6911,
  [SMALL_STATE(93)] = 6965,
  [SMALL_STATE(94)] = 7025,
  [SMALL_STATE(95)] = 7075,
  [SMALL_STATE(96)] = 7149,
  [SMALL_STATE(97)] = 7199,
  [SMALL_STATE(98)] = 7249,
  [SMALL_STATE(99)] = 7321,
  [SMALL_STATE(100)] = 7375,
  [SMALL_STATE(101)] = 7425,
  [SMALL_STATE(102)] = 7507,
  [SMALL_STATE(103)] = 7563,
  [SMALL_STATE(104)] = 7613,
  [SMALL_STATE(105)] = 7687,
  [SMALL_STATE(106)] = 7759,
  [SMALL_STATE(107)] = 7829,
  [SMALL_STATE(108)] = 7897,
  [SMALL_STATE(109)] = 7963,
  [SMALL_STATE(110)] = 8027,
  [SMALL_STATE(111)] = 8087,
  [SMALL_STATE(112)] = 8145,
  [SMALL_STATE(113)] = 8199,
  [SMALL_STATE(114)] = 8249,
  [SMALL_STATE(115)] = 8321,
  [SMALL_STATE(116)] = 8393,
  [SMALL_STATE(117)] = 8443,
  [SMALL_STATE(118)] = 8493,
  [SMALL_STATE(119)] = 8565,
  [SMALL_STATE(120)] = 8637,
  [SMALL_STATE(121)] = 8721,
  [SMALL_STATE(122)] = 8795,
  [SMALL_STATE(123)] = 8867,
  [SMALL_STATE(124)] = 8939,
  [SMALL_STATE(125)] = 8989,
  [SMALL_STATE(126)] = 9039,
  [SMALL_STATE(127)] = 9111,
  [SMALL_STATE(128)] = 9183,
  [SMALL_STATE(129)] = 9255,
  [SMALL_STATE(130)] = 9327,
  [SMALL_STATE(131)] = 9399,
  [SMALL_STATE(132)] = 9471,
  [SMALL_STATE(133)] = 9542,
  [SMALL_STATE(134)] = 9613,
  [SMALL_STATE(135)] = 9682,
  [SMALL_STATE(136)] = 9751,
  [SMALL_STATE(137)] = 9822,
  [SMALL_STATE(138)] = 9891,
  [SMALL_STATE(139)] = 9962,
  [SMALL_STATE(140)] = 10031,
  [SMALL_STATE(141)] = 10103,
  [SMALL_STATE(142)] = 10175,
  [SMALL_STATE(143)] = 10247,
  [SMALL_STATE(144)] = 10319,
  [SMALL_STATE(145)] = 10391,
  [SMALL_STATE(146)] = 10463,
  [SMALL_STATE(147)] = 10535,
  [SMALL_STATE(148)] = 10607,
  [SMALL_STATE(149)] = 10679,
  [SMALL_STATE(150)] = 10765,
  [SMALL_STATE(151)] = 10833,
  [SMALL_STATE(152)] = 10905,
  [SMALL_STATE(153)] = 10970,
  [SMALL_STATE(154)] = 11035,
  [SMALL_STATE(155)] = 11100,
  [SMALL_STATE(156)] = 11165,
  [SMALL_STATE(157)] = 11230,
  [SMALL_STATE(158)] = 11307,
  [SMALL_STATE(159)] = 11372,
  [SMALL_STATE(160)] = 11437,
  [SMALL_STATE(161)] = 11502,
  [SMALL_STATE(162)] = 11567,
  [SMALL_STATE(163)] = 11632,
  [SMALL_STATE(164)] = 11697,
  [SMALL_STATE(165)] = 11762,
  [SMALL_STATE(166)] = 11827,
  [SMALL_STATE(167)] = 11892,
  [SMALL_STATE(168)] = 11973,
  [SMALL_STATE(169)] = 12020,
  [SMALL_STATE(170)] = 12093,
  [SMALL_STATE(171)] = 12140,
  [SMALL_STATE(172)] = 12221,
  [SMALL_STATE(173)] = 12286,
  [SMALL_STATE(174)] = 12371,
  [SMALL_STATE(175)] = 12418,
  [SMALL_STATE(176)] = 12483,
  [SMALL_STATE(177)] = 12548,
  [SMALL_STATE(178)] = 12613,
  [SMALL_STATE(179)] = 12678,
  [SMALL_STATE(180)] = 12725,
  [SMALL_STATE(181)] = 12808,
  [SMALL_STATE(182)] = 12873,
  [SMALL_STATE(183)] = 12943,
  [SMALL_STATE(184)] = 13013,
  [SMALL_STATE(185)] = 13083,
  [SMALL_STATE(186)] = 13153,
  [SMALL_STATE(187)] = 13223,
  [SMALL_STATE(188)] = 13293,
  [SMALL_STATE(189)] = 13363,
  [SMALL_STATE(190)] = 13433,
  [SMALL_STATE(191)] = 13503,
  [SMALL_STATE(192)] = 13573,
  [SMALL_STATE(193)] = 13643,
  [SMALL_STATE(194)] = 13713,
  [SMALL_STATE(195)] = 13783,
  [SMALL_STATE(196)] = 13853,
  [SMALL_STATE(197)] = 13923,
  [SMALL_STATE(198)] = 13993,
  [SMALL_STATE(199)] = 14063,
  [SMALL_STATE(200)] = 14133,
  [SMALL_STATE(201)] = 14203,
  [SMALL_STATE(202)] = 14273,
  [SMALL_STATE(203)] = 14352,
  [SMALL_STATE(204)] = 14401,
  [SMALL_STATE(205)] = 14480,
  [SMALL_STATE(206)] = 14550,
  [SMALL_STATE(207)] = 14620,
  [SMALL_STATE(208)] = 14690,
  [SMALL_STATE(209)] = 14760,
  [SMALL_STATE(210)] = 14830,
  [SMALL_STATE(211)] = 14900,
  [SMALL_STATE(212)] = 14947,
  [SMALL_STATE(213)] = 14990,
  [SMALL_STATE(214)] = 15037,
  [SMALL_STATE(215)] = 15084,
  [SMALL_STATE(216)] = 15127,
  [SMALL_STATE(217)] = 15174,
  [SMALL_STATE(218)] = 15216,
  [SMALL_STATE(219)] = 15258,
  [SMALL_STATE(220)] = 15300,
  [SMALL_STATE(221)] = 15342,
  [SMALL_STATE(222)] = 15412,
  [SMALL_STATE(223)] = 15478,
  [SMALL_STATE(224)] = 15520,
  [SMALL_STATE(225)] = 15562,
  [SMALL_STATE(226)] = 15604,
  [SMALL_STATE(227)] = 15646,
  [SMALL_STATE(228)] = 15688,
  [SMALL_STATE(229)] = 15730,
  [SMALL_STATE(230)] = 15772,
  [SMALL_STATE(231)] = 15814,
  [SMALL_STATE(232)] = 15856,
  [SMALL_STATE(233)] = 15898,
  [SMALL_STATE(234)] = 15940,
  [SMALL_STATE(235)] = 15982,
  [SMALL_STATE(236)] = 16024,
  [SMALL_STATE(237)] = 16066,
  [SMALL_STATE(238)] = 16108,
  [SMALL_STATE(239)] = 16150,
  [SMALL_STATE(240)] = 16192,
  [SMALL_STATE(241)] = 16234,
  [SMALL_STATE(242)] = 16276,
  [SMALL_STATE(243)] = 16318,
  [SMALL_STATE(244)] = 16360,
  [SMALL_STATE(245)] = 16402,
  [SMALL_STATE(246)] = 16444,
  [SMALL_STATE(247)] = 16486,
  [SMALL_STATE(248)] = 16528,
  [SMALL_STATE(249)] = 16570,
  [SMALL_STATE(250)] = 16612,
  [SMALL_STATE(251)] = 16654,
  [SMALL_STATE(252)] = 16696,
  [SMALL_STATE(253)] = 16738,
  [SMALL_STATE(254)] = 16780,
  [SMALL_STATE(255)] = 16822,
  [SMALL_STATE(256)] = 16864,
  [SMALL_STATE(257)] = 16906,
  [SMALL_STATE(258)] = 16948,
  [SMALL_STATE(259)] = 16989,
  [SMALL_STATE(260)] = 17030,
  [SMALL_STATE(261)] = 17071,
  [SMALL_STATE(262)] = 17112,
  [SMALL_STATE(263)] = 17153,
  [SMALL_STATE(264)] = 17194,
  [SMALL_STATE(265)] = 17235,
  [SMALL_STATE(266)] = 17276,
  [SMALL_STATE(267)] = 17317,
  [SMALL_STATE(268)] = 17358,
  [SMALL_STATE(269)] = 17399,
  [SMALL_STATE(270)] = 17440,
  [SMALL_STATE(271)] = 17481,
  [SMALL_STATE(272)] = 17522,
  [SMALL_STATE(273)] = 17563,
  [SMALL_STATE(274)] = 17604,
  [SMALL_STATE(275)] = 17645,
  [SMALL_STATE(276)] = 17686,
  [SMALL_STATE(277)] = 17727,
  [SMALL_STATE(278)] = 17768,
  [SMALL_STATE(279)] = 17809,
  [SMALL_STATE(280)] = 17850,
  [SMALL_STATE(281)] = 17891,
  [SMALL_STATE(282)] = 17932,
  [SMALL_STATE(283)] = 17973,
  [SMALL_STATE(284)] = 18014,
  [SMALL_STATE(285)] = 18055,
  [SMALL_STATE(286)] = 18096,
  [SMALL_STATE(287)] = 18137,
  [SMALL_STATE(288)] = 18178,
  [SMALL_STATE(289)] = 18219,
  [SMALL_STATE(290)] = 18260,
  [SMALL_STATE(291)] = 18301,
  [SMALL_STATE(292)] = 18342,
  [SMALL_STATE(293)] = 18382,
  [SMALL_STATE(294)] = 18421,
  [SMALL_STATE(295)] = 18460,
  [SMALL_STATE(296)] = 18499,
  [SMALL_STATE(297)] = 18538,
  [SMALL_STATE(298)] = 18577,
  [SMALL_STATE(299)] = 18616,
  [SMALL_STATE(300)] = 18655,
  [SMALL_STATE(301)] = 18694,
  [SMALL_STATE(302)] = 18733,
  [SMALL_STATE(303)] = 18772,
  [SMALL_STATE(304)] = 18810,
  [SMALL_STATE(305)] = 18848,
  [SMALL_STATE(306)] = 18886,
  [SMALL_STATE(307)] = 18924,
  [SMALL_STATE(308)] = 18962,
  [SMALL_STATE(309)] = 18999,
  [SMALL_STATE(310)] = 19046,
  [SMALL_STATE(311)] = 19095,
  [SMALL_STATE(312)] = 19128,
  [SMALL_STATE(313)] = 19177,
  [SMALL_STATE(314)] = 19224,
  [SMALL_STATE(315)] = 19271,
  [SMALL_STATE(316)] = 19317,
  [SMALL_STATE(317)] = 19368,
  [SMALL_STATE(318)] = 19419,
  [SMALL_STATE(319)] = 19470,
  [SMALL_STATE(320)] = 19521,
  [SMALL_STATE(321)] = 19572,
  [SMALL_STATE(322)] = 19623,
  [SMALL_STATE(323)] = 19674,
  [SMALL_STATE(324)] = 19725,
  [SMALL_STATE(325)] = 19776,
  [SMALL_STATE(326)] = 19827,
  [SMALL_STATE(327)] = 19878,
  [SMALL_STATE(328)] = 19929,
  [SMALL_STATE(329)] = 19980,
  [SMALL_STATE(330)] = 20031,
  [SMALL_STATE(331)] = 20065,
  [SMALL_STATE(332)] = 20108,
  [SMALL_STATE(333)] = 20163,
  [SMALL_STATE(334)] = 20206,
  [SMALL_STATE(335)] = 20261,
  [SMALL_STATE(336)] = 20304,
  [SMALL_STATE(337)] = 20337,
  [SMALL_STATE(338)] = 20366,
  [SMALL_STATE(339)] = 20410,
  [SMALL_STATE(340)] = 20456,
  [SMALL_STATE(341)] = 20502,
  [SMALL_STATE(342)] = 20530,
  [SMALL_STATE(343)] = 20572,
  [SMALL_STATE(344)] = 20612,
  [SMALL_STATE(345)] = 20652,
  [SMALL_STATE(346)] = 20692,
  [SMALL_STATE(347)] = 20732,
  [SMALL_STATE(348)] = 20772,
  [SMALL_STATE(349)] = 20812,
  [SMALL_STATE(350)] = 20852,
  [SMALL_STATE(351)] = 20888,
  [SMALL_STATE(352)] = 20922,
  [SMALL_STATE(353)] = 20962,
  [SMALL_STATE(354)] = 21002,
  [SMALL_STATE(355)] = 21042,
  [SMALL_STATE(356)] = 21082,
  [SMALL_STATE(357)] = 21122,
  [SMALL_STATE(358)] = 21162,
  [SMALL_STATE(359)] = 21202,
  [SMALL_STATE(360)] = 21230,
  [SMALL_STATE(361)] = 21258,
  [SMALL_STATE(362)] = 21286,
  [SMALL_STATE(363)] = 21334,
  [SMALL_STATE(364)] = 21374,
  [SMALL_STATE(365)] = 21414,
  [SMALL_STATE(366)] = 21454,
  [SMALL_STATE(367)] = 21504,
  [SMALL_STATE(368)] = 21544,
  [SMALL_STATE(369)] = 21584,
  [SMALL_STATE(370)] = 21612,
  [SMALL_STATE(371)] = 21652,
  [SMALL_STATE(372)] = 21692,
  [SMALL_STATE(373)] = 21720,
  [SMALL_STATE(374)] = 21760,
  [SMALL_STATE(375)] = 21788,
  [SMALL_STATE(376)] = 21816,
  [SMALL_STATE(377)] = 21856,
  [SMALL_STATE(378)] = 21896,
  [SMALL_STATE(379)] = 21936,
  [SMALL_STATE(380)] = 21976,
  [SMALL_STATE(381)] = 22016,
  [SMALL_STATE(382)] = 22056,
  [SMALL_STATE(383)] = 22084,
  [SMALL_STATE(384)] = 22124,
  [SMALL_STATE(385)] = 22152,
  [SMALL_STATE(386)] = 22184,
  [SMALL_STATE(387)] = 22224,
  [SMALL_STATE(388)] = 22251,
  [SMALL_STATE(389)] = 22296,
  [SMALL_STATE(390)] = 22323,
  [SMALL_STATE(391)] = 22350,
  [SMALL_STATE(392)] = 22399,
  [SMALL_STATE(393)] = 22426,
  [SMALL_STATE(394)] = 22467,
  [SMALL_STATE(395)] = 22494,
  [SMALL_STATE(396)] = 22521,
  [SMALL_STATE(397)] = 22570,
  [SMALL_STATE(398)] = 22597,
  [SMALL_STATE(399)] = 22624,
  [SMALL_STATE(400)] = 22651,
  [SMALL_STATE(401)] = 22678,
  [SMALL_STATE(402)] = 22707,
  [SMALL_STATE(403)] = 22752,
  [SMALL_STATE(404)] = 22795,
  [SMALL_STATE(405)] = 22836,
  [SMALL_STATE(406)] = 22875,
  [SMALL_STATE(407)] = 22912,
  [SMALL_STATE(408)] = 22947,
  [SMALL_STATE(409)] = 22980,
  [SMALL_STATE(410)] = 23011,
  [SMALL_STATE(411)] = 23052,
  [SMALL_STATE(412)] = 23093,
  [SMALL_STATE(413)] = 23138,
  [SMALL_STATE(414)] = 23179,
  [SMALL_STATE(415)] = 23220,
  [SMALL_STATE(416)] = 23265,
  [SMALL_STATE(417)] = 23310,
  [SMALL_STATE(418)] = 23354,
  [SMALL_STATE(419)] = 23392,
  [SMALL_STATE(420)] = 23430,
  [SMALL_STATE(421)] = 23464,
  [SMALL_STATE(422)] = 23498,
  [SMALL_STATE(423)] = 23532,
  [SMALL_STATE(424)] = 23563,
  [SMALL_STATE(425)] = 23582,
  [SMALL_STATE(426)] = 23601,
  [SMALL_STATE(427)] = 23620,
  [SMALL_STATE(428)] = 23639,
  [SMALL_STATE(429)] = 23658,
  [SMALL_STATE(430)] = 23677,
  [SMALL_STATE(431)] = 23696,
  [SMALL_STATE(432)] = 23715,
  [SMALL_STATE(433)] = 23734,
  [SMALL_STATE(434)] = 23753,
  [SMALL_STATE(435)] = 23772,
  [SMALL_STATE(436)] = 23791,
  [SMALL_STATE(437)] = 23810,
  [SMALL_STATE(438)] = 23829,
  [SMALL_STATE(439)] = 23860,
  [SMALL_STATE(440)] = 23879,
  [SMALL_STATE(441)] = 23898,
  [SMALL_STATE(442)] = 23917,
  [SMALL_STATE(443)] = 23945,
  [SMALL_STATE(444)] = 23973,
  [SMALL_STATE(445)] = 24001,
  [SMALL_STATE(446)] = 24029,
  [SMALL_STATE(447)] = 24057,
  [SMALL_STATE(448)] = 24085,
  [SMALL_STATE(449)] = 24102,
  [SMALL_STATE(450)] = 24119,
  [SMALL_STATE(451)] = 24136,
  [SMALL_STATE(452)] = 24153,
  [SMALL_STATE(453)] = 24170,
  [SMALL_STATE(454)] = 24195,
  [SMALL_STATE(455)] = 24212,
  [SMALL_STATE(456)] = 24229,
  [SMALL_STATE(457)] = 24246,
  [SMALL_STATE(458)] = 24263,
  [SMALL_STATE(459)] = 24280,
  [SMALL_STATE(460)] = 24297,
  [SMALL_STATE(461)] = 24314,
  [SMALL_STATE(462)] = 24331,
  [SMALL_STATE(463)] = 24348,
  [SMALL_STATE(464)] = 24365,
  [SMALL_STATE(465)] = 24382,
  [SMALL_STATE(466)] = 24403,
  [SMALL_STATE(467)] = 24420,
  [SMALL_STATE(468)] = 24437,
  [SMALL_STATE(469)] = 24454,
  [SMALL_STATE(470)] = 24471,
  [SMALL_STATE(471)] = 24488,
  [SMALL_STATE(472)] = 24505,
  [SMALL_STATE(473)] = 24522,
  [SMALL_STATE(474)] = 24539,
  [SMALL_STATE(475)] = 24556,
  [SMALL_STATE(476)] = 24573,
  [SMALL_STATE(477)] = 24594,
  [SMALL_STATE(478)] = 24619,
  [SMALL_STATE(479)] = 24644,
  [SMALL_STATE(480)] = 24661,
  [SMALL_STATE(481)] = 24678,
  [SMALL_STATE(482)] = 24695,
  [SMALL_STATE(483)] = 24712,
  [SMALL_STATE(484)] = 24729,
  [SMALL_STATE(485)] = 24750,
  [SMALL_STATE(486)] = 24767,
  [SMALL_STATE(487)] = 24784,
  [SMALL_STATE(488)] = 24799,
  [SMALL_STATE(489)] = 24816,
  [SMALL_STATE(490)] = 24844,
  [SMALL_STATE(491)] = 24860,
  [SMALL_STATE(492)] = 24880,
  [SMALL_STATE(493)] = 24896,
  [SMALL_STATE(494)] = 24912,
  [SMALL_STATE(495)] = 24932,
  [SMALL_STATE(496)] = 24952,
  [SMALL_STATE(497)] = 24968,
  [SMALL_STATE(498)] = 24981,
  [SMALL_STATE(499)] = 25000,
  [SMALL_STATE(500)] = 25025,
  [SMALL_STATE(501)] = 25038,
  [SMALL_STATE(502)] = 25053,
  [SMALL_STATE(503)] = 25066,
  [SMALL_STATE(504)] = 25079,
  [SMALL_STATE(505)] = 25092,
  [SMALL_STATE(506)] = 25109,
  [SMALL_STATE(507)] = 25126,
  [SMALL_STATE(508)] = 25143,
  [SMALL_STATE(509)] = 25161,
  [SMALL_STATE(510)] = 25181,
  [SMALL_STATE(511)] = 25201,
  [SMALL_STATE(512)] = 25221,
  [SMALL_STATE(513)] = 25241,
  [SMALL_STATE(514)] = 25261,
  [SMALL_STATE(515)] = 25281,
  [SMALL_STATE(516)] = 25295,
  [SMALL_STATE(517)] = 25313,
  [SMALL_STATE(518)] = 25333,
  [SMALL_STATE(519)] = 25353,
  [SMALL_STATE(520)] = 25375,
  [SMALL_STATE(521)] = 25390,
  [SMALL_STATE(522)] = 25401,
  [SMALL_STATE(523)] = 25418,
  [SMALL_STATE(524)] = 25433,
  [SMALL_STATE(525)] = 25452,
  [SMALL_STATE(526)] = 25463,
  [SMALL_STATE(527)] = 25478,
  [SMALL_STATE(528)] = 25493,
  [SMALL_STATE(529)] = 25510,
  [SMALL_STATE(530)] = 25525,
  [SMALL_STATE(531)] = 25540,
  [SMALL_STATE(532)] = 25555,
  [SMALL_STATE(533)] = 25570,
  [SMALL_STATE(534)] = 25585,
  [SMALL_STATE(535)] = 25600,
  [SMALL_STATE(536)] = 25617,
  [SMALL_STATE(537)] = 25632,
  [SMALL_STATE(538)] = 25647,
  [SMALL_STATE(539)] = 25664,
  [SMALL_STATE(540)] = 25675,
  [SMALL_STATE(541)] = 25686,
  [SMALL_STATE(542)] = 25701,
  [SMALL_STATE(543)] = 25716,
  [SMALL_STATE(544)] = 25727,
  [SMALL_STATE(545)] = 25743,
  [SMALL_STATE(546)] = 25753,
  [SMALL_STATE(547)] = 25769,
  [SMALL_STATE(548)] = 25783,
  [SMALL_STATE(549)] = 25797,
  [SMALL_STATE(550)] = 25807,
  [SMALL_STATE(551)] = 25817,
  [SMALL_STATE(552)] = 25833,
  [SMALL_STATE(553)] = 25843,
  [SMALL_STATE(554)] = 25853,
  [SMALL_STATE(555)] = 25869,
  [SMALL_STATE(556)] = 25883,
  [SMALL_STATE(557)] = 25895,
  [SMALL_STATE(558)] = 25911,
  [SMALL_STATE(559)] = 25927,
  [SMALL_STATE(560)] = 25937,
  [SMALL_STATE(561)] = 25953,
  [SMALL_STATE(562)] = 25963,
  [SMALL_STATE(563)] = 25973,
  [SMALL_STATE(564)] = 25987,
  [SMALL_STATE(565)] = 26001,
  [SMALL_STATE(566)] = 26015,
  [SMALL_STATE(567)] = 26031,
  [SMALL_STATE(568)] = 26047,
  [SMALL_STATE(569)] = 26057,
  [SMALL_STATE(570)] = 26071,
  [SMALL_STATE(571)] = 26085,
  [SMALL_STATE(572)] = 26099,
  [SMALL_STATE(573)] = 26111,
  [SMALL_STATE(574)] = 26121,
  [SMALL_STATE(575)] = 26137,
  [SMALL_STATE(576)] = 26150,
  [SMALL_STATE(577)] = 26163,
  [SMALL_STATE(578)] = 26176,
  [SMALL_STATE(579)] = 26189,
  [SMALL_STATE(580)] = 26198,
  [SMALL_STATE(581)] = 26211,
  [SMALL_STATE(582)] = 26220,
  [SMALL_STATE(583)] = 26233,
  [SMALL_STATE(584)] = 26246,
  [SMALL_STATE(585)] = 26257,
  [SMALL_STATE(586)] = 26270,
  [SMALL_STATE(587)] = 26279,
  [SMALL_STATE(588)] = 26292,
  [SMALL_STATE(589)] = 26305,
  [SMALL_STATE(590)] = 26318,
  [SMALL_STATE(591)] = 26331,
  [SMALL_STATE(592)] = 26340,
  [SMALL_STATE(593)] = 26349,
  [SMALL_STATE(594)] = 26360,
  [SMALL_STATE(595)] = 26373,
  [SMALL_STATE(596)] = 26386,
  [SMALL_STATE(597)] = 26399,
  [SMALL_STATE(598)] = 26412,
  [SMALL_STATE(599)] = 26423,
  [SMALL_STATE(600)] = 26436,
  [SMALL_STATE(601)] = 26449,
  [SMALL_STATE(602)] = 26462,
  [SMALL_STATE(603)] = 26475,
  [SMALL_STATE(604)] = 26486,
  [SMALL_STATE(605)] = 26499,
  [SMALL_STATE(606)] = 26510,
  [SMALL_STATE(607)] = 26519,
  [SMALL_STATE(608)] = 26532,
  [SMALL_STATE(609)] = 26545,
  [SMALL_STATE(610)] = 26558,
  [SMALL_STATE(611)] = 26567,
  [SMALL_STATE(612)] = 26576,
  [SMALL_STATE(613)] = 26589,
  [SMALL_STATE(614)] = 26602,
  [SMALL_STATE(615)] = 26615,
  [SMALL_STATE(616)] = 26626,
  [SMALL_STATE(617)] = 26635,
  [SMALL_STATE(618)] = 26648,
  [SMALL_STATE(619)] = 26661,
  [SMALL_STATE(620)] = 26674,
  [SMALL_STATE(621)] = 26685,
  [SMALL_STATE(622)] = 26698,
  [SMALL_STATE(623)] = 26711,
  [SMALL_STATE(624)] = 26724,
  [SMALL_STATE(625)] = 26737,
  [SMALL_STATE(626)] = 26750,
  [SMALL_STATE(627)] = 26763,
  [SMALL_STATE(628)] = 26776,
  [SMALL_STATE(629)] = 26789,
  [SMALL_STATE(630)] = 26802,
  [SMALL_STATE(631)] = 26813,
  [SMALL_STATE(632)] = 26824,
  [SMALL_STATE(633)] = 26835,
  [SMALL_STATE(634)] = 26848,
  [SMALL_STATE(635)] = 26861,
  [SMALL_STATE(636)] = 26870,
  [SMALL_STATE(637)] = 26879,
  [SMALL_STATE(638)] = 26892,
  [SMALL_STATE(639)] = 26905,
  [SMALL_STATE(640)] = 26914,
  [SMALL_STATE(641)] = 26927,
  [SMALL_STATE(642)] = 26938,
  [SMALL_STATE(643)] = 26949,
  [SMALL_STATE(644)] = 26959,
  [SMALL_STATE(645)] = 26967,
  [SMALL_STATE(646)] = 26975,
  [SMALL_STATE(647)] = 26985,
  [SMALL_STATE(648)] = 26993,
  [SMALL_STATE(649)] = 27003,
  [SMALL_STATE(650)] = 27013,
  [SMALL_STATE(651)] = 27023,
  [SMALL_STATE(652)] = 27031,
  [SMALL_STATE(653)] = 27039,
  [SMALL_STATE(654)] = 27049,
  [SMALL_STATE(655)] = 27059,
  [SMALL_STATE(656)] = 27069,
  [SMALL_STATE(657)] = 27079,
  [SMALL_STATE(658)] = 27087,
  [SMALL_STATE(659)] = 27095,
  [SMALL_STATE(660)] = 27105,
  [SMALL_STATE(661)] = 27113,
  [SMALL_STATE(662)] = 27121,
  [SMALL_STATE(663)] = 27131,
  [SMALL_STATE(664)] = 27139,
  [SMALL_STATE(665)] = 27149,
  [SMALL_STATE(666)] = 27159,
  [SMALL_STATE(667)] = 27167,
  [SMALL_STATE(668)] = 27175,
  [SMALL_STATE(669)] = 27183,
  [SMALL_STATE(670)] = 27193,
  [SMALL_STATE(671)] = 27201,
  [SMALL_STATE(672)] = 27211,
  [SMALL_STATE(673)] = 27221,
  [SMALL_STATE(674)] = 27229,
  [SMALL_STATE(675)] = 27239,
  [SMALL_STATE(676)] = 27247,
  [SMALL_STATE(677)] = 27257,
  [SMALL_STATE(678)] = 27265,
  [SMALL_STATE(679)] = 27275,
  [SMALL_STATE(680)] = 27283,
  [SMALL_STATE(681)] = 27293,
  [SMALL_STATE(682)] = 27301,
  [SMALL_STATE(683)] = 27311,
  [SMALL_STATE(684)] = 27319,
  [SMALL_STATE(685)] = 27327,
  [SMALL_STATE(686)] = 27335,
  [SMALL_STATE(687)] = 27345,
  [SMALL_STATE(688)] = 27355,
  [SMALL_STATE(689)] = 27365,
  [SMALL_STATE(690)] = 27373,
  [SMALL_STATE(691)] = 27381,
  [SMALL_STATE(692)] = 27391,
  [SMALL_STATE(693)] = 27401,
  [SMALL_STATE(694)] = 27411,
  [SMALL_STATE(695)] = 27418,
  [SMALL_STATE(696)] = 27425,
  [SMALL_STATE(697)] = 27432,
  [SMALL_STATE(698)] = 27439,
  [SMALL_STATE(699)] = 27446,
  [SMALL_STATE(700)] = 27453,
  [SMALL_STATE(701)] = 27460,
  [SMALL_STATE(702)] = 27467,
  [SMALL_STATE(703)] = 27474,
  [SMALL_STATE(704)] = 27481,
  [SMALL_STATE(705)] = 27488,
  [SMALL_STATE(706)] = 27495,
  [SMALL_STATE(707)] = 27502,
  [SMALL_STATE(708)] = 27509,
  [SMALL_STATE(709)] = 27516,
  [SMALL_STATE(710)] = 27523,
  [SMALL_STATE(711)] = 27530,
  [SMALL_STATE(712)] = 27537,
  [SMALL_STATE(713)] = 27544,
  [SMALL_STATE(714)] = 27551,
  [SMALL_STATE(715)] = 27558,
  [SMALL_STATE(716)] = 27565,
  [SMALL_STATE(717)] = 27572,
  [SMALL_STATE(718)] = 27579,
  [SMALL_STATE(719)] = 27586,
  [SMALL_STATE(720)] = 27593,
  [SMALL_STATE(721)] = 27600,
  [SMALL_STATE(722)] = 27607,
  [SMALL_STATE(723)] = 27614,
  [SMALL_STATE(724)] = 27621,
  [SMALL_STATE(725)] = 27628,
  [SMALL_STATE(726)] = 27635,
  [SMALL_STATE(727)] = 27642,
  [SMALL_STATE(728)] = 27649,
  [SMALL_STATE(729)] = 27656,
  [SMALL_STATE(730)] = 27663,
  [SMALL_STATE(731)] = 27670,
  [SMALL_STATE(732)] = 27677,
  [SMALL_STATE(733)] = 27684,
  [SMALL_STATE(734)] = 27691,
  [SMALL_STATE(735)] = 27698,
  [SMALL_STATE(736)] = 27705,
  [SMALL_STATE(737)] = 27712,
  [SMALL_STATE(738)] = 27719,
  [SMALL_STATE(739)] = 27726,
  [SMALL_STATE(740)] = 27733,
  [SMALL_STATE(741)] = 27740,
  [SMALL_STATE(742)] = 27747,
  [SMALL_STATE(743)] = 27754,
  [SMALL_STATE(744)] = 27761,
  [SMALL_STATE(745)] = 27768,
  [SMALL_STATE(746)] = 27775,
  [SMALL_STATE(747)] = 27782,
  [SMALL_STATE(748)] = 27789,
  [SMALL_STATE(749)] = 27796,
  [SMALL_STATE(750)] = 27803,
  [SMALL_STATE(751)] = 27810,
  [SMALL_STATE(752)] = 27817,
  [SMALL_STATE(753)] = 27824,
  [SMALL_STATE(754)] = 27831,
  [SMALL_STATE(755)] = 27838,
  [SMALL_STATE(756)] = 27845,
  [SMALL_STATE(757)] = 27852,
  [SMALL_STATE(758)] = 27859,
  [SMALL_STATE(759)] = 27866,
  [SMALL_STATE(760)] = 27873,
  [SMALL_STATE(761)] = 27880,
  [SMALL_STATE(762)] = 27887,
  [SMALL_STATE(763)] = 27894,
  [SMALL_STATE(764)] = 27901,
  [SMALL_STATE(765)] = 27908,
  [SMALL_STATE(766)] = 27915,
  [SMALL_STATE(767)] = 27922,
  [SMALL_STATE(768)] = 27929,
  [SMALL_STATE(769)] = 27936,
  [SMALL_STATE(770)] = 27943,
  [SMALL_STATE(771)] = 27950,
  [SMALL_STATE(772)] = 27957,
  [SMALL_STATE(773)] = 27964,
  [SMALL_STATE(774)] = 27971,
  [SMALL_STATE(775)] = 27978,
  [SMALL_STATE(776)] = 27985,
  [SMALL_STATE(777)] = 27992,
  [SMALL_STATE(778)] = 27999,
  [SMALL_STATE(779)] = 28006,
  [SMALL_STATE(780)] = 28013,
  [SMALL_STATE(781)] = 28020,
  [SMALL_STATE(782)] = 28027,
  [SMALL_STATE(783)] = 28034,
  [SMALL_STATE(784)] = 28041,
  [SMALL_STATE(785)] = 28048,
  [SMALL_STATE(786)] = 28055,
  [SMALL_STATE(787)] = 28062,
  [SMALL_STATE(788)] = 28069,
  [SMALL_STATE(789)] = 28076,
  [SMALL_STATE(790)] = 28083,
  [SMALL_STATE(791)] = 28090,
  [SMALL_STATE(792)] = 28097,
  [SMALL_STATE(793)] = 28104,
  [SMALL_STATE(794)] = 28111,
  [SMALL_STATE(795)] = 28118,
  [SMALL_STATE(796)] = 28125,
  [SMALL_STATE(797)] = 28132,
  [SMALL_STATE(798)] = 28139,
  [SMALL_STATE(799)] = 28146,
  [SMALL_STATE(800)] = 28153,
  [SMALL_STATE(801)] = 28160,
  [SMALL_STATE(802)] = 28167,
  [SMALL_STATE(803)] = 28174,
  [SMALL_STATE(804)] = 28181,
  [SMALL_STATE(805)] = 28188,
  [SMALL_STATE(806)] = 28195,
  [SMALL_STATE(807)] = 28202,
  [SMALL_STATE(808)] = 28209,
  [SMALL_STATE(809)] = 28216,
  [SMALL_STATE(810)] = 28223,
  [SMALL_STATE(811)] = 28230,
  [SMALL_STATE(812)] = 28237,
  [SMALL_STATE(813)] = 28244,
  [SMALL_STATE(814)] = 28251,
  [SMALL_STATE(815)] = 28258,
  [SMALL_STATE(816)] = 28265,
  [SMALL_STATE(817)] = 28272,
  [SMALL_STATE(818)] = 28279,
  [SMALL_STATE(819)] = 28286,
  [SMALL_STATE(820)] = 28293,
  [SMALL_STATE(821)] = 28300,
  [SMALL_STATE(822)] = 28307,
  [SMALL_STATE(823)] = 28314,
  [SMALL_STATE(824)] = 28321,
  [SMALL_STATE(825)] = 28328,
  [SMALL_STATE(826)] = 28335,
  [SMALL_STATE(827)] = 28342,
  [SMALL_STATE(828)] = 28349,
  [SMALL_STATE(829)] = 28356,
  [SMALL_STATE(830)] = 28363,
  [SMALL_STATE(831)] = 28370,
  [SMALL_STATE(832)] = 28377,
  [SMALL_STATE(833)] = 28384,
  [SMALL_STATE(834)] = 28391,
  [SMALL_STATE(835)] = 28398,
  [SMALL_STATE(836)] = 28405,
  [SMALL_STATE(837)] = 28412,
  [SMALL_STATE(838)] = 28419,
  [SMALL_STATE(839)] = 28426,
  [SMALL_STATE(840)] = 28433,
  [SMALL_STATE(841)] = 28440,
  [SMALL_STATE(842)] = 28447,
  [SMALL_STATE(843)] = 28454,
  [SMALL_STATE(844)] = 28461,
  [SMALL_STATE(845)] = 28468,
  [SMALL_STATE(846)] = 28475,
  [SMALL_STATE(847)] = 28482,
  [SMALL_STATE(848)] = 28489,
  [SMALL_STATE(849)] = 28496,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(706),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(484),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(746),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(368),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(766),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(649),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(786),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(816),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(496),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(490),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(545),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(830),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(734),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(761),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(796),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(843),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(177),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(180),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(689),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [77] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [81] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [85] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sizeof_expression, 4, 0, 26),
  [87] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sizeof_expression, 4, 0, 26),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(112),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(785),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(525),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(543),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(559),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [111] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(527),
  [114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0),
  [116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(821),
  [119] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(13),
  [122] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(786),
  [125] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2),
  [128] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(557),
  [131] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(175),
  [134] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(830),
  [137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(734),
  [140] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(761),
  [143] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(796),
  [146] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(843),
  [149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(176),
  [152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(175),
  [155] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(177),
  [158] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(180),
  [161] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(180),
  [164] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(689),
  [167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [169] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(541),
  [172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [174] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(797),
  [177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [179] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(816),
  [182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(496),
  [185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(490),
  [188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(545),
  [191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(709),
  [203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(847),
  [205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(842),
  [207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(848),
  [209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_code, 2, 0, 0),
  [211] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_code, 2, 0, 0),
  [213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 4, 0, 0),
  [215] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 4, 0, 0),
  [217] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_defn, 1, 0, 0),
  [219] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block_defn, 1, 0, 0),
  [221] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 2, 0, 0),
  [223] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 2, 0, 0),
  [225] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_code, 3, 0, 13),
  [227] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_code, 3, 0, 13),
  [229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 3, 0, 0),
  [231] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 3, 0, 0),
  [233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(739),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 5, 0, 2),
  [275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 5, 0, 2),
  [277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [281] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 6, 0, 2),
  [283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 6, 0, 2),
  [285] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 3, 0, 2),
  [287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 3, 0, 2),
  [289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 4, 0, 2),
  [291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 4, 0, 2),
  [293] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(532),
  [296] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(849),
  [299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0),
  [301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(791),
  [304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(682),
  [307] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(496),
  [310] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(816),
  [313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(490),
  [316] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(490),
  [319] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(545),
  [322] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(824),
  [325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(829),
  [328] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(739),
  [331] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(743),
  [334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(603),
  [337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [343] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 0),
  [345] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 0),
  [347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2, 0, 0),
  [351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2, 0, 0),
  [353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 4, 0, 0),
  [363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 4, 0, 0),
  [365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 2, 0, 0),
  [367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 2, 0, 0),
  [369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [371] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 0),
  [373] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 0),
  [375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, 0, 5),
  [381] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 5),
  [383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sizeof_expression, 2, 0, 17),
  [387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(152),
  [389] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sizeof_expression, 2, 0, 17),
  [391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(154),
  [393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(164),
  [395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, 0, 18),
  [397] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 18),
  [399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(171),
  [407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [409] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [411] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exit_expression, 3, 0, 0),
  [415] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exit_expression, 3, 0, 0),
  [417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 10),
  [421] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 10),
  [423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 3, 0, 23),
  [425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 3, 0, 23),
  [427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, 0, 10),
  [429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(178),
  [431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(158),
  [441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(160),
  [443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(161),
  [445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 3, 0, 24),
  [455] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 3, 0, 24),
  [457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cast_expression, 4, 0, 25),
  [459] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cast_expression, 4, 0, 25),
  [461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exit_expression, 4, 0, 0),
  [463] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exit_expression, 4, 0, 0),
  [465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 4, 0, 23),
  [471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 4, 0, 23),
  [473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_expression, 4, 0, 0),
  [475] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_expression, 4, 0, 0),
  [477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_expression, 5, 0, 29),
  [483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 3, 0, 0),
  [493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 3, 0, 0),
  [495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_char_literal, 3, 0, 0),
  [497] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_char_literal, 3, 0, 0),
  [499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(173),
  [515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [519] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0), SHIFT_REPEAT(530),
  [522] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0), SHIFT_REPEAT(826),
  [525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0),
  [527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0),
  [529] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0), SHIFT_REPEAT(694),
  [532] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0), SHIFT_REPEAT(496),
  [535] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0), SHIFT_REPEAT(816),
  [538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0), SHIFT_REPEAT(490),
  [541] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0), SHIFT_REPEAT(490),
  [544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0), SHIFT_REPEAT(545),
  [547] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 7, 0, 2),
  [549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 7, 0, 2),
  [551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 8, 0, 2),
  [553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 8, 0, 2),
  [555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comma_expr, 3, 0, 0),
  [557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(99),
  [563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(202),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(102),
  [571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(104),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(105),
  [579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(501),
  [589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(574),
  [593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(106),
  [595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(107),
  [603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(108),
  [607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(109),
  [611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(110),
  [615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(111),
  [619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(120),
  [623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(204),
  [627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_comma_expr_repeat1, 2, 0, 0),
  [631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structdef, 4, 0, 19),
  [633] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_structdef, 4, 0, 19),
  [635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2, 0, 0),
  [637] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2, 0, 0), SHIFT_REPEAT(816),
  [640] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2, 0, 0), SHIFT_REPEAT(496),
  [643] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2, 0, 0), SHIFT_REPEAT(490),
  [646] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_state_block_repeat1, 2, 0, 0), SHIFT_REPEAT(490),
  [649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2, 0, 0), SHIFT_REPEAT(545),
  [652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2, 0, 0), SHIFT_REPEAT(824),
  [655] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2, 0, 0), SHIFT_REPEAT(829),
  [658] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_state_block_repeat1, 2, 0, 0), SHIFT_REPEAT(739),
  [661] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2, 0, 0), SHIFT_REPEAT(743),
  [664] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2, 0, 0), SHIFT_REPEAT(603),
  [667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_expr, 1, 0, 0),
  [669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_args, 1, 0, 0),
  [671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(90),
  [673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(92),
  [677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(93),
  [683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(101),
  [687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_funcdef, 3, 0, 0),
  [691] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_funcdef, 3, 0, 0),
  [693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__comma_expr, 1, 0, 0),
  [695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(149),
  [699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [701] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0), SHIFT_REPEAT(533),
  [704] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0), SHIFT_REPEAT(827),
  [707] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0), SHIFT_REPEAT(839),
  [710] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0), SHIFT_REPEAT(532),
  [713] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0), SHIFT_REPEAT(849),
  [716] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2, 0, 0), SHIFT_REPEAT(791),
  [719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_program_repeat2, 2, 0, 0),
  [723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_program_repeat2, 2, 0, 0),
  [725] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat2, 2, 0, 0), SHIFT_REPEAT(841),
  [728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 27),
  [734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 27),
  [736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_set, 6, 0, 2),
  [740] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_state_set, 6, 0, 2),
  [742] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat2, 2, 0, 0), SHIFT_REPEAT(846),
  [745] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat2, 2, 0, 0), SHIFT_REPEAT(729),
  [748] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_set, 5, 0, 2),
  [750] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_state_set, 5, 0, 2),
  [752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 27),
  [756] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 27),
  [758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syncq, 3, 0, 0),
  [760] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_syncq, 3, 0, 0),
  [762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 2, 0, 0),
  [764] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 2, 0, 0),
  [766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [768] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [776] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2, 0, 0), SHIFT_REPEAT(816),
  [779] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2, 0, 0), SHIFT_REPEAT(496),
  [782] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2, 0, 0), SHIFT_REPEAT(490),
  [785] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_state_set_repeat1, 2, 0, 0), SHIFT_REPEAT(490),
  [788] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2, 0, 0), SHIFT_REPEAT(545),
  [791] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2, 0, 0), SHIFT_REPEAT(824),
  [794] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2, 0, 0), SHIFT_REPEAT(829),
  [797] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_state_set_repeat1, 2, 0, 0), SHIFT_REPEAT(739),
  [800] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2, 0, 0), SHIFT_REPEAT(743),
  [803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2, 0, 0),
  [805] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assign, 5, 0, 0),
  [807] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assign, 5, 0, 0),
  [809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assign, 4, 0, 0),
  [811] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assign, 4, 0, 0),
  [813] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 5, 0, 28),
  [815] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, 0, 28),
  [817] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assign, 3, 0, 0),
  [819] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assign, 3, 0, 0),
  [821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 30),
  [823] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6, 0, 30),
  [825] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_statement, 2, 0, 31),
  [827] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_statement, 2, 0, 31),
  [829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 32),
  [831] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 32),
  [833] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 33),
  [835] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 33),
  [837] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 34),
  [839] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 34),
  [841] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 35),
  [843] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 35),
  [845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 36),
  [847] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 36),
  [849] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 37),
  [851] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 37),
  [853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, 0, 38),
  [855] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 38),
  [857] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_monitor, 4, 0, 0),
  [859] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_monitor, 4, 0, 0),
  [861] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assign, 7, 0, 0),
  [863] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assign, 7, 0, 0),
  [865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syncq, 7, 0, 0),
  [867] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_syncq, 7, 0, 0),
  [869] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sync, 4, 0, 0),
  [871] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sync, 4, 0, 0),
  [873] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syncq, 4, 0, 0),
  [875] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_syncq, 4, 0, 0),
  [877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assign, 8, 0, 0),
  [879] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assign, 8, 0, 0),
  [881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assign, 6, 0, 0),
  [883] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assign, 6, 0, 0),
  [885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sync, 6, 0, 0),
  [887] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sync, 6, 0, 0),
  [889] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syncq, 6, 0, 0),
  [891] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_syncq, 6, 0, 0),
  [893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sync, 5, 0, 0),
  [895] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sync, 5, 0, 0),
  [897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_monitor, 3, 0, 0),
  [899] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_monitor, 3, 0, 0),
  [901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syncq, 5, 0, 0),
  [903] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_syncq, 5, 0, 0),
  [905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1, 0, 0),
  [907] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 1, 0, 0),
  [909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 2, 0, 0),
  [911] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 2, 0, 0),
  [913] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exit, 2, 0, 0),
  [915] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exit, 2, 0, 0),
  [917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_final_defn, 1, 0, 0),
  [919] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_final_defn, 1, 0, 0),
  [921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option, 4, 0, 20),
  [923] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option, 4, 0, 20),
  [925] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreign_declaration, 4, 0, 0),
  [927] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreign_declaration, 4, 0, 0),
  [929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreign_declaration, 2, 0, 0),
  [931] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreign_declaration, 2, 0, 0),
  [933] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program_param, 3, 0, 0),
  [935] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program_param, 3, 0, 0),
  [937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreign_declaration, 3, 0, 0),
  [939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreign_declaration, 3, 0, 0),
  [941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initial_defn, 1, 0, 0),
  [943] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initial_defn, 1, 0, 0),
  [945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_defn, 1, 0, 0),
  [947] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_state_defn, 1, 0, 0),
  [949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [953] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ss_defn, 1, 0, 0),
  [955] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ss_defn, 1, 0, 0),
  [957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2, 0, 0),
  [963] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(816),
  [966] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(496),
  [969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(490),
  [972] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(490),
  [975] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(545),
  [978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(465),
  [984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(792),
  [986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(379),
  [988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(439),
  [990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(793),
  [992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(393),
  [994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(357),
  [996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(653),
  [998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(435),
  [1000] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elif, 3, 0, 11),
  [1002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(427),
  [1004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(430),
  [1006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(486),
  [1008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(460),
  [1010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(480),
  [1012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(482),
  [1014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(469),
  [1016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(470),
  [1018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(462),
  [1020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(455),
  [1022] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elif, 4, 0, 11),
  [1024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__preproc_expression, 1, 0, 0),
  [1026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [1028] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__preproc_expression, 1, 0, 0),
  [1030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [1032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [1034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(348),
  [1036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [1038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [1040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [1042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(330),
  [1044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(654),
  [1046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [1048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [1050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [1052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [1054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(386),
  [1056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [1058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [1060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [1062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [1064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(349),
  [1066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [1068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(354),
  [1070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [1076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [1078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [1080] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(789),
  [1083] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(790),
  [1086] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(465),
  [1089] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(792),
  [1092] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(379),
  [1095] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [1097] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(793),
  [1100] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(653),
  [1103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(333),
  [1105] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [1107] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_decl, 3, 0, 0),
  [1109] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_decl, 3, 0, 0),
  [1111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_binary_expression, 3, 0, 10),
  [1113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_binary_expression, 3, 0, 10),
  [1115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_argument_list, 4, 0, 0),
  [1117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_argument_list, 4, 0, 0),
  [1119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [1121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [1123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [1125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [1127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [1129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [1131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [1133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [1135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(358),
  [1137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [1139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [1141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [1143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(336),
  [1145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(650),
  [1147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [1149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [1151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [1153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [1155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [1157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_call_expression, 2, 0, 4),
  [1159] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_call_expression, 2, 0, 4),
  [1161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_unary_expression, 2, 0, 5),
  [1163] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_unary_expression, 2, 0, 5),
  [1165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_defined, 2, 0, 0),
  [1167] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_defined, 2, 0, 0),
  [1169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [1171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [1173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [1175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_argument_list_repeat1, 2, 0, 0),
  [1177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [1179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [1181] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_argument_list, 2, 0, 0),
  [1183] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_argument_list, 2, 0, 0),
  [1185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [1187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [1189] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_parenthesized_expression, 3, 0, 0),
  [1191] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_parenthesized_expression, 3, 0, 0),
  [1193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [1195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_argument_list, 3, 0, 0),
  [1197] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_argument_list, 3, 0, 0),
  [1199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_defined, 4, 0, 0),
  [1201] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_defined, 4, 0, 0),
  [1203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [1205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [1207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [1209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [1211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [1213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [1215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [1217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [1219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(381),
  [1221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [1223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(364),
  [1225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(367),
  [1227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(377),
  [1229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(353),
  [1231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(365),
  [1233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(371),
  [1235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(373),
  [1237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(378),
  [1239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(380),
  [1241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [1243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(814),
  [1245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [1247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(476),
  [1249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(817),
  [1251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(383),
  [1253] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_else, 1, 0, 0),
  [1255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(818),
  [1257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(693),
  [1259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [1261] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(814),
  [1264] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(815),
  [1267] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(476),
  [1270] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(817),
  [1273] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(383),
  [1276] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(818),
  [1279] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(693),
  [1282] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_else, 2, 0, 0),
  [1284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [1286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [1288] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(706),
  [1291] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(757),
  [1294] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(484),
  [1297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(746),
  [1300] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(368),
  [1303] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(766),
  [1306] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(649),
  [1309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [1315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_expr, 1, 0, 0),
  [1317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(494),
  [1319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__abs_decl, 1, 0, 0),
  [1321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(495),
  [1323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 1, 1, 0),
  [1325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(491),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [1335] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_def, 4, 0, 8),
  [1337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_def, 4, 0, 8),
  [1339] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_function_def, 4, 0, 9),
  [1341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_function_def, 4, 0, 9),
  [1343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_line_marker, 4, 0, 7),
  [1345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line_marker, 4, 0, 7),
  [1347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 4, 0, 11),
  [1349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 4, 0, 11),
  [1351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 5, 0, 15),
  [1353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 5, 0, 15),
  [1355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_call, 2, 0, 1),
  [1357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_call, 2, 0, 1),
  [1359] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 5, 0, 11),
  [1361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 5, 0, 11),
  [1363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 5, 0, 16),
  [1365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 5, 0, 16),
  [1367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_line_marker, 3, 0, 0),
  [1369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line_marker, 3, 0, 0),
  [1371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_function_def, 5, 0, 14),
  [1373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_function_def, 5, 0, 14),
  [1375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_def, 3, 0, 2),
  [1377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_def, 3, 0, 2),
  [1379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 3, 0, 2),
  [1381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 3, 0, 2),
  [1383] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_include, 3, 0, 3),
  [1385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_include, 3, 0, 3),
  [1387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 4, 0, 12),
  [1389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 4, 0, 12),
  [1391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 4, 0, 2),
  [1393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 4, 0, 2),
  [1395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 6, 0, 22),
  [1397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 6, 0, 22),
  [1399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_call, 3, 0, 6),
  [1401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_call, 3, 0, 6),
  [1403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [1405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [1407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(578),
  [1409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [1411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(608),
  [1413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [1415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(625),
  [1417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 3, 0, 0),
  [1419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [1421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(659),
  [1423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [1425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [1427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(657),
  [1429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_prim_type, 1, 0, 0),
  [1431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_prim_type, 1, 0, 0),
  [1433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [1435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_declarator, 2, 0, 0),
  [1437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_prim_type, 2, 0, 0),
  [1439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_prim_type, 2, 0, 0),
  [1441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_basetype, 2, 0, 0),
  [1443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_basetype, 2, 0, 0),
  [1445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declarator, 1, 0, 0),
  [1447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declarator, 2, 0, 0),
  [1449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_basetype, 1, 0, 0),
  [1451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_basetype, 1, 0, 0),
  [1453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declarator, 3, 0, 21),
  [1455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [1457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [1461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [1463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [1465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declarator, 3, 0, 0),
  [1467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0),
  [1469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0),
  [1471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_declarator, 2, 0, 0),
  [1473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declarator, 4, 0, 21),
  [1475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declarator, 5, 0, 21),
  [1477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [1479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(567),
  [1481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [1483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [1485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__expanded_string_literal_repeat1, 2, 0, 0),
  [1487] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__expanded_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(509),
  [1490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__expanded_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(777),
  [1493] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__expanded_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(509),
  [1496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(635),
  [1498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [1500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [1502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(509),
  [1504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [1506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(591),
  [1508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [1510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(510),
  [1512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [1514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [1516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(646),
  [1518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(553),
  [1520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(248),
  [1522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [1524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abs_decl, 1, 0, 0),
  [1526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(56),
  [1528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(655),
  [1530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(174),
  [1532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(288),
  [1534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 2, 1, 0),
  [1536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [1538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(269),
  [1540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(270),
  [1542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(170),
  [1544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [1546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(293),
  [1548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__abs_decl, 2, 0, 0),
  [1550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(247),
  [1552] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__c_code_repeat1, 2, 0, 0), SHIFT_REPEAT(553),
  [1555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__c_code_repeat1, 2, 0, 0),
  [1557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_declarator, 1, 0, 0),
  [1559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [1561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [1563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(50),
  [1565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_state_block_repeat2, 2, 0, 0),
  [1567] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat2, 2, 0, 0), SHIFT_REPEAT(733),
  [1570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(434),
  [1572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [1574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(805),
  [1576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [1578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(468),
  [1580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(701),
  [1582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [1584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_state_set_repeat2, 2, 0, 0),
  [1586] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat2, 2, 0, 0), SHIFT_REPEAT(767),
  [1589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_entry, 2, 0, 0),
  [1591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_function_declarator, 2, 0, 0),
  [1593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [1595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__c_code_repeat1, 1, 0, 0),
  [1597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(748),
  [1599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [1601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(558),
  [1603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comma_expr, 4, 0, 0),
  [1605] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_expansion, 3, 0, 0),
  [1607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_expansion, 3, 0, 0),
  [1609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(88),
  [1611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [1613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(560),
  [1615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0),
  [1617] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(558),
  [1620] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(558),
  [1623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [1625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(124),
  [1627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__abs_decl, 3, 0, 0),
  [1629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_function_declarator, 3, 0, 0),
  [1631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comma_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(159),
  [1634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [1636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(457),
  [1640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(747),
  [1642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(770),
  [1644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [1646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(554),
  [1648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_function_declarator, 4, 0, 0),
  [1650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [1652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [1654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [1656] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 3, 0, 0),
  [1658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_function_declarator, 5, 0, 0),
  [1660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [1662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [1664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [1666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [1668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [1670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [1672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [1674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_expr, 6, 0, 0),
  [1676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [1678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [1680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_expr, 3, 0, 0),
  [1682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [1684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [1686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [1688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_expr, 2, 0, 0),
  [1690] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(376),
  [1693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_params_repeat1, 2, 0, 0),
  [1695] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_params_repeat1, 2, 0, 0), SHIFT_REPEAT(645),
  [1698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_declarator_repeat1, 2, 0, 0),
  [1700] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(315),
  [1703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expanded_string_literal, 2, 0, 0),
  [1705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_expr, 7, 0, 0),
  [1707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [1709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [1711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [1713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [1715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [1717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [1719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [1721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [1723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [1725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [1727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [1729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_transition, 5, 0, 0),
  [1731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [1733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [1735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [1737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_transition, 6, 0, 39),
  [1739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_transition, 7, 0, 41),
  [1741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [1743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_args, 2, 0, 0),
  [1745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [1747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_expr, 4, 0, 0),
  [1749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_init_expr_repeat1, 2, 0, 0),
  [1751] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_init_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(133),
  [1754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_foreign_declaration_repeat1, 2, 0, 0),
  [1756] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_foreign_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(820),
  [1759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [1761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [1763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [1765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [1767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [1769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [1771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(691),
  [1773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_assign_repeat1, 2, 0, 0),
  [1777] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assign_repeat1, 2, 0, 0), SHIFT_REPEAT(665),
  [1780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [1782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expanded_string_literal, 3, 0, 0),
  [1784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_expr, 5, 0, 0),
  [1786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [1788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [1790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_transition, 6, 0, 40),
  [1792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declaration_repeat1, 2, 0, 0),
  [1794] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(438),
  [1797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [1799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [1801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(425),
  [1803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(703),
  [1805] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_params, 3, 0, 0),
  [1807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [1809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [1811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [1813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(466),
  [1815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(731),
  [1817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [1819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [1821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state, 3, 0, 2),
  [1823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(429),
  [1825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(773),
  [1827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [1829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [1831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(452),
  [1833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(726),
  [1835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_flag, 1, 0, 0),
  [1837] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_block, 5, 0, 0),
  [1839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [1841] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_params, 2, 0, 0),
  [1843] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_block, 2, 0, 0),
  [1845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_block, 4, 0, 0),
  [1847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(475),
  [1849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(759),
  [1851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [1853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [1855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_declarator, 3, 0, 0),
  [1857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [1859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [1861] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_block, 6, 0, 0),
  [1863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_param_decl, 1, 0, 0),
  [1865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [1867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [1869] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_param_decl, 2, 0, 0),
  [1871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [1873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [1875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(822),
  [1877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_block, 3, 0, 0),
  [1879] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_params, 4, 0, 0),
  [1881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(749),
  [1883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_expr, 2, 0, 0),
  [1885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(488),
  [1887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(741),
  [1889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [1891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [1893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [1895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [1897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [1899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [1901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [1903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [1905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [1907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [1909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [1911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [1913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [1915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [1919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [1921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(675),
  [1923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [1925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [1929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 3, 0, 0),
  [1931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [1933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [1935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [1937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [1941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [1943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [1945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 2, 0, 0),
  [1947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [1949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [1953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [1955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [1957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [1959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [1961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [1963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [1965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [1967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [1969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [1971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [1973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [1975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [1977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [1979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [1981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [1983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [1989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [1991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [1993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [1999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [2001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [2003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [2005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [2007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [2009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [2011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [2013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [2017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [2023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [2027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [2029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [2031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [2033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [2035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [2037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [2043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [2045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [2049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [2051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [2053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [2057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [2059] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [2063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [2065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [2069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [2071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [2073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [2077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(696),
  [2079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [2081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [2083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [2085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif, 5, 0, 22),
  [2087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [2089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [2093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif, 4, 0, 15),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [2097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [2099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_value, 1, 0, 0),
  [2101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [2103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [2107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [2109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [2111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [2113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [2115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [2117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [2119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [2121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [2123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(754),
  [2125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [2127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syncq_size, 1, 0, 0),
  [2129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [2131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [2133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(774),
  [2135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [2137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(788),
  [2139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [2141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [2143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [2145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [2149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [2151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [2153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [2155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [2157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [2159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [2161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [2163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [2165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [2167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [2169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [2171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [2173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [2175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [2177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(717),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_snl(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
    .name = "snl",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 0,
      .minor_version = 1,
      .patch_version = 0,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
